(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     66812,       1557]*)
(*NotebookOutlinePosition[     68055,       1601]*)
(*  CellTagsIndexPosition[     67958,       1594]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["SEM", "Title",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontColor->RGBColor[1, 0, 0]],

Cell["\<\
Linear Structural Equations Models 
with Arbitrary Nonlinear 
Parameter Restrictions

Version 0.3 

\[Copyright] Hermann.Singer@FernUni-Hagen.de\
\>", "Subtitle",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontColor->RGBColor[1, 0, 0]],

Cell[TextData[StyleBox["\nThe program is shareware, \nso please cite the \
author and \nsend me a message \nif you are using it\nor if you find bugs",
  FontColor->RGBColor[1, 0, 0]]], "Subsubtitle",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Model 1: stochastic regressors xi", "Section",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  "eta = beta.eta + gamma.xi + zeta\ny   = lambdaeta.eta + epsilon\nx   = \
lambdaxi.xi + delta\n\nFree parameters:\n\n        \
{{beta,gamma,muexi,sigmaxi,sigmazeta},\n        \
{lambdaeta,lambdaxi,sigmaepsilon,sigmadelta}}=\n        \n        ",
  StyleBox["System",
    FontColor->RGBColor[1, 0, 0]],
  "[Theta,ThetaFix];"
}], "Input",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Model 2: deterministic regressors xi", "Section",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  "eta = beta.eta + gamma.xi + zeta\ny   = lambdaeta.eta + taueta.xi + \
epsilon\n\nFree parameters:\n\n        {{beta,gamma,sigmazeta},\n         \
{lambdaeta,taueta,sigmaepsilon}}=  \n         \n         ",
  StyleBox["System",
    FontColor->RGBColor[1, 0, 0]],
  "[Theta,ThetaFix];"
}], "Input",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
 Remarks
\
\>", "Section",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["The second model is more general, since eta --> (eta,xi) includes \
stochastic regressors\n\n",
    FontFamily->"Times",
    FontSize->14],
  StyleBox["The LISREL model with structured means is a special case:",
    FontFamily->"Times",
    FontSize->14,
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["\n\n",
    FontFamily->"Arial",
    FontSize->14,
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["{eta,xi} = {{Beta,Gamma},{0,0}}.{eta,xi} + {alpha,kappa} + \
{zeta1,zeta2}; \n\nCov(",
    FontSize->10,
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["zeta1,zeta2",
    FontSize->10,
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[")=0; Var(zeta2)=phi; E[xi]=kappa",
    FontSize->10,
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["\n\n",
    FontFamily->"Arial",
    FontSize->10,
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["{y,x} = {tauy,taux} + ",
    FontSize->10,
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["DiagonalMatrix[",
    FontSize->10,
    FontWeight->"Plain"],
  StyleBox["{lambday,lambdax}].",
    FontSize->10,
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["{eta,xi}",
    FontSize->10,
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" + {epsilon,delta}",
    FontSize->10,
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["\n\nThetaFix contains fixed parameters (e.g. sampling interval)\n\
\nNonlinear restrictions are implemented in module System\n\nExecute the \
following code and study the example notebooks\n\n",
    FontFamily->"Times",
    FontSize->14],
  StyleBox["car2.SEM.determ.1komponente.nb (ar(2) with deterministic \
regressors)",
    FontWeight->"Plain"],
  StyleBox["\n",
    FontSize->14],
  StyleBox["car2.SEM.random.1komponente.nb (ar(2) with random effects, \
stochastic regressors)\nfactor.nb  (LISREL  model EX1.LS8, p.6,  97-122)",
    FontWeight->"Plain"],
  StyleBox["\n",
    FontSize->14]
}], "Input",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pakete", "Section",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontVariations->{"CompatibilityType"->0}],

Cell[BoxData[{
    \(<< "\<LinearAlgebra`MatrixManipulation`\>"\), "\n", 
    \(\(\(<< "\<Statistics`NormalDistribution`\>"\)\(\n\)
    \) (*<< "\<Statistics`InverseStatisticalFunctions`\>"*) \), "\n", 
    \(<< "\<Statistics`Common`DistributionsCommon`\>"\)}], "Input",
  CellLabel->"In[146]:=",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}]
}, Closed]],

Cell[CellGroupData[{

Cell["Clear Modules", "Section",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  FontVariations->{"CompatibilityType"->0}],

Cell[BoxData[{
    \(\(Unprotect["\<Hermann`Kronecker`*\>"];\)\), "\[IndentingNewLine]", 
    \(\(Clear["\<Hermann`Kronecker`*\>"];\)\)}], "Input",
  CellLabel->"In[149]:=",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],

Cell[BoxData[{
    \(\(Unprotect["\<Hermann`LSD`*\>"];\)\), "\[IndentingNewLine]", 
    \(\(Clear["\<Hermann`LSD`*\>"];\)\)}], "Input",
  CellLabel->"In[151]:=",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],

Cell[BoxData[{
    \(\(Unprotect["\<Hermann`PARTest`*\>"];\)\), "\[IndentingNewLine]", 
    \(\(Clear["\<Hermann`PARTest`*\>"];\)\)}], "Input",
  CellLabel->"In[153]:=",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}]
}, Closed]],

Cell[CellGroupData[{

Cell["Implementierung / stochastische Regressoren", "Section",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[BoxData[{
    \(Clear[LISRELsimul]\), "\n", 
    \(LISRELsimul[{n_, Generator_}, 
        Theta_, {System_, 
          ThetaFix_}] := \[IndentingNewLine]\[IndentingNewLine]Block[{p, q, 
          beta, gamma, B1, muexi, sigmaxi, XI, sigmazeta, 
          ZETA, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ ETA, sigmaepsilon, 
          lambdaeta, kp, EPSILON, sigmadelta, lambdaxi, kq, Y, X, 
          DELTA}, \[IndentingNewLine]\[IndentingNewLine]{{beta, gamma, muexi, 
              sigmaxi, sigmazeta}, \[IndentingNewLine]{lambdaeta, lambdaxi, 
              sigmaepsilon, sigmadelta}} = 
          System[Theta, ThetaFix]; \[IndentingNewLine]{p, q} = 
          Dimensions[gamma]; \[IndentingNewLine]B1 = 
          IdentityMatrix[p] - beta; \[IndentingNewLine]sigmaxi = 
          symmetric[sigmaxi]; \[IndentingNewLine]XI = 
          RandomGauss[muexi, sigmaxi, n, 
            Generator]; \[IndentingNewLine]sigmazeta = 
          symmetric[sigmazeta]; \[IndentingNewLine]ZETA = 
          RandomGauss[Shape[0, {p}], sigmazeta, n, 
            Generator]; \[IndentingNewLine]ETA = \((XI . Transpose[gamma] + 
                ZETA)\) . 
            Transpose[Inverse[B1]]; \[IndentingNewLine]sigmaepsilon = 
          symmetric[sigmaepsilon]; \[IndentingNewLine]kp = 
          Length[lambdaeta]; \[IndentingNewLine]EPSILON = 
          RandomGauss[Shape[0, {kp}], sigmaepsilon, n, 
            Generator]; \[IndentingNewLine]sigmadelta = 
          symmetric[sigmadelta]; \[IndentingNewLine]kq = 
          Length[lambdaxi]; \[IndentingNewLine]DELTA = 
          RandomGauss[Shape[0, {kq}], sigmadelta, n, 
            Generator]; \[IndentingNewLine]Y = 
          ETA . Transpose[lambdaeta] + EPSILON; \[IndentingNewLine]X = 
          XI . Transpose[lambdaxi] + DELTA; \[IndentingNewLine]{{Y, X, ETA, 
            XI}, {ZETA, EPSILON, 
            DELTA}, {{beta, gamma, muexi, sigmaxi, sigmazeta}, {lambdaeta, 
              lambdaxi, sigmaepsilon, 
              sigmadelta}}}\[IndentingNewLine]]\)}], "Input",
  CellLabel->"In[155]:=",
  PageWidth->Infinity,
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],

Cell[BoxData[{
    \(Clear[LISRELlik]\), "\n", 
    \(LISRELlik[{S_, m_, n_}, 
        Theta_, {System_, ThetaFix_}, {Singular_, 
          const_ : 
            2\ \[Pi]}] := \[IndentingNewLine]\[IndentingNewLine]Block[{p, q, 
          gamma, beta, B1, muexi, sigmaxi, sigmazeta, sigmaepsilon, 
          lambdaeta, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ kp, sigmadelta, 
          lambdaxi, kq, B11, B11gamma, sigmaetaxi, sigmaeta, 
          sigmayx, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ sigmaxy, sigmax, 
          sigmay, mueeta, muey, muex, SigmaYX, mueYX, 
          l}, \[IndentingNewLine]\[IndentingNewLine]{{beta, gamma, muexi, 
              sigmaxi, sigmazeta}, \[IndentingNewLine]{lambdaeta, lambdaxi, 
              sigmaepsilon, sigmadelta}} = 
          System[Theta, ThetaFix]; \[IndentingNewLine]\[IndentingNewLine]{p, 
            q} = Dimensions[gamma]; \[IndentingNewLine]B1 = 
          IdentityMatrix[p] - beta; \ \ \[IndentingNewLine]kp = 
          Length[lambdaeta]; \[IndentingNewLine]kq = 
          Length[lambdaxi]; \[IndentingNewLine]B11 = 
          Inverse[B1]; \[IndentingNewLine]B11gamma = 
          B11 . gamma; \ \ \[IndentingNewLine]sigmaetaxi = 
          B11gamma . sigmaxi; \[IndentingNewLine]sigmaeta = 
          B11gamma . sigmaxi . Transpose[B11gamma] + 
            B11 . sigmazeta . Transpose[B11]; \[IndentingNewLine]sigmayx = 
          lambdaeta . sigmaetaxi . 
            Transpose[lambdaxi]; \[IndentingNewLine]sigmaxy = 
          Transpose[sigmayx]; \[IndentingNewLine]sigmax = 
          lambdaxi . sigmaxi . Transpose[lambdaxi] + 
            sigmadelta; \ \[IndentingNewLine]sigmay = 
          lambdaeta . sigmaeta . Transpose[lambdaeta] + 
            sigmaepsilon; \ \[IndentingNewLine]mueeta = 
          B11gamma . muexi; \ \[IndentingNewLine]muey = 
          lambdaeta . mueeta; \[IndentingNewLine]muex = 
          lambdaxi . muexi; \[IndentingNewLine]SigmaYX = 
          vv[ii[sigmay, sigmayx], 
            ii[sigmaxy, sigmax]]; \ \ \[IndentingNewLine]mueYX = 
          Flatten[{muey, 
              muex}]; \[IndentingNewLine]If[\(! Singular\), \
\[IndentingNewLine]l = \(-\(1\/2\)\)\ n\ \((\((kp + kq)\)\ Log[const] + 
                  Log[Det[SigmaYX]] + 
                  Tr[Inverse[
                        SigmaYX] . \((S + 
                          Outer[Times, m - mueYX, 
                            m - mueYX])\)])\), \[IndentingNewLine]\
\[IndentingNewLine]eig = Eigenvalues[SigmaYX]; 
          eig = Select[
              eig, #1 > 
                  0 &]; \[IndentingNewLine]l = \(-\(1\/2\)\)\ n\ \((Plus @@ 
                    Log[const\ eig] + 
                  Tr[PseudoInverse[
                        SigmaYX] . \((S + 
                          Outer[Times, m - mueYX, 
                            m - mueYX])\)])\)]\[IndentingNewLine]]\)}], \
"Input",
  CellLabel->"In[157]:=",
  PageWidth->Infinity,
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}]
}, Closed]],

Cell[CellGroupData[{

Cell["Implementierung / deterministische Regressoren", "Section",
  PageWidth->Infinity,
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontVariations->{"CompatibilityType"->0}],

Cell[BoxData[
    \(LISRELsimul[{n_, Generator_, X_}, Theta_, {System_, ThetaFix_}, 
        comp_ : True] := \[IndentingNewLine]\[IndentingNewLine]Block[{p, q, 
          beta, gamma, B1, sigmazeta, ZETA, ETA, sigmaepsilon, lambdaeta, kp, 
          EPSILON, kq, 
          Y}, \[IndentingNewLine]\[IndentingNewLine]{{beta, gamma, 
              sigmazeta}, {lambdaeta, taueta, sigmaepsilon}} = 
          System[Theta, ThetaFix]; \[IndentingNewLine]{p, q} = 
          Dimensions[gamma]; \[IndentingNewLine]B1 = 
          IdentityMatrix[p] - beta; \[IndentingNewLine]If[comp, 
          RandomGauss[Shape[0, q], IdentityMatrix[q], n, 
            Generator]]; \[IndentingNewLine]sigmazeta = 
          symmetric[sigmazeta]; \[IndentingNewLine]ZETA = 
          RandomGauss[Shape[0, {p}], sigmazeta, n, 
            Generator]; \[IndentingNewLine]ETA = \((X . Transpose[gamma] + 
                ZETA)\) . 
            Transpose[Inverse[B1]]; \[IndentingNewLine]sigmaepsilon = 
          symmetric[sigmaepsilon]; \[IndentingNewLine]kp = 
          Length[lambdaeta]; \[IndentingNewLine]EPSILON = 
          RandomGauss[Shape[0, {kp}], sigmaepsilon, n, 
            Generator]; \[IndentingNewLine]Y = 
          ETA . Transpose[lambdaeta] + X . Transpose[taueta] + 
            EPSILON; \[IndentingNewLine]{{Y, X, ETA}, {ZETA, 
            EPSILON}, {{beta, gamma, sigmazeta}, {lambdaeta, taueta, 
              sigmaepsilon}}}\[IndentingNewLine]]\)], "Input",
  CellLabel->"In[159]:=",
  PageWidth->Infinity,
  CellMargins->{{19.625, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{2319, Inherited},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],

Cell[BoxData[
    \(LISRELlik[{S_, m_, n_, Deterministisch_}, 
        Theta_, {System_, ThetaFix_}, {Singular_, 
          const_ : 
            2\ \[Pi]}] := \[IndentingNewLine]\[IndentingNewLine]Block[{p, q, 
          gamma, beta, B1, sigmazeta, sigmaepsilon, lambdaeta, kp, 
          kq, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ B11, sigmaeta, sigmay, 
          M, My, Mx, Myx, MyxCs, CMxy, l, C, Cs, 
          eig}, \[IndentingNewLine]\[IndentingNewLine]{{beta, gamma, 
              sigmazeta}, {lambdaeta, taueta, sigmaepsilon}} = 
          System[Theta, ThetaFix]; \[IndentingNewLine]{p, q} = 
          Dimensions[gamma]; \ \ \[IndentingNewLine]B1 = 
          IdentityMatrix[p] - beta; \ \ \[IndentingNewLine]kp = 
          Length[lambdaeta]; \[IndentingNewLine]kq = 
          q; \[IndentingNewLine]B11 = 
          Inverse[B1]; \ \[IndentingNewLine]sigmaeta = 
          B11 . sigmazeta . 
            Transpose[B11]; \ \ \ \ \[IndentingNewLine]sigmay = 
          lambdaeta . sigmaeta . Transpose[lambdaeta] + 
            sigmaepsilon; \ \[IndentingNewLine]M = 
          S + Outer[Times, m, m]; \ \ \[IndentingNewLine]My = 
          M\[LeftDoubleBracket]Range[kp], 
            Range[kp]\[RightDoubleBracket]; \[IndentingNewLine]Mx = 
          M\[LeftDoubleBracket]Range[kp + 1, kp + kq], 
            Range[kp + 1, 
              kp + kq]\[RightDoubleBracket]; \[IndentingNewLine]Myx = 
          M\[LeftDoubleBracket]Range[kp], 
            Range[kp + 1, 
              kp + kq]\[RightDoubleBracket]; \[IndentingNewLine]C = 
          lambdaeta . B11 . gamma + taueta; \[IndentingNewLine]Cs = 
          Transpose[C]; \[IndentingNewLine]MyxCs = 
          Myx . Cs; \[IndentingNewLine]CMxy = 
          Transpose[
            MyxCs]; \ \ \[IndentingNewLine]If[\(! Singular\), \
\[IndentingNewLine]\[IndentingNewLine]l = \(-\(1\/2\)\)\ n\ \((kp\ Log[
                      const] + Log[Det[sigmay]] + 
                  Tr[Inverse[
                        sigmay] . \((My + C . Mx . Cs - MyxCs - 
                          CMxy)\)])\), \
\[IndentingNewLine]\[IndentingNewLine]eig = 
            Eigenvalues[sigmay]; \[IndentingNewLine]eig = 
            Select[eig, #1 > 
                  0 &]; \[IndentingNewLine]l = \(-\(1\/2\)\)\ n\ \((Plus @@ 
                    Log[const\ eig] + 
                  Tr[PseudoInverse[
                        sigmay] . \((My + C . Mx . Cs - MyxCs - 
                          CMxy)\)])\)]\[IndentingNewLine]]\)], "Input",
  CellLabel->"In[160]:=",
  PageWidth->Infinity,
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],

Cell[BoxData[{
    \(NormalCorrelation // Clear\), "\[IndentingNewLine]", 
    \(NormalCorrelation[{Y_, X_, miss_: - 9}, {Theta_, COV_}, {System_, 
          ThetaFix_}, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ {print_:  False, labely_:  None, 
          labeleta_:  None, 
          labelx_:  None}] := \[IndentingNewLine]\[IndentingNewLine]Block[{p, 
          q, beta, gamma, sigmazeta, lambdaeta, taueta, 
          sigmaepsilon, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ B1, B11, 
          sigmaeta, sl, sigmaY, C, Cs, mueetay, sigmaetaysel, sel, seln, 
          lambdaetan, inno, gain, n, 
          nn}, \[IndentingNewLine]\[IndentingNewLine]{{beta, gamma, 
              sigmazeta}, {lambdaeta, taueta, sigmaepsilon}} = 
          System[Theta, ThetaFix]; \[IndentingNewLine]{p, q} = 
          Dimensions[gamma]; \[IndentingNewLine]B1 = 
          IdentityMatrix[p] - beta; \[IndentingNewLine]B11 = 
          Inverse[B1]; \ \[IndentingNewLine]sigmazeta = 
          symmetric[sigmazeta]; \[IndentingNewLine]mueeta = 
          X . Transpose[gamma] . 
            Transpose[B11]; \[IndentingNewLine]sigmaeta = 
          B11 . sigmazeta . Transpose[B11]; \[IndentingNewLine]sigmaepsilon = 
          symmetric[sigmaepsilon]; \[IndentingNewLine]\[IndentingNewLine]C = 
          lambdaeta . B11 . gamma + taueta; \[IndentingNewLine]Cs = 
          Transpose[C]; \[IndentingNewLine]mueY = 
          X . Cs; \[IndentingNewLine]\[IndentingNewLine]sel\  = 
          Map[NotPosition[#, miss] &, Y]; \[IndentingNewLine]nn = 
          Y // Length; \[IndentingNewLine]\[IndentingNewLine]{mueetay, 
            sigmaetay} = \[IndentingNewLine]\[IndentingNewLine]Table[\
\[IndentingNewLine]\[IndentingNewLine]seln = 
                sel[\([n]\)]; \[IndentingNewLine]lambdaetan = 
                lambdaeta[\([seln, All]\)]; \n\ \ \ \ \ \ \ \ \ \ \ inno = 
                Y[\([n, seln]\)] - 
                  mueY[\([n, seln]\)]; \[IndentingNewLine]sl = \ 
                sigmaeta . \((lambdaetan // 
                      Transpose)\); \[IndentingNewLine]sigmaY = 
                lambdaetan . sl + 
                  sigmaepsilon[\([seln, 
                      seln]\)]; \[IndentingNewLine]gain = \ \ sl . 
                  Inverse[sigmaY]; \[IndentingNewLine]{\ 
                mueeta[\([n]\)]\  + \ 
                  gain . inno, \((IdentityMatrix[p] - gain . lambdaetan)\) . 
                  sigmaeta}, \[IndentingNewLine]{n, nn}] // 
            Transpose; \[IndentingNewLine]\[IndentingNewLine]If[
          print, \[IndentingNewLine]\[IndentingNewLine]\ \ \(beta // 
              MatrixForm[#, 
                  TableHeadings \[Rule] {labeleta, 
                      labeleta}] &\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  // 
            Print["\<beta              \>", #] &; \[IndentingNewLine]\ \ \
\(gamma // MatrixForm[#, 
                  TableHeadings \[Rule] {labeleta, 
                      labelx}] &\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  // 
            Print["\<gamma             \>", #] &; \[IndentingNewLine]\ \ \
\(sigmazeta // MatrixForm[#, 
                  TableHeadings \[Rule] {labeleta, 
                      labeleta}] &\)\ \ \ \ \ \ \  // 
            Print["\<sigmazeta         \>", #] &; \[IndentingNewLine]\ \ \
\(lambdaeta // MatrixForm[#, 
                  TableHeadings \[Rule] {labely, 
                      labeleta}] &\)\ \ \ \ \ \ \ \ \ \ \ \  // 
            Print["\<lambdaeta         \>", #] &; \[IndentingNewLine]\ \ \
\(taueta // MatrixForm[#, 
                  TableHeadings \[Rule] {labely, 
                      labeleta}] &\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  // 
            Print["\<taueta            \>", #] &; \[IndentingNewLine]\ \ \
\(sigmaepsilon // 
              MatrixForm[#, TableHeadings \[Rule] {labeleta, labeleta}] &\) // 
            Print["\<sigmaepsilon      \>", #] &; \[IndentingNewLine]\
\[IndentingNewLine]\ \(mueeta[\([1]\)] // 
              MatrixForm[#, 
                  TableHeadings \[Rule] {labeleta, 
                      None}] &\)\ \ \ \ \ \ \ \ \ \ \  // 
            Print["\<mueeta[[1]]       \>", #] &; \[IndentingNewLine]\ \ \
\(sigmaeta // MatrixForm[#, 
                  TableHeadings \[Rule] {labeleta, 
                      labeleta}] &\)\ \ \ \ \ \ \ \ \  // 
            Print["\<sigmaeta          \>", #] &; \[IndentingNewLine]\ \ \(\(\
\(sigmaeta // Sigma2Corr\) // First\) // 
              MatrixForm[#, 
                  TableHeadings \[Rule] {labeleta, 
                      labeleta}] &\)\ \[IndentingNewLine]\t\t\t\t\t\t\t\t\t\t\
\t\t\t\t\t\t\ \ \  // 
            Print["\<corr(eta)         \>", #] &; \[IndentingNewLine]\(1 - 
                VecDiag[sigmazeta]/VecDiag[sigmaeta] // 
              MatrixForm[#, 
                  TableHeadings \[Rule] {labeleta, 
                      None}] &\)\ \[IndentingNewLine]\t\t\t\t // 
            Print["\<Squared Multiple Correlations for Structural Equations: \
1-sigmazeta/sigmaeta=1-MQR/MQT\n                  \>", #] &; \
\[IndentingNewLine]\[IndentingNewLine]\(1 - Det[sigmazeta]/Det[sigmaeta] // 
              MatrixForm[#, 
                  TableHeadings \[Rule] {labeleta, 
                      None}] &\)\ \[IndentingNewLine]\t\t\t\t // 
            Print["\<Total Coefficient of Determination for Structural \
Equations: 1-|sigmazeta|/|sigmaeta| = \>", #] &; \[IndentingNewLine]\
\[IndentingNewLine]Print["\<\nAsymptotic Standard Errors (Delta Theorem)\>"]; \
\[IndentingNewLine]\[IndentingNewLine]t // Clear; \[IndentingNewLine]th = 
            Array[t, 
              u = Theta // Length]; \[IndentingNewLine]{{beta, gamma, 
                sigmazeta}, {lambdaeta, taueta, sigmaepsilon}} = 
            System[th, ThetaFix]; \n\[IndentingNewLine]\ \ \ \ \ Dbeta = 
            Outer[D, beta // Flatten, 
              th]; \[IndentingNewLine]\ \(Shape[
                Sqrt@VecDiag[Dbeta . COV . \((Dbeta // Transpose)\)], 
                beta // 
                  Dimensions]\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \  // MatrixForm[#, TableHeadings \[Rule] {labeleta, labeleta}] &\) // 
            Print["\<std(beta)         \>", #] &; \[IndentingNewLine]\
\[IndentingNewLine]Dgamma = 
            Outer[D, gamma // Flatten, 
              th]; \[IndentingNewLine]\ \(Shape[
                Sqrt@VecDiag[Dgamma . COV . \((Dgamma // Transpose)\)], 
                gamma // 
                  Dimensions]\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \  // MatrixForm[#, TableHeadings \[Rule] {labeleta, labelx}] &\) // 
            Print["\<std(gamma)        \>", #] &; \[IndentingNewLine]\
\[IndentingNewLine]Dsigmazeta = 
            Outer[D, sigmazeta // Flatten, 
              th]; \[IndentingNewLine]\ \(Shape[
                Sqrt@VecDiag[
                    Dsigmazeta . COV . \((Dsigmazeta // Transpose)\)], 
                sigmazeta // 
                  Dimensions]\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \  // MatrixForm[#, TableHeadings \[Rule] {labeleta, labeleta}] &\) // 
            Print["\<std(sigmazeta)    \>", #] &; \[IndentingNewLine]\
\[IndentingNewLine]\[IndentingNewLine]Dlambdaeta = 
            Outer[D, lambdaeta // Flatten, 
              th]; \[IndentingNewLine]\ \(Shape[
                Sqrt@VecDiag[
                    Dlambdaeta . COV . \((Dlambdaeta // Transpose)\)], 
                lambdaeta // 
                  Dimensions]\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \  // MatrixForm[#, TableHeadings \[Rule] {labely, labeleta}] &\) // 
            Print["\<std(lambdaeta)    \>", #] &; \[IndentingNewLine]\
\[IndentingNewLine]Dtaueta = 
            Outer[D, taueta // Flatten, 
              th]; \[IndentingNewLine]\ \(Shape[
                Sqrt@VecDiag[Dtaueta . COV . \((Dtaueta // Transpose)\)], 
                taueta // 
                  Dimensions]\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \  // MatrixForm[#, TableHeadings \[Rule] {labely, labeleta}] &\) // 
            Print["\<std(taueta)       \>", #] &; \[IndentingNewLine]\
\[IndentingNewLine]Dsigmaepsilon = 
            Outer[D, sigmaepsilon // Flatten, 
              th]; \[IndentingNewLine]\ \(Shape[
                Sqrt@VecDiag[
                    Dsigmaepsilon . COV . \((Dsigmaepsilon // Transpose)\)], 
                sigmaepsilon // 
                  Dimensions]\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \  // MatrixForm[#, TableHeadings \[Rule] {labeleta, labeleta}] &\) // 
            Print["\<std(sigmaepsilon) \>", #] &;\[IndentingNewLine]\
\[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine]\ ]; \
\[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine]{{mueetay, 
            sigmaetay}, {mueeta, sigmaeta}, {mueY, 
            sigmaY}}\[IndentingNewLine]]\)}], "Input",
  CellLabel->"In[438]:=",
  PageWidth->Infinity,
  CellMargins->{{19.625, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{2319, Inherited},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],

Cell[BoxData[{
    \(IndividualLik // Clear\), "\[IndentingNewLine]", 
    \(IndividualLik[{Y_, X_, miss_}, 
        Theta_, {System_, ThetaFix_}, {Singular_, const_ : 2\ \[Pi]\ , 
          option_:  0}] := \[IndentingNewLine]\[IndentingNewLine]Block[{p, q, 
          gamma, beta, B1, sigmazeta, sigmaepsilon, lambdaeta, kp, 
          kq, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ B11, sigmaeta, sigmay, 
          lik, C, n, yn, ymiss, sel, muesel, sigmaysel, Csel, nue, 
          eig}, \[IndentingNewLine]\[IndentingNewLine]{{beta, gamma, 
              sigmazeta}, {lambdaeta, taueta, sigmaepsilon}} = 
          System[Theta, ThetaFix]; \[IndentingNewLine]{p, q} = 
          Dimensions[gamma]; \ \ \[IndentingNewLine]B1 = 
          IdentityMatrix[p] - beta; \ \ \[IndentingNewLine]kp = 
          Length[lambdaeta]; \[IndentingNewLine]kq = 
          q; \[IndentingNewLine]B11 = 
          Inverse[B1]; \ \[IndentingNewLine]sigmaeta = 
          B11 . sigmazeta . 
            Transpose[B11]; \ \ \ \ \[IndentingNewLine]sigmay = 
          lambdaeta . sigmaeta . Transpose[lambdaeta] + 
            sigmaepsilon; \ \[IndentingNewLine]C = 
          lambdaeta . B11 . gamma + 
            taueta; \[IndentingNewLine]\[IndentingNewLine]n = 
          Y // Length; \ \[IndentingNewLine]lik = {}; \[IndentingNewLine]\
\[IndentingNewLine]Do[\ \ \ yn = 
            Y[\([nn]\)]; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ ymiss = 
            Map[SameQ[miss, #] &, yn]; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ sel = 
            Locate[ymiss, 
              False]; \[IndentingNewLine]\[IndentingNewLine]\ \ \ \ \ \ \  \
(*\(sel // Print;\)*) \n\[IndentingNewLine]\ \ \ \ \ \ If[sel \[Equal] {}, 
            l = 0,  (*keine\ Messung*) \[IndentingNewLine]\[IndentingNewLine]\
\ \ \  (*else*) \[IndentingNewLine]\[IndentingNewLine]\t\ sigmaysel = 
              sigmay[\([sel, sel]\)]; \[IndentingNewLine]\t\ Csel = 
              C[\([sel]\)]; \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ muesel = 
              Csel . X[\([nn]\)]; \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ nue \
= yn[\([sel]\)] - \ 
                muesel; \[IndentingNewLine]\[IndentingNewLine]\ \ \ \ \ \ \ \ \
\ If[\(! Singular\), \ \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ l = \(-\
\(1\/2\)\)\ \((Log[Det[const\ sigmaysel]] + 
                      nue . Inverse[sigmaysel] . 
                        nue)\), \[IndentingNewLine]\[IndentingNewLine]\ \ \ \ \
\ \ \ \ \ \ \  (*else*) \[IndentingNewLine]\[IndentingNewLine]\ \ \ \ \ \ \ \ \
\ \ \ \ \ \ eig = 
                Eigenvalues[
                  sigmay]; \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ eig \
= Select[eig, #1 > 
                      0 &]; \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ l = \
\(-\(1\/2\)\)\ \((Plus @@ Log[const\ eig] + 
                      nue . PseudoInverse[sigmaysel] . 
                        nue)\)\[IndentingNewLine]\ \ \ \ \ \ \ \ \ ];\
\[IndentingNewLine]\ \ \ \ \ \ ]; \[IndentingNewLine]\[IndentingNewLine]\ \ \ \
\ \ \ \ lik = Append[lik, l];\[IndentingNewLine], {nn, 
            n}]; \[IndentingNewLine]\[IndentingNewLine]If[
          option \[Equal] 5, {Plus @@ lik, lik}, 
          Plus @@ lik]\[IndentingNewLine]\[IndentingNewLine]]\)}], "Input",
  CellLabel->"In[149]:=",
  PageWidth->Infinity,
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Misc",
    FontWeight->"Bold"],
  ""
}], "Section",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain"],

Cell[BoxData[
    \(\(symmetric[A_] :=  .5\ \((A + Transpose[A])\);\)\)], "Input",
  CellLabel->"In[161]:=",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain"],

Cell[BoxData[
    StyleBox[\(SymmetricMatrix[vec_, p_, opt_: "\<obere\>"] := 
        Module[{n, A}, \n\tn = 0; \n\t
          A = Shape[0, {p, p}]; \n\ \ \ \ If[
            opt == "\<obere\>", \n\ \ \ \ \ \ \ \ Do[\(A[\([i, 
                      j]\)] = \ \(A[\([j, i]\)] = 
                    vec[\([n += 1]\)]\);\)\ , {i, p}, {j, i, 
                p}], \n\ \ \ \ \ \ \ \ Do[\(A[\([i, 
                      j]\)] = \ \(A[\([j, i]\)] = 
                    vec[\([n += 1]\)]\);\)\ , {i, p}, {j, 1, 
                i}]\n\ \ \ \ \ \ \ \ ]; \n\ \ \ \ A\n\ \ \ \ ]\),
      FontWeight->"Plain",
      FontVariations->{"CompatibilityType"->0}]], "Input",
  CellLabel->"In[398]:=",
  CellMargins->{{19.8125, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[{
    \(\(Unprotect[RandomGauss];\)\), "\n", 
    \(\(Clear[RandomGauss];\)\), "\n", 
    \(RandomGauss[X_, Theta_, {mue_, sigma_}, n_?IntegerQ, 
        Generator_ : Gauss] := 
      Module[{m, s, s2}, m = mue[X, Theta]; s = sigma[X, Theta]; 
        s2 = CholeskyDecomposition[
            s]; \((m + #1 &)\) /@ \((Table[Generator[], {n}, {Length[m]}] . 
              s2)\)]\), "\n", 
    \(RandomGauss[mue_, sigma_, n_?IntegerQ, Generator_ : Gauss] := 
      Module[{s2}, 
        s2 = CholeskyDecomposition[
            sigma]; \((mue + #1 &)\) /@ \((Table[
                Generator[], {n}, {Length[mue]}] . s2)\)]\), "\n", 
    \(\(Gauss[] := Plus @@ Table[Random[], {i, 12}] - 6.0;\)\), "\n", 
    \(\(symmetric[A_] :=  .5\ \((A + Transpose[A])\);\)\)}], "Input",
  CellLabel->"In[162]:=",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain"],

Cell[BoxData[
    \(max[x__] := Max[x]; SetAttributes[max, Listable];\)], "Input",
  CellLabel->"In[168]:=",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain"],

Cell[BoxData[
    \(GRIDIJ[PSI_, i_, J_, HI_, HJ_] := 
      Module[{OUT}, OUT = PSI; 
        OUT\[LeftDoubleBracket]i\[RightDoubleBracket] = 
          OUT\[LeftDoubleBracket]i\[RightDoubleBracket] + 
            HI\[LeftDoubleBracket]i\[RightDoubleBracket]; 
        OUT\[LeftDoubleBracket]J\[RightDoubleBracket] = 
          OUT\[LeftDoubleBracket]J\[RightDoubleBracket] + 
            HJ\[LeftDoubleBracket]J\[RightDoubleBracket]; OUT]\)], "Input",
  CellLabel->"In[169]:=",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{4, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain"],

Cell[BoxData[
    \(GRIDI[PSI_, i_, HI_] := 
      Module[{OUT}, OUT = PSI; 
        OUT\[LeftDoubleBracket]i\[RightDoubleBracket] = 
          OUT\[LeftDoubleBracket]i\[RightDoubleBracket] + 
            HI\[LeftDoubleBracket]i\[RightDoubleBracket]; OUT]\)], "Input",
  CellLabel->"In[170]:=",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{4, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain"],

Cell[BoxData[{
    \(Clear[SubDiagonalMatrix]\), "\n", 
    \(SubDiagonalMatrix[astern_, {T_, p_}] := 
      Module[{beta, null = Shape[0, {p, p}]}, beta = IdentityMatrix[T]; 
        beta = RotateLeft[beta, \(-1\)]; 
        beta\[LeftDoubleBracket]1, T\[RightDoubleBracket] = 0; 
        beta = beta /. \[InvisibleSpace]{1 \[Rule] astern, 0 \[Rule] null}; 
        beta = BlockMatrix[beta]]\)}], "Input",
  CellLabel->"In[171]:=",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain"],

Cell[BoxData[{
    \(DoUntil[range_, cond_, body_] := 
      Module[{}, Do[body; If[cond, Break[]], range]]\), "\n", 
    \(\(Attributes[DoUntil] = HoldAll;\)\)}], "Input",
  CellLabel->"In[173]:=",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain"],

Cell[BoxData[{
    \(DoWhile[range_, cond_, body_] := 
      Module[{}, Do[If[\(! cond\), Break[]]; body, range]]\), "\n", 
    \(\(Attributes[DoWhile] = HoldAll;\)\)}], "Input",
  CellLabel->"In[175]:=",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain"],

Cell[BoxData[
    \(VecPrint[veclist_, label_] := 
      Print[TableForm[Transpose[veclist], 
          TableHeadings \[Rule] {Automatic, label}, 
          TableDirections \[Rule] {Column, Row}, 
          TableSpacing \[Rule] {0, 2}]]\)], "Input",
  CellLabel->"In[177]:=",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain"],

Cell[BoxData[
    \(KroneckerProduct[a_, b_] := 
      Module[{ab, i, j, k, l}, 
        ab = Outer[Times, a, b]; {i, j, k, l} = Dimensions[ab]; 
        ab = Flatten[Transpose[ab, {1, 3, 2, 4}]]; 
        Partition[ab, j\ l]]\)], "Input",
  CellLabel->"In[178]:=",
  CellMargins->{{19.625, 29}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{73, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],

Cell[BoxData[
    \(Shape[A_, p_] := 
      Module[{pp, prod, a}, a = A; If[Length[a] == 0, Return[Array[a &, p]]]; 
        If[Length[p] == 1, Return[Flatten[a]], 
          If[Length[p] == 2, 
            Return[Take[
                Partition[Flatten[a], 
                  p\[LeftDoubleBracket]2\[RightDoubleBracket]], 
                p\[LeftDoubleBracket]1\[RightDoubleBracket]]], 
            pp = Drop[p, 1]; prod = Times @@ pp; 
            a = Partition[Flatten[a], prod]; \((Shape[#1, pp] &)\) /@ 
              a]]]\)], "Input",
  CellLabel->"In[179]:=",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],

Cell[BoxData[
    \(Spalte[x_] := Shape[x, {Length[x], 1}]\)], "Input",
  CellLabel->"In[180]:=",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],

Cell[BoxData[{
    \(BlockDiagonalMatrix[{a_List, b_List}] := 
      Module[{a1, a2, null1, null2}, {a1, a2} = Dimensions[a]; {b1, b2} = 
          Dimensions[b]; null1 = Shape[0, {a1, b2}]; 
        null2 = Shape[0, {b1, a2}]; 
        BlockMatrix[{{a, null1}, {null2, b}}]]\), "\n", 
    \(BlockDiagonalMatrix[x_List] := 
      Module[{hilf}, hilf = BlockDiagonalMatrix[Drop[x, \(-1\)]]; 
        BlockDiagonalMatrix[{hilf, Last[x]}]]\)}], "Input",
  CellLabel->"In[181]:=",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],

Cell[BoxData[{
    \(\(all[A_] := And @@ Flatten[A];\)\), "\n", 
    \(gr[x_, y_] := x > y; SetAttributes[gr, Listable];\), "\n", 
    \(\(ii = AppendRows;\)\), "\n", 
    \(\(vv\  = \ AppendColumns;\)\), "\[IndentingNewLine]", 
    \(\(VecDiag = Transpose[#1, {1, 1}] &;\)\)}], "Input",
  CellLabel->"In[183]:=",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],

Cell[BoxData[{
    \(Varianz[y_] := 
      Module[{yy, n, SML, S, means}, 
        If[TensorRank[y] === 1, yy = Spalte[y], yy = y]; 
        n = First[Dimensions[yy]]; means = mean[yy]; 
        SML = Transpose[yy] . yy\/n - Outer[Times, means, means]; 
        S = \(n\ SML\)\/\(n - 1\); {SML, S, means}]\), "\n", 
    \(\(mean[y_] := Plus @@ y\/First[Dimensions[y]];\)\)}], "Input",
  CellLabel->"In[188]:=",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],

Cell[BoxData[{\(AddTimeAxis[X_, dt_:  1.0] := 
      Module[{T}, 
        T = Length[X]; \[IndentingNewLine]AppendRows[
          Shape[dt\ Range[0, T - 1], {T, 1}], X]]\), "\n", 
    RowBox[{\(AddTimeAxis[X_, {t0_, t1_, dt_}] := 
        AppendRows[Spalte[Range[t0, t1, dt]], X]\), "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(nnn = 200;\), "\n"}], "\[IndentingNewLine]", 
    RowBox[{\(Options[plot1] = {PlotJoined \[Rule] True, Frame \[Rule] True, 
            Axes \[Rule] False, dicke \[Rule]  .01, gestrichelt \[Rule] 1, 
            color \[Rule] Range[nnn], 
            DisplayFunction \[Rule] $DisplayFunction, 
            farbmodell \[Rule] eigene, 
            text \[Rule] Array[\(("\< \>")\) &, nnn], 
            TEXTSHIFT \[Rule] Array[{0, 0} &, nnn], 
            permute \[Rule] Range[nnn]};\), 
      StyleBox["\n",
        FontColor->RGBColor[1, 0, 0]], "\n"}], "\n", 
    StyleBox[\(plot1 // Clear\),
      FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["plot1",
            FontColor->RGBColor[1, 0, 0]], "[", \(Data_List, opts___Rule\), 
          "]"}], ":=", \(Module[{d, d1, dash, Datai, i, ii, gi, g, f, join1, 
            dicke1, frame1, axes1, gestrichelt1, color1, epilog1, 
            aspectratio1, optionen, display1, farbe1, text1, textcoords, 
            textshift}, {join1, dicke1, frame1, axes1, gestrichelt1, color1, 
              display1, farbe1, text1, textshift, 
              permute1} = \({PlotJoined, dicke, Frame, Axes, gestrichelt, 
                  color, DisplayFunction, farbmodell, text, TEXTSHIFT, 
                  permute} /. {opts}\) /. 
              Options[plot1]; \[IndentingNewLine]If[
            TensorRank[dicke1] \[Equal] 0, 
            dicke1 = Array[dicke1 &, nnn]]; \[IndentingNewLine]If[
            TensorRank[gestrichelt1] \[Equal] 0, 
            gestrichelt1 = Array[gestrichelt1 &, nnn]]; \[IndentingNewLine]If[
            TensorRank[color1] \[Equal] 0, 
            color1 = 
              Array[color1 &, 
                nnn]]; \[IndentingNewLine] \
(*\(Print["\<Optionen:{dicke,gestrichelt,color,epilog}\>"];\)*)  \
(*\(Print[{join1, dicke1, gestrichelt1, color1, epilog1, 
                  aspectratio1}];\)*)  (*\(gestrichelt1 // 
                Print;\)*) \[IndentingNewLine]\[IndentingNewLine]Farben = \
{RGBColor[ .1,  .1,  .9], RGBColor[ .1,  .9,  .8], 
              RGBColor[0.875, 0.202, 0.515], RGBColor[ .4,  .3,  .6], 
              RGBColor[ .9,  .3,  .4], RGBColor[ .9,  .0,  .2], 
              RGBColor[ .4,  .0,  .9], RGBColor[ .6,  .9,  .4], 
              RGBColor[ .6,  .1,  .4], 
              RGBColor[ .0,  .0,  .0]}; \[IndentingNewLine] \
(*\[IndentingNewLine]\(Farben = {Blue, SpringGreenMedium, Red, Yellow, 
                  BlueViolet, CadmiumOrange, Magenta, TurquoiseDark, 
                  VioletRedPale, 
                  Black};\)\[IndentingNewLine]*) \[IndentingNewLine]\
\[IndentingNewLine]If[farbe1 === eigene, Farben, 
            If[farbe1 === Hue, 
              Farben = Map[Hue, Range[ .1, 1,  .1] // Reverse], 
              If[farbe1 === GrayLevel, 
                Farben = Map[GrayLevel, Range[0,  .9,  .1]], 
                Farben = farbe1]]]; \[IndentingNewLine]f = 
            Length[Farben]; \[IndentingNewLine]color1 = 
            Mod[color1 - 1, f] + 1;  (*nur\ zul\[ADoubleDot]ssige\ Farben*) 
            dash = Map[
              Dashing,  .01 {{}, {1, 1}, {2, 4}, {1, 2}, {4, 4}, {4, 1}, {1, 
                    4}, {1, 3, 1}, { .8}, {5, 2}}]; \[IndentingNewLine]f = 
            Length[dash]; \[IndentingNewLine]gestrichelt1 = 
            Mod[gestrichelt1 - 1, f] + 
              1;  (*nur\ zul\[ADoubleDot]ssige\ Muster*) d = 
            Dimensions[
              Data]; \[IndentingNewLine] (*\(Print["\<Dimension der Daten  \
\>", d];\)*) \[IndentingNewLine]If[
            Dimensions[d] \[Equal] {1},  (*Vektor*) g = 
              plot1[\(Data // Spalte\) // AddTimeAxis, opts]; 
            Return[g],  (*rekursiver\ Aufruf*)  (*else*) If[
              d[\([2]\)] === 1,  (*Spalten - Vektor*) g = 
                plot1[Data // AddTimeAxis, opts]; 
              Return[g],  (*rekursiver\ Aufruf*)  (*else*) d1 = 
                d[\([1]\)] // 
                  Range; \[IndentingNewLine]g = {}; \[IndentingNewLine]Do[
                Datai = 
                  Data[\([d1, {1, 
                        permute1[\([i - 1]\)] + 
                          1}]\)]; \[IndentingNewLine]ii = 
                  permute1[\([i - 1]\)]; \[IndentingNewLine]links = \((Datai // 
                      First)\); \[IndentingNewLine]rechts = \((Datai // 
                      Last)\); \[IndentingNewLine]mitte = 
                  Datai[\([d[\([1]\)]/2 // 
                        Floor]\)]; \[IndentingNewLine]If[\((text1 // Last)\) 
                    === "\<Links\>", textcoords = links, 
                  If[\((text1 // Last)\) === "\<Rechts\>", 
                    textcoords = rechts, 
                    If[\((text1 // Last)\) === "\<Mitte\>", 
                      textcoords = mitte, 
                      If[IntegerQ[\((text1 // Last)\)], 
                        textcoords = Datai[\([text1 // Last]\)], 
                        textcoords = 
                          rechts]]]]; \[IndentingNewLine]textcoords = 
                  textcoords + textshift[\([ii]\)]; \[IndentingNewLine]gi = 
                  ListPlot[Datai, DisplayFunction \[Rule] Identity, 
                    PlotJoined \[Rule] join1, Frame \[Rule] frame1, 
                    Axes \[Rule] axes1, 
                    PlotStyle \[Rule] {Farben[\([color1[\([ii]\)]]\)], 
                        PointSize[dicke1[\([ii]\)]], 
                        Thickness[dicke1[\([ii]\)]], 
                        dash[\([gestrichelt1[\([ii]\)]]\)], 
                        Text[text1[\([ii]\)], 
                          textcoords]}]; \[IndentingNewLine]g = 
                  Join[g, {gi}];, {i, 2, 
                  d[\([2]\)]}];]; \[IndentingNewLine]g = 
              Show[g, DisplayFunction \[Rule] display1, 
                FilterOptions[Graphics, opts]]; \[IndentingNewLine]Return[
              g];]]\)}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\( (*End\ of\ plot1*) \)}]}], "Input",
  CellLabel->"In[462]:=",
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain",
  CellTags->"plot1"],

Cell["\<\
connectdatasets//Clear
connectdatasets[X_,opts___]:=
Module[{g1,g2,arrow1},
arrow1=arrow/.{opts};
{t,n,p}=X//Dimensions;
nX=Join[{n//Range},X];
g1=MapThread[plot1[{##2},farbmodell->Hue,dicke->.03,opts,PlotJoined->False,
                   color->#1,DisplayFunction->Identity]&,nX];
g2=MapThread[plot1[{##2},farbmodell->Hue,opts,PlotJoined->True,       
                   color->#1,DisplayFunction->Identity]&,nX];
g3=If[arrow1, \
phaseplotarrowmultiple[X//Transpose,DisplayFunction->Identity],{},{}];

Show[g1,g2,g3,DisplayFunction->$DisplayFunction]

]\
\>", "Input",
  CellLabel->"In[172]:=",
  PageWidth->Infinity,
  CellMargins->{{19.875, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],

Cell[BoxData[{
    StyleBox[\(missings[z_, miss_, op_] := 
        Apply[op, Map[\((# === miss)\) &, z]]\),
      FontWeight->"Plain"], "\n", 
    StyleBox[\(CaseDel[Z_, miss_] := 
        Select[Z, Not[missings[#, miss, Or]] &]\),
      FontWeight->"Plain"]}], "Input",
  CellLabel->"In[62]:=",
  CellMargins->{{19.8125, Inherited}, {Inherited, Inherited}},
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Maximierung",
    FontWeight->"Bold"],
  ""
}], "Section",
  PageWidth->Infinity,
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain"],

Cell[BoxData[{
    \(\(RESAMPLING = True;\)\), "\n", 
    \(\(FDIGITS = Round[\(-Log[10, $MachineEpsilon]\)];\)\), "\n", 
    \(\(TYP = 1;\)\), "\n", 
    \(\(YMAX = 1000. ;\)\), "\n", 
    \(\(ANALGRAD = False;\)\), "\n", 
    \(\(FACTOR = 1.0;\)\), "\n", 
    \(\(MAXSTEP = 0.1;\)\), "\n", 
    \(\(CSEED = \(-999\);\)\), "\n", 
    \(\(SCALING = 1;\)\), "\n", 
    \(\(STEPREDUCE = 4;\)\), "\n", 
    \(\(FISHER = False;\)\), "\n", 
    \(\(PRINT = {1, 1, 1, 1, 1, 1, 1, 1};\)\)}], "Input",
  CellLabel->"In[5]:=",
  PageWidth->Infinity,
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["Lik,Score,BFGS", "Subsection",
  PageWidth->Infinity,
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain"],

Cell["\<\
Unprotect[Lik]; 
Clear[Lik]; 
Lik[data_, Theta_, {system_, LikN_}, misc_] := 
   Plus @@ (LikN[#1, Theta*SCALING, system, misc] & ) /@ data; 
Protect[Lik]; \
\>", "Input",
  CellLabel->"In[207]:=",
  PageWidth->Infinity,
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain"],

Cell["\<\
Unprotect[Lik1]; 
Clear[Lik1]; 
Lik1[data_, Theta_, {system_, LikN_}, misc_] := 
   Sum[LikN[data[[i]], Theta*SCALING, system, misc], 
    {i, 1, Length[data]}]; 
Protect[Lik1]; \
\>", "Input",
  CellLabel->"In[211]:=",
  PageWidth->Infinity,
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain"],

Cell["\<\
Clear[Score]; 
Score[data_, Theta_, {system_, {Lik_, LikN_}}, misc_] := 
   Module[{INC, i, LIK, LIKI, INC1, SNUM, ETA}, 
    LIK = Lik[data, Theta, {system, LikN}, misc]; 
     ETA = Max[$MachineEpsilon, 10.^(-FDIGITS)]; 
     INC = Sqrt[ETA]*max[Abs[Theta], Abs[TYP]]; INC1 = 1./INC; 
     SNUM = {}; u = Length[Theta]; Do[Thetai = GRIDI[Theta, i, INC]; 
       LIKI = Lik[data, Thetai, {system, LikN}, misc]; 
       SNUM = Append[SNUM, N[(LIKI - LIK)*INC1[[i]]]], {i, u}]; 
     {SNUM, LIK}]; \
\>", "Input",
  CellLabel->"In[215]:=",
  PageWidth->Infinity,
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain"],

Cell["\<\
Clear[Score2]; 
Score2[data_, Theta_, {system_, {Lik_, LikN_}}, misc_] := 
   Module[{INC, i, LIK, LIKup, LIKdo, INC1, SNUM, ETA}, 
    LIK = Lik[data, Theta, {system, LikN}, misc]; 
     ETA = Max[$MachineEpsilon, 10.^(-FDIGITS)]; 
     INC = ETA^(1/3)*max[Abs[Theta], Abs[TYP]]; 
     Print[\"Score2: INC: \", INC]; INC1 = 1/(2*INC); SNUM = {}; 
     Do[LIKup = Lik[data, GRIDI[Theta, i, INC], {system, LikN}, 
         misc]; LIKdo = Lik[data, GRIDI[Theta, i, -INC], 
         {system, LikN}, misc]; SNUM = Append[SNUM, 
         (LIKup - LIKdo)*INC1[[i]]], {i, Length[Theta]}]; 
     {SNUM, LIK}]; \
\>", "Input",
  CellLabel->"In[217]:=",
  PageWidth->Infinity,
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain"],

Cell["\<\
Hesse2[data_, Theta_, {system_, {Lik_, LikN_, Score_}}, misc_] := 
   Module[{INC, i, LIK, INC1, Sup, Sdo, DS, S, HNUM, SNUM, ETA}, 
    {S, LIK} = Score[data, Theta, {system, {Lik, LikN}}, misc]; 
     ETA = Max[$MachineEpsilon, 10.^(-FDIGITS)]; INC = ETA^(1/3); 
     INC = INC*max[Abs[Theta], Abs[TYP]]; INC1 = 1/(2*INC); 
     HNUM = {}; SNUM = {}; 
     Do[{Sup, likup} = Score[data, GRIDI[Theta, i, INC], 
         {system, {Lik, LikN}}, misc]; {Sdo, likdo} = 
        Score[data, GRIDI[Theta, i, -INC], {system, {Lik, LikN}}, 
         misc]; HNUM = Append[HNUM, (Sup - Sdo)*INC1[[i]]]; 
       SNUM = Append[SNUM, (likup - likdo)*INC1[[i]]], 
      {i, Length[Theta]}]; HNUM = 0.5*(HNUM + Transpose[HNUM]); 
     DS = S - SNUM; Print[
      \"KONTROLLE: NUMERISCHER SCORE - ZENTRALE DIFFERENZEN\"]; 
     Print[MatrixForm[Transpose[{SNUM, S, DS, Theta, INC}], 
       TableHeadings -> {Automatic, {\"SNUM\", \"S\", \"DS\", \"THETA\", 
          \"INC\"}}]]; {HNUM, LIK}]; \
\>", "Input",
  CellLabel->"In[219]:=",
  PageWidth->Infinity,
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain"],

Cell["\<\
Hesse[data_, Theta_, {system_, {Lik_, LikN_, Score_}}, misc_] := 
   Module[{LIK, L2, INK, INK2, H4, H, LIJ, LIMJ, LIJM, LIMJM, L2I, 
     LM2I, i, J, ETA}, LIK = Lik[data, Theta, {system, LikN}, misc]; 
     ETA = Max[$MachineEpsilon, 10.^(-FDIGITS)]; INC = ETA^(1/3); 
     INK = INC*max[Abs[Theta], Abs[TYP]]; Print[\"INK: \", INK]; 
     U = Length[Theta]; INK2 = 2*INK; 
     H4 = 0.25/Outer[Times, INK, INK]; L2 = 2*LIK; 
     H = Shape[0, {U, U}]; Do[{LIJ, LIMJ, LIJM, LIMJM} = 
        (Lik[data, #1, {system, LikN}, misc] & ) /@ 
         {GRIDIJ[Theta, i, J, INK, INK], GRIDIJ[Theta, i, J, INK, 
           -INK], GRIDIJ[Theta, i, J, -INK, INK], GRIDIJ[Theta, i, 
           J, -INK, -INK]}; H[[i,J]] = LIJ - LIMJ - LIJM + LIMJM; , 
      {i, 1, U}, {J, i + 1, U}]; H = H + Transpose[H]; 
     Do[{L2I, LM2I} = (Lik[data, #1, {system, LikN}, misc] & ) /@ 
         {GRIDI[Theta, i, INK2], GRIDI[Theta, i, -INK2]}; 
       H[[i,i]] = L2I - L2 + LM2I; , {i, 1, U}]; H = H*H4; 
     {H, LIK}]; \
\>", "Input",
  CellLabel->"In[220]:=",
  PageWidth->Infinity,
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{4, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain"],

Cell["\<\
Clear[BFGSUP]; 
BFGSUP[F_, SNEU_, S_, STEP_] := Module[{MACHEPS2, Y, FSTEP, A, B, 
     Fup, ETA}, ETA = Max[$MachineEpsilon, 10.^(-FDIGITS)]; 
     TOL = If[ANALGRAD, ETA, ETA^0.5, ETA^0.5]; 
     NOISE = (Max[Abs[SNEU]] + Max[Abs[S]])*TOL; 
     MACHEPS2 = $MachineEpsilon^0.5; Y = -SNEU + S; 
     FSTEP = F . STEP; A = Y . STEP; 
     If[A < MACHEPS2*Max[Abs[STEP]]*Max[Abs[Y]], Return[F]]; 
     If[Max[Abs[Y - FSTEP]] < NOISE, Return[F]]; A = 1/A; 
     B = 1/STEP . FSTEP; 
     (*Print[\"*BFGSUP \", A, \"  \", B];*)
     Fup = F + Outer[Times, A*Y, Y] - Outer[Times, B*FSTEP, FSTEP]; 
     Fup]; \
\>", "Input",
  CellLabel->"In[61]:=",
  PageWidth->Infinity,
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{1, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain"],

Cell["\<\
LikTest[LIKNEU_] := If[ !NumberQ[LIKNEU] || Im[LIKNEU] =!= 0 || 
     LIKNEU > 10.^10, Print[\"LIKNEU = \", LIKNEU, 
      \" reset to -10.^10\"]; -10.^10, LIKNEU]; \
\>", "Input",
  CellLabel->"In[223]:=",
  PageWidth->Infinity,
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  CellLabelMargins->{{1, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain"],

Cell["\<\
Clear[BFGS]; 
BFGS[data_, {THETA0_, F0_}, {system_, {Lik_, LikN_, Score_, Hesse_}}, 
     {misc_, KMAX_, {EPS1_, EPS2_}, OPTION_, PRINT_}] :=
      
   Module[{MINSTEP, BOUND, ALPHA, u, THETA, THETA1, F, S, LIKALT, 
     LIKI, psii, scoreii, STEPL, STEP, LIKNEU, SNEU, likpsi, COV, 
     LIKELI, n, T, T1, Tc, P, Q, k, K, KK, Z, Y, X, ReturnCode}, 
     MINSTEP = 1/10.^10; FMAX = 10^3; BOUND = 1/10.^6; 
     ALPHA = 1/10.^4; 
     
     (*
     T = data[[1,2]]//Length;
     n = data[[1,3]];
     *)
      
     If[PRINT[[1]] == 1, 
       Print[\"***********************LSDE1**********************************\
\"]; 
       Print[\"***********************MODUL:    BFGS (skeleton)**************\
\"]; 
       Print[\"**************************************************************\
\"]; 
       Print[\"Technical Output\"]; Print[LikN]; 
       Print[\"**************************************************************\
\"]; 
       VecPrint[Spalte[{KMAX, EPS1, EPS2, K, Q, n, T, OPTION}], 
                      {\"KMAX\", \"EPS1\", \"EPS2\", \"K\", \"Q\", \"n\", \"T\
\", \"OPTION    \"}]; 
       Print[\"\"];
       VecPrint[Spalte[{MAXSTEP, MINSTEP, BOUND,STEPREDUCE, FMAX}], \
{\"MAXSTEP\", \"MINSTEP\", \"BOUND\", 
         \"STEPREDUCE\", \"FMAX\"}]; Print[\"\"]; 
       VecPrint[Spalte[{RESAMPLING, FDIGITS, TYP, YMAX, ANALGRAD, 
          FACTOR, CSEED}], {\"RESAMPLING\", \"FDIGITS\", \"TYP\", \"YMAX\", 
         \"ANALGRAD\", \"FACTOR\", \"CSEED\"}]; Print[\"\"]; 
       Print[\"    SCALING\"]; Print[MatrixForm[
         Transpose[Spalte[SCALING]], TableHeadings -> 
          {Automatic, {\"SCALING\"}}, TableDepth -> 0]]; Print[\"\"]; 
       Print[\"**************************************************************\
\"]; 
       Print[\"\"]; 
       Print[\"STARTWERT THETA0 = \", THETA0]]; 
     
     u = Length[THETA0]; 
     THETA = THETA0; 
     
     F = F0; 
     If[OPTION == 1, F = SHIFT[F, BOUND]]; 
     {S, LIKALT} = Score[data, THETA0, {system, {Lik, LikN}}, misc]; 
     Print[{S, LIKALT}]; LIKI = {}; psii = {}; scoreii = {}; 
     ReturnCode = 0; k = 0; DoUntil[{KK, KMAX}, ReturnCode == 3, 
      If[PRINT[[2]] == 1, 
      Print[\"----------------------------------------------------------------\
-\"]; 
      Print[\"BFGS: Iteration = \", KK]; ]; LIKI = Append[LIKI, LIKALT]; 
       psii = Append[psii, THETA]; scoreii = Append[scoreii, S]; 
       STEP = LinearSolve[F, S]; STEPL = Max[Abs[STEP]]; 
       STEP = STEP*Min[1, MAXSTEP/STEPL]; THETA1 = THETA + STEP; 
       LIKNEU = Lik[data, THETA1, {system, LikN}, misc]; 
       LIKNEU = LikTest[LIKNEU]; DoWhile[{half, 100}, 
        LIKNEU < LIKALT + ALPHA*S . STEP && Max[Abs[STEP]] > 
          MINSTEP, STEP = STEP/STEPREDUCE; THETA1 = THETA + STEP; 
         LIKNEU = Lik[data, THETA1, {system, LikN}, misc]; 
         LIKNEU = LikTest[LIKNEU]; If[PRINT[[3]] == 1, 
          Print[\"STEP-REDUCTION:  \", half, \"  LIKNEU  \", 
            PaddedForm[LIKNEU, {20, 15}], \"  LIKALT  \", 
            PaddedForm[LIKALT, {20, 15}]]; ]; ]; 
       If[LIKNEU - LIKALT < 0, Print[\"ReturnCode = 4\"]; 
         ReturnCode = 4; Break[]]; If[PRINT[[4]] == 1, 
        Print[\"LIKNEU  \", PaddedForm[LIKNEU, {20, 15}]]; 
         Print[\"LIKALT  \", PaddedForm[LIKALT, {20, 15}]]; 
         Print[\"LIKNEU - LIKALT  \", PaddedForm[LIKNEU - LIKALT, 
           {20, 15}]]; Print[\"\"]; ]; If[PRINT[[5]] == 1, 
        Print[PaddedForm[TableForm[(Chop[#1, 1/10^5] & )[
            Transpose[{THETA1, THETA, STEP, S}]], TableHeadings -> 
            {Automatic, {\"THETA1\", \"THETA\", \"STEP\", \"SCORE\"}}, 
           TableDirections -> {Column, Row}, TableSpacing -> 
            {0, 2}], {5, 4}]]]; If[PRINT[[6]] == 1, 
        Print[\"F\"]; Print[MatrixForm[F]]; ]; {SNEU, LIKALT} = 
        Score[data, THETA1, {system, {Lik, LikN}}, misc]; 
       F = BFGSUP[F, SNEU, S, STEP]; S = SNEU; 
       THETA = THETA1GLOBAL = THETA1; k = KK; 
       relgrad = Max[Abs[S*max[Abs[THETA], TYP]]]/Abs[LIKNEU]; 
       Print[\"relgrad = \", relgrad, 
        \" = Elastizitaet(d l/l)/(d theta/theta)\"]; 
       If[Max[Abs[S]] < EPS1, Print[\"ReturnCode = 1\"]; 
         ReturnCode = 1]; If[Max[Abs[STEP]] < EPS2, 
        Print[\"ReturnCode = 2\"]; ReturnCode = 2]; 
       If[Max[Abs[S]] < EPS1 && Max[Abs[STEP]] < EPS2, 
        Print[\"ReturnCode = 3\"]; ReturnCode = 3]; ]; 
     If[PRINT[[7]] == 1, Print[\"BFGS:  ENDE DER ITERATION  \", k, 
       \"  \", KMAX]]; If[PRINT[[5]] == 1, 
      Print[TableForm[Transpose[{SNEU}], TableHeadings -> 
         {Automatic, {\"SCORE\"}}, TableDirections -> {Column, Row}, 
        TableSpacing -> {0, 2}]]]; If[PRINT[[6]] == 1, 
      Print[\"F\"]; Print[MatrixForm[F]]; ]; 
     LIKI = Append[LIKI, LIKALT]; psii = Append[psii, THETA]; 
     scoreii = Append[scoreii, S]; likpsi = ii[Spalte[LIKI], psii]; 
     If[PRINT[[8]] == 1, Print[TableForm[likpsi, 
        TableHeadings -> {Automatic, {\"Likelihood\", \"THETA\"}}, 
        TableDirections -> {Column, Row}, TableSpacing -> {0, 2}]]]; 
     If[FISHER && k < KMAX, 
          {F, LIKELI} = Hesse[data, THETA, {system, {Lik, LikN, Score}}, \
misc];
          F = -F; 
          COV = OUTPUT[THETA, F, 0.05, S, LIKELI]; 
          LKOMP[LIKELI, u, Indeterminate], 
          (*else*)
          COV = Inverse[F]; 
          ]; 
     {THETA, COV, LIKI, psii, scoreii, k, ReturnCode}]; \
\>", "Input",
  CellLabel->"In[753]:=",
  PageWidth->Infinity,
  CellMargins->{{20.375, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  TextAlignment->Left,
  TextJustification->0,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain",
  CellTags->"BFGS"],

Cell["\<\
LKOMP//Clear
LKOMP[LIK_, U_, Nue_] := Module[{EPS, LN, KOMP1, KOMP2, KOMP3}, 
     EPS = 1/10^3; LN = Log[N[Nue]]; KOMP1 = U; KOMP2 = 0.5*U*LN; 
     KOMP3 = 0.5*U*(U + 1)*(1 + EPS)*Log[LN]; 
     Print[\"--------------------------------------------------------\"]; 
     Print[\"KOMPENSIERTE LIKELIHOOD\"]; 
     Print[\"--------------------------------------------------------\"]; 
     Print[\"U =  \", U, \"  Nue = \", Nue]; 
     Print[\"AKAIKE (AIC) SCHWARZ/RISSANEN (SIC/RISS) \
AZENCOTT/DACUNHA-CASTELLE (A/D)\"]; 
     ket = {{0, KOMP1, KOMP2, KOMP3}, {LIK, LIK - KOMP1, LIK - KOMP2, LIK - \
KOMP3}}; 
     Print[TableForm[ket, TableHeadings -> {{\"Kompensator\", \"komp. \
Lik.\"}, 
         {\"LIK\", \"AIC\", \"SIC/RISS\", \"A/D\"}}, TableDirections -> \
{Column, Row}, 
       TableSpacing -> {1, 2}]]; ]; \
\>", "Input",
  CellLabel->"In[87]:=",
  PageWidth->Infinity,
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["LKOMP[100.99, 5, 10]", "Input",
  CellLabel->"In[43]:=",
  PageWidth->Infinity,
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain"],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print",
  CellLabel->"From In[43]:="],

Cell[BoxData[
    \("KOMPENSIERTE LIKELIHOOD"\)], "Print",
  CellLabel->"From In[43]:="],

Cell[BoxData[
    \("--------------------------------------------------------"\)], "Print",
  CellLabel->"From In[43]:="],

Cell[BoxData[
    InterpretationBox[\("U =  "\[InvisibleSpace]5\[InvisibleSpace]"  Nue = "\
\[InvisibleSpace]10\),
      SequenceForm[ "U =  ", 5, "  Nue = ", 10],
      Editable->False]], "Print",
  CellLabel->"From In[43]:="],

Cell[BoxData[
    \("AKAIKE (AIC) SCHWARZ/RISSANEN (SIC/RISS) AZENCOTT/DACUNHA-CASTELLE \
(A/D)"\)], "Print",
  CellLabel->"From In[43]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"LIK\"\>", "\<\"AIC\"\>", "\<\"SIC/RISS\"\>", \
"\<\"A/D\"\>"},
          {"\<\"Kompensator\"\>", "0", "5", "5.756462732485115`", 
            "12.522997165398058`"},
          {"\<\"komp. Lik.\"\>", "100.99`", "95.99`", "95.23353726751488`", 
            "88.46700283460194`"}
          },
        RowSpacings->1,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {{"Kompensator", "komp. Lik."}, {"LIK", 
          "AIC", "SIC/RISS", "A/D"}}, TableDirections -> {Column, Row}, 
          TableSpacing -> {1, 2}]]]], "Print",
  CellLabel->"From In[43]:="]
}, Open  ]],

Cell["\<\
OUTPUT[THETA_, F_, ALPHA_, SCORE_, LIKELI_] := 
   Module[{COV, EIGF, EIGCOV}, 
    Print[
      \"--------------------------------------------------------\"]; 
     Print[\"ML-Sch\[ADoubleDot]tzer, SCORE UND LIKELIHOOD\"]; 
     Print[\"--------------------------------------------------------\\
\"]; Print[(MatrixForm[#1, TableHeadings -> {Automatic, 
           {\"THETA\", \"SCORE\"}}] & )[Transpose[{THETA, SCORE}]], 
      \"   Likelihood = \", N[LIKELI, 25]]; 
     COV = SIGNI[THETA, F, ALPHA]; EIGF = Eigenvalues[F]; 
     EIGCOV = 1/EIGF; 
     Print[\"--------------------------------------------------------\\
\"]; Print[\"GESCH\[CapitalADoubleDot]TZTE KOVARIANZMATRIX UND EIGENWERTE\"]; \

     Print[\"--------------------------------------------------------\\
\"]; Print[MatrixForm[Chop[N[COV, 5]]]]; Print[\"\"]; 
     Print[N[EIGCOV, 5]]; 
     Print[\"--------------------------------------------------------\\
\"]; Print[\"GESCH\[CapitalADoubleDot]TZTE FISHER-INFORMATIONS-MATRIX UND \
EIGENWERTE\"]; 
     Print[
      \"--------------------------------------------------------\"]; 
     Print[MatrixForm[Chop[N[F, 5]]]]; Print[\"\"]; Print[N[EIGF, 5]]; 
     COV]; \
\>", "Input",
  CellLabel->"In[228]:=",
  PageWidth->Infinity,
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain"],

Cell["\<\
SIGNI[THETA_, F_, ALPHA_] := Module[{U, CHI, PROB, Z, COV, AU2, \
DCOV, STD, STD1, 
     CORR, GRENZE}, U = Length[THETA]; CHI = N[THETA . F . THETA]; 
     If[CHI >= 0, PROB = 1 - CDF[ChiSquareDistribution[U], CHI]; 
       Print[\"------------------------------------------------------\"]; 
       Print[\"WALD-TEST:\"]; 
       Print[\"------------------------------------------------------\"]; 
       VecPrint[Spalte[{CHI, U, Chop[PROB], ALPHA}], {\"CHI \", \"U \", \
\"PROB \", 
         \"ALPHA \"}]; If[PROB < ALPHA, 
        Print[\"NULLHYPOTHESE THETA = 0 ABLEHNEN\"]]; , 
      Print[\"F NICHT POSITIV DEFINIT\"]; ]; COV = PseudoInverse[F]; 
     AU2 = ALPHA/(2*U); Z = Quantile[NormalDistribution[0, 1], 1 - AU2]; 
     DCOV = Transpose[COV, {1, 1}]; If[all[gr[DCOV, 0]], 
      STD = Sqrt[DCOV]; STD1 = 1/STD; CORR = DiagonalMatrix[STD1] . COV . 
         DiagonalMatrix[STD1]; GRENZE = Z*STD; 
       Print[\"------------------------------------------------------\"]; 
       Print[\"BONFERRONI-KONFIDENZINTERVALLE:\"]; 
       Print[\"------------------------------------------------------\"]; 
       Print[\"P{THETA AUS [THDACH-GRENZE,THDACH+GRENZE] } >= 1-ALPHA\"]; 
       Print[\"QUANTIL Z(1-ALPHA/2U) = \", N[Z]]; 
       VecPrint[N[{THETA, GRENZE, STD}], {\"THETA\", \"GRENZE\", \"STD\"}]; 
       Print[\"-------------------------------------------------------\"]; 
       Print[\"Korrelation der ML-Sch\[ADoubleDot]tzer\"]; 
       Print[\"-------------------------------------------------------\"]; 
       Print[MatrixForm[Chop[N[CORR, 2]]]]; , 
      Print[\"Warnung: Negative Diagonalelemente der Kovarianzmatrix\"]; ]; 
     Return[COV]; ]; \
\>", "Input",
  CellLabel->"In[92]:=",
  PageWidth->WindowWidth,
  CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
  InitializationCell->True,
  ImageRegion->{{-0, 1}, {0, 1}},
  FontWeight->"Plain"]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{42, 1440}, {0, 878}},
AutoGeneratedPackage->Automatic,
WindowToolbars->"RulerBar",
WindowSize->{1044, 828},
WindowMargins->{{Automatic, 9}, {Automatic, 4}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowSelection->True,
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1.25,
StyleDefinitions -> "ArticleModern.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "plot1"->{
    Cell[39920, 921, 6558, 120, 1262, "Input",
      InitializationCell->True,
      CellTags->"plot1"]},
  "BFGS"->{
    Cell[55067, 1281, 5654, 121, 1781, "Input",
      InitializationCell->True,
      CellTags->"BFGS"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"plot1", 67709, 1582},
  {"BFGS", 67827, 1586}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 176, 4, 100, "Title",
  InitializationCell->True],
Cell[1955, 59, 328, 12, 222, "Subtitle",
  InitializationCell->True],
Cell[2286, 73, 323, 5, 144, "Subsubtitle",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2634, 82, 148, 2, 75, "Section"],
Cell[2785, 86, 472, 11, 203, "Input",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[3294, 102, 151, 2, 75, "Section"],
Cell[3448, 106, 433, 10, 186, "Input",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[3918, 121, 132, 5, 100, "Section"],
Cell[4053, 128, 2338, 69, 403, "Input",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[6428, 202, 193, 4, 75, "Section",
  InitializationCell->True],
Cell[6624, 208, 487, 10, 122, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[7148, 223, 166, 3, 41, "Section",
  InitializationCell->True],
Cell[7317, 228, 330, 7, 84, "Input",
  InitializationCell->True],
Cell[7650, 237, 318, 7, 84, "Input",
  InitializationCell->True],
Cell[7971, 246, 326, 7, 84, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[8334, 258, 186, 3, 41, "Section",
  InitializationCell->True],
Cell[8523, 263, 2262, 42, 521, "Input",
  InitializationCell->True],
Cell[10788, 307, 3091, 60, 724, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[13916, 372, 256, 5, 41, "Section",
  InitializationCell->True],
Cell[14175, 379, 1724, 32, 369, "Input",
  InitializationCell->True],
Cell[15902, 413, 2724, 53, 647, "Input",
  InitializationCell->True],
Cell[18629, 468, 9098, 161, 1813, "Input",
  InitializationCell->True],
Cell[27730, 631, 3446, 60, 1087, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[31213, 696, 226, 8, 75, "Section",
  InitializationCell->True],
Cell[31442, 706, 255, 6, 65, "Input",
  InitializationCell->True],
Cell[31700, 714, 746, 14, 217, "Input"],
Cell[32449, 730, 957, 20, 217, "Input",
  InitializationCell->True],
Cell[33409, 752, 255, 6, 65, "Input",
  InitializationCell->True],
Cell[33667, 760, 688, 14, 65, "Input",
  InitializationCell->True],
Cell[34358, 776, 503, 11, 65, "Input",
  InitializationCell->True],
Cell[34864, 789, 579, 12, 122, "Input",
  InitializationCell->True],
Cell[35446, 803, 345, 8, 84, "Input",
  InitializationCell->True],
Cell[35794, 813, 351, 8, 84, "Input",
  InitializationCell->True],
Cell[36148, 823, 422, 10, 103, "Input",
  InitializationCell->True],
Cell[36573, 835, 512, 12, 84, "Input",
  InitializationCell->True],
Cell[37088, 849, 757, 17, 122, "Input",
  InitializationCell->True],
Cell[37848, 868, 288, 7, 65, "Input",
  InitializationCell->True],
Cell[38139, 877, 667, 14, 141, "Input",
  InitializationCell->True],
Cell[38809, 893, 504, 11, 141, "Input",
  InitializationCell->True],
Cell[39316, 906, 601, 13, 188, "Input",
  InitializationCell->True],
Cell[39920, 921, 6558, 120, 1262, "Input",
  InitializationCell->True,
  CellTags->"plot1"],
Cell[46481, 1043, 819, 24, 302, "Input",
  InitializationCell->True],
Cell[47303, 1069, 386, 9, 84, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[47726, 1083, 256, 9, 75, "Section",
  InitializationCell->True],
Cell[47985, 1094, 687, 18, 274, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[48697, 1116, 206, 5, 65, "Subsection",
  InitializationCell->True],
Cell[48906, 1123, 377, 12, 132, "Input",
  InitializationCell->True],
Cell[49286, 1137, 399, 13, 149, "Input",
  InitializationCell->True],
Cell[49688, 1152, 718, 17, 217, "Input",
  InitializationCell->True],
Cell[50409, 1171, 823, 19, 251, "Input",
  InitializationCell->True],
Cell[51235, 1192, 1201, 24, 336, "Input",
  InitializationCell->True],
Cell[52439, 1218, 1284, 25, 336, "Input",
  InitializationCell->True],
Cell[53726, 1245, 887, 21, 268, "Input",
  InitializationCell->True],
Cell[54616, 1268, 448, 11, 98, "Input",
  InitializationCell->True],
Cell[55067, 1281, 5654, 121, 1781, "Input",
  InitializationCell->True,
  CellTags->"BFGS"],
Cell[60724, 1404, 1039, 24, 268, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[61788, 1432, 204, 5, 64, "Input"],
Cell[61995, 1439, 121, 2, 46, "Print"],
Cell[62119, 1443, 88, 2, 46, "Print"],
Cell[62210, 1447, 121, 2, 46, "Print"],
Cell[62334, 1451, 227, 5, 46, "Print"],
Cell[62564, 1458, 139, 3, 46, "Print"],
Cell[62706, 1463, 748, 18, 84, "Print"]
}, Open  ]],
Cell[63469, 1484, 1407, 31, 421, "Input",
  InitializationCell->True],
Cell[64879, 1517, 1893, 35, 489, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

