(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    232319,       6104]
NotebookOptionsPosition[    222284,       5785]
NotebookOutlinePosition[    224201,       5848]
CellTagsIndexPosition[    223934,       5838]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["SEM", "Title",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontColor->RGBColor[1, 0, 0]],

Cell[TextData[{
 "Linear Structural Equations Models \nwith Arbitrary Nonlinear \nParameter \
Restrictions\n\n",
 StyleBox["Version 0.4 \n",
  FontColor->GrayLevel[0]],
 "\n\n",
 StyleBox["\[Copyright] Hermann.Singer@FernUni-Hagen.de",
  FontColor->GrayLevel[0]]
}], "Subtitle",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 CellChangeTimes->{3.4600840495536413`*^9},
 ImageRegion->{{0, 1}, {0, 1}},
 FontColor->RGBColor[1, 0, 0]],

Cell[TextData[{
 StyleBox["\n",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["The program is shareware, \nso please cite the author and \nsend \
me a message \nif you are using it\nor if you find bugs",
  FontColor->GrayLevel[0]]
}], "Subsubtitle",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Model 1: stochastic regressors xi", "Section",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["eta = beta.eta + gamma.xi + zeta\ny   = lambdaeta.eta + epsilon\nx \
  = lambdaxi.xi + delta",
  FontColor->RGBColor[0, 0, 1]],
 "\n\nFree parameters:\n\n        {{beta,gamma,muexi,sigmaxi,sigmazeta},\n    \
    {lambdaeta,lambdaxi,sigmaepsilon,sigmadelta}}=\n        \n        ",
 StyleBox["System",
  FontColor->RGBColor[1, 0, 0]],
 "[Theta,ThetaFix];"
}], "Input",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 Evaluatable->False,
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Model 2: deterministic regressors xi", "Section",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["eta = beta.eta + gamma.xi + zeta\ny   = lambdaeta.eta + taueta.xi \
+ epsilon",
  FontColor->RGBColor[0, 0, 1]],
 "\n\nFree parameters:\n\n        {{beta,gamma,sigmazeta},\n         \
{lambdaeta,taueta,sigmaepsilon}}=  \n         \n         ",
 StyleBox["System",
  FontColor->RGBColor[1, 0, 0]],
 "[Theta,ThetaFix];"
}], "Input",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 Evaluatable->False,
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
 Remarks
\
\>", "Section",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["--The second model is more general, since eta --> (eta,xi) \
includes stochastic regressors\n\n--",
  FontFamily->"Arial",
  FontSize->14],
 StyleBox["The LISREL model with structured means is a special case:",
  FontFamily->"Arial",
  FontSize->14,
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["\n\n",
  FontFamily->"Arial",
  FontSize->14,
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["{eta,xi} = {{Beta,Gamma},{0,0}}.{eta,xi} + {alpha,kappa} + \
{zeta1,zeta2}; \n\n{y,x} = {tauy,taux} + ",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0},
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["DiagonalMatrix[",
  FontWeight->"Plain",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["{lambday,lambdax}].{eta,xi} + {epsilon,delta};",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0},
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\n\n\nCov(zeta1,zeta2)=0; Var(zeta2)=phi; E[xi]=kappa\n\n\
Cov(epsilon,delta)=0\n\n",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["\n--",
  FontFamily->"Times",
  FontSize->14],
 StyleBox["ThetaFix contains fixed parameters (e.g. sampling interval)\n\n\
--Nonlinear restrictions are implemented in module System\n\nExecute the \
following code and study the example notebooks:",
  FontFamily->"Arial",
  FontSize->14],
 StyleBox["\n\n",
  FontFamily->"Times",
  FontSize->14],
 StyleBox["car2.SEM.determ.1komponente.nb (ar(2) with deterministic \
regressors)",
  FontWeight->"Plain"],
 StyleBox["\n",
  FontSize->14],
 StyleBox["car2.SEM.random.1komponente.nb (ar(2) with random effects, \
stochastic regressors)\nfactor.nb  (LISREL  model EX1.LS8, p.6,  97-122)",
  FontWeight->"Plain"],
 StyleBox["\n",
  FontSize->14]
}], "Input",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 Evaluatable->False,
 CellChangeTimes->{{3.460083959645925*^9, 3.460083995440178*^9}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pakete", "Section",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontVariations->{"CompatibilityType"->0}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"<<", "\"\<LinearAlgebra`MatrixManipulation`\>\""}], "\n", 
    RowBox[{"<<", "\"\<Statistics`NormalDistribution`\>\""}]}], "*)"}], "\n", 
  
  RowBox[{"(*", 
   RowBox[{"<<", "\"\<Statistics`InverseStatisticalFunctions`\>\""}], "*)"}], 
  "\n", 
  RowBox[{"<<", "\"\<Statistics`Common`DistributionsCommon`\>\""}]}]], "Input",\

 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 CellChangeTimes->{{3.4602010261257133`*^9, 3.4602010299544067`*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 CellLabel->"In[1520]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Clear Modules", "Section",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 FontVariations->{"CompatibilityType"->0}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Unprotect", "[", "\"\<Hermann`Kronecker`*\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "\"\<Hermann`Kronecker`*\>\"", "]"}], ";"}]}], "Input",\

 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 CellLabel->"In[149]:="],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Unprotect", "[", "\"\<Hermann`LSD`*\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "\"\<Hermann`LSD`*\>\"", "]"}], ";"}]}], "Input",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 CellLabel->"In[151]:="],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Unprotect", "[", "\"\<Hermann`PARTest`*\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "\"\<Hermann`PARTest`*\>\"", "]"}], ";"}]}], "Input",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 CellLabel->"In[153]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Implementierung / stochastische Regressoren", "Section",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[{
 RowBox[{"Clear", "[", "LISRELsimul", "]"}], "\n", 
 RowBox[{
  RowBox[{"LISRELsimul", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"n_", ",", "Generator_"}], "}"}], ",", "Theta_", ",", 
    RowBox[{"{", 
     RowBox[{"System_", ",", "ThetaFix_"}], "}"}]}], "]"}], ":=", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "p", ",", "q", ",", "beta", ",", "gamma", ",", "B1", ",", "muexi", ",", 
      "sigmaxi", ",", "XI", ",", "sigmazeta", ",", "ZETA", ",", 
      "\[IndentingNewLine]", "          ", "ETA", ",", "sigmaepsilon", ",", 
      "lambdaeta", ",", "kp", ",", "EPSILON", ",", "sigmadelta", ",", 
      "lambdaxi", ",", "kq", ",", "Y", ",", "X", ",", "DELTA"}], "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "beta", ",", "gamma", ",", "muexi", ",", "sigmaxi", ",", 
          "sigmazeta"}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "lambdaeta", ",", "lambdaxi", ",", "sigmaepsilon", ",", 
          "sigmadelta"}], "}"}]}], "}"}], "=", 
      RowBox[{"System", "[", 
       RowBox[{"Theta", ",", "ThetaFix"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p", ",", "q"}], "}"}], "=", 
      RowBox[{"Dimensions", "[", "gamma", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"B1", "=", 
      RowBox[{
       RowBox[{"IdentityMatrix", "[", "p", "]"}], "-", "beta"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"sigmaxi", "=", 
      RowBox[{"symmetric", "[", "sigmaxi", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"XI", "=", 
      RowBox[{"RandomGauss", "[", 
       RowBox[{"muexi", ",", "sigmaxi", ",", "n", ",", "Generator"}], "]"}]}],
      ";", "\[IndentingNewLine]", 
     RowBox[{"sigmazeta", "=", 
      RowBox[{"symmetric", "[", "sigmazeta", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ZETA", "=", 
      RowBox[{"RandomGauss", "[", 
       RowBox[{
        RowBox[{"Shape", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "p", "}"}]}], "]"}], ",", "sigmazeta", ",", "n", ",", 
        "Generator"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ETA", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"XI", ".", 
          RowBox[{"Transpose", "[", "gamma", "]"}]}], "+", "ZETA"}], ")"}], 
       ".", 
       RowBox[{"Transpose", "[", 
        RowBox[{"Inverse", "[", "B1", "]"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"sigmaepsilon", "=", 
      RowBox[{"symmetric", "[", "sigmaepsilon", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"kp", "=", 
      RowBox[{"Length", "[", "lambdaeta", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"EPSILON", "=", 
      RowBox[{"RandomGauss", "[", 
       RowBox[{
        RowBox[{"Shape", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "kp", "}"}]}], "]"}], ",", "sigmaepsilon", ",", "n", 
        ",", "Generator"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"sigmadelta", "=", 
      RowBox[{"symmetric", "[", "sigmadelta", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"kq", "=", 
      RowBox[{"Length", "[", "lambdaxi", "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"DELTA", "=", 
      RowBox[{"RandomGauss", "[", 
       RowBox[{
        RowBox[{"Shape", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "kq", "}"}]}], "]"}], ",", "sigmadelta", ",", "n", ",",
         "Generator"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Y", "=", 
      RowBox[{
       RowBox[{"ETA", ".", 
        RowBox[{"Transpose", "[", "lambdaeta", "]"}]}], "+", "EPSILON"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"X", "=", 
      RowBox[{
       RowBox[{"XI", ".", 
        RowBox[{"Transpose", "[", "lambdaxi", "]"}]}], "+", "DELTA"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Y", ",", "X", ",", "ETA", ",", "XI"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ZETA", ",", "EPSILON", ",", "DELTA"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "beta", ",", "gamma", ",", "muexi", ",", "sigmaxi", ",", 
           "sigmazeta"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
          "lambdaeta", ",", "lambdaxi", ",", "sigmaepsilon", ",", 
           "sigmadelta"}], "}"}]}], "}"}]}], "}"}]}]}], "\[IndentingNewLine]",
    "]"}]}]}], "Input",
 PageWidth->Infinity,
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 CellLabel->"In[155]:="],

Cell[BoxData[{
 RowBox[{"Clear", "[", "LISRELlik", "]"}], "\n", 
 RowBox[{
  RowBox[{"LISRELlik", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"S_", ",", "m_", ",", "n_"}], "}"}], ",", "Theta_", ",", 
    RowBox[{"{", 
     RowBox[{"System_", ",", "ThetaFix_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"Singular_", ",", 
      RowBox[{"const_", ":", 
       RowBox[{"2", " ", "\[Pi]"}]}]}], "}"}]}], "]"}], ":=", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "p", ",", "q", ",", "gamma", ",", "beta", ",", "B1", ",", "muexi", ",", 
      "sigmaxi", ",", "sigmazeta", ",", "sigmaepsilon", ",", "lambdaeta", ",",
       "\[IndentingNewLine]", "          ", "kp", ",", "sigmadelta", ",", 
      "lambdaxi", ",", "kq", ",", "B11", ",", "B11gamma", ",", "sigmaetaxi", 
      ",", "sigmaeta", ",", "sigmayx", ",", "\[IndentingNewLine]", 
      "          ", "sigmaxy", ",", "sigmax", ",", "sigmay", ",", "mueeta", 
      ",", "muey", ",", "muex", ",", "SigmaYX", ",", "mueYX", ",", "l"}], 
     "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "beta", ",", "gamma", ",", "muexi", ",", "sigmaxi", ",", 
          "sigmazeta"}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "lambdaeta", ",", "lambdaxi", ",", "sigmaepsilon", ",", 
          "sigmadelta"}], "}"}]}], "}"}], "=", 
      RowBox[{"System", "[", 
       RowBox[{"Theta", ",", "ThetaFix"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p", ",", "q"}], "}"}], "=", 
      RowBox[{"Dimensions", "[", "gamma", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"B1", "=", 
      RowBox[{
       RowBox[{"IdentityMatrix", "[", "p", "]"}], "-", "beta"}]}], ";", "  ", 
     "\[IndentingNewLine]", 
     RowBox[{"kp", "=", 
      RowBox[{"Length", "[", "lambdaeta", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"kq", "=", 
      RowBox[{"Length", "[", "lambdaxi", "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"B11", "=", 
      RowBox[{"Inverse", "[", "B1", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"B11gamma", "=", 
      RowBox[{"B11", ".", "gamma"}]}], ";", "  ", "\[IndentingNewLine]", 
     RowBox[{"sigmaetaxi", "=", 
      RowBox[{"B11gamma", ".", "sigmaxi"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"sigmaeta", "=", 
      RowBox[{
       RowBox[{"B11gamma", ".", "sigmaxi", ".", 
        RowBox[{"Transpose", "[", "B11gamma", "]"}]}], "+", 
       RowBox[{"B11", ".", "sigmazeta", ".", 
        RowBox[{"Transpose", "[", "B11", "]"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"sigmayx", "=", 
      RowBox[{"lambdaeta", ".", "sigmaetaxi", ".", 
       RowBox[{"Transpose", "[", "lambdaxi", "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"sigmaxy", "=", 
      RowBox[{"Transpose", "[", "sigmayx", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"sigmax", "=", 
      RowBox[{
       RowBox[{"lambdaxi", ".", "sigmaxi", ".", 
        RowBox[{"Transpose", "[", "lambdaxi", "]"}]}], "+", "sigmadelta"}]}], 
     ";", " ", "\[IndentingNewLine]", 
     RowBox[{"sigmay", "=", 
      RowBox[{
       RowBox[{"lambdaeta", ".", "sigmaeta", ".", 
        RowBox[{"Transpose", "[", "lambdaeta", "]"}]}], "+", 
       "sigmaepsilon"}]}], ";", " ", "\[IndentingNewLine]", 
     RowBox[{"mueeta", "=", 
      RowBox[{"B11gamma", ".", "muexi"}]}], ";", " ", "\[IndentingNewLine]", 
     RowBox[{"muey", "=", 
      RowBox[{"lambdaeta", ".", "mueeta"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"muex", "=", 
      RowBox[{"lambdaxi", ".", "muexi"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"SigmaYX", "=", 
      RowBox[{"vv", "[", 
       RowBox[{
        RowBox[{"ii", "[", 
         RowBox[{"sigmay", ",", "sigmayx"}], "]"}], ",", 
        RowBox[{"ii", "[", 
         RowBox[{"sigmaxy", ",", "sigmax"}], "]"}]}], "]"}]}], ";", "  ", 
     "\[IndentingNewLine]", 
     RowBox[{"mueYX", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{"muey", ",", "muex"}], "}"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"!", "Singular"}], ",", "\[IndentingNewLine]", 
       RowBox[{"l", "=", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", "n", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"kp", "+", "kq"}], ")"}], " ", 
            RowBox[{"Log", "[", "const", "]"}]}], "+", 
           RowBox[{"Log", "[", 
            RowBox[{"Det", "[", "SigmaYX", "]"}], "]"}], "+", 
           RowBox[{"Tr", "[", 
            RowBox[{
             RowBox[{"Inverse", "[", "SigmaYX", "]"}], ".", 
             RowBox[{"(", 
              RowBox[{"S", "+", 
               RowBox[{"Outer", "[", 
                RowBox[{"Times", ",", 
                 RowBox[{"m", "-", "mueYX"}], ",", 
                 RowBox[{"m", "-", "mueYX"}]}], "]"}]}], ")"}]}], "]"}]}], 
          ")"}]}]}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"eig", "=", 
         RowBox[{"Eigenvalues", "[", "SigmaYX", "]"}]}], ";", 
        RowBox[{"eig", "=", 
         RowBox[{"Select", "[", 
          RowBox[{"eig", ",", 
           RowBox[{
            RowBox[{"#1", ">", "0"}], "&"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"l", "=", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", "n", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Plus", "@@", 
             RowBox[{"Log", "[", 
              RowBox[{"const", " ", "eig"}], "]"}]}], "+", 
            RowBox[{"Tr", "[", 
             RowBox[{
              RowBox[{"PseudoInverse", "[", "SigmaYX", "]"}], ".", 
              RowBox[{"(", 
               RowBox[{"S", "+", 
                RowBox[{"Outer", "[", 
                 RowBox[{"Times", ",", 
                  RowBox[{"m", "-", "mueYX"}], ",", 
                  RowBox[{"m", "-", "mueYX"}]}], "]"}]}], ")"}]}], "]"}]}], 
           ")"}]}]}]}]}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}]}], "Input",\

 PageWidth->Infinity,
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 CellLabel->"In[157]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Implementierung / deterministische Regressoren", "Section",
 PageWidth->Infinity,
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontVariations->{"CompatibilityType"->0}],

Cell[BoxData[
 RowBox[{
  RowBox[{"LISRELsimul", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"n_", ",", "Generator_", ",", "X_"}], "}"}], ",", "Theta_", ",", 
    
    RowBox[{"{", 
     RowBox[{"System_", ",", "ThetaFix_"}], "}"}], ",", 
    RowBox[{"comp_", ":", "True"}]}], "]"}], ":=", "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "p", ",", "q", ",", "beta", ",", "gamma", ",", "B1", ",", "sigmazeta", 
      ",", "ZETA", ",", "ETA", ",", "sigmaepsilon", ",", "lambdaeta", ",", 
      "taueta", ",", "kp", ",", "EPSILON", ",", "kq", ",", "Y"}], "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"beta", ",", "gamma", ",", "sigmazeta"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"lambdaeta", ",", "taueta", ",", "sigmaepsilon"}], "}"}]}], 
       "}"}], "=", 
      RowBox[{"System", "[", 
       RowBox[{"Theta", ",", "ThetaFix"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"beta", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"1", ";;", "10"}], ",", 
            RowBox[{"1", ";;", "10"}]}], "]"}], "]"}], "//", "MatrixForm"}], "//",
         "Print"}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"gamma", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"1", ";;", "10"}], ",", 
            RowBox[{"1", ";;", "10"}]}], "]"}], "]"}], "//", "MatrixForm"}], "//",
         "Print"}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"sigmazeta", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"1", ";;", "10"}], ",", 
            RowBox[{"1", ";;", "10"}]}], "]"}], "]"}], "//", "MatrixForm"}], "//",
         "Print"}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"lambdaeta", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"1", ";;", "10"}], ",", 
            RowBox[{"1", ";;", "10"}]}], "]"}], "]"}], "//", "MatrixForm"}], "//",
         "Print"}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"taueta", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"1", ";;", "10"}], ",", 
            RowBox[{"1", ";;", "10"}]}], "]"}], "]"}], "//", "MatrixForm"}], "//",
         "Print"}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"sigmaepsilon", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"1", ";;", "10"}], ",", 
            RowBox[{"1", ";;", "10"}]}], "]"}], "]"}], "//", "MatrixForm"}], "//",
         "Print"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"Return", "[", "]"}], ";"}], "\[IndentingNewLine]", "*)"}], 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p", ",", "q"}], "}"}], "=", 
      RowBox[{"Dimensions", "[", "gamma", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"B1", "=", 
      RowBox[{
       RowBox[{"IdentityMatrix", "[", "p", "]"}], "-", "beta"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{"comp", ",", 
       RowBox[{"RandomGauss", "[", 
        RowBox[{
         RowBox[{"Shape", "[", 
          RowBox[{"0", ",", "q"}], "]"}], ",", 
         RowBox[{"IdentityMatrix", "[", "q", "]"}], ",", "n", ",", 
         "Generator"}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"sigmazeta", "=", 
      RowBox[{"symmetric", "[", "sigmazeta", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ZETA", "=", 
      RowBox[{"RandomGauss", "[", 
       RowBox[{
        RowBox[{"Shape", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "p", "}"}]}], "]"}], ",", "sigmazeta", ",", "n", ",", 
        "Generator"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ETA", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"X", ".", 
          RowBox[{"Transpose", "[", "gamma", "]"}]}], "+", "ZETA"}], ")"}], 
       ".", 
       RowBox[{"Transpose", "[", 
        RowBox[{"Inverse", "[", "B1", "]"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"sigmaepsilon", "=", 
      RowBox[{"symmetric", "[", "sigmaepsilon", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"kp", "=", 
      RowBox[{"Length", "[", "lambdaeta", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"EPSILON", "=", 
      RowBox[{"RandomGauss", "[", 
       RowBox[{
        RowBox[{"Shape", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "kp", "}"}]}], "]"}], ",", "sigmaepsilon", ",", "n", 
        ",", "Generator"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Y", "=", 
      RowBox[{
       RowBox[{"ETA", ".", 
        RowBox[{"Transpose", "[", "lambdaeta", "]"}]}], "+", 
       RowBox[{"X", ".", 
        RowBox[{"Transpose", "[", "taueta", "]"}]}], "+", "EPSILON"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Y", ",", "X", ",", "ETA"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ZETA", ",", "EPSILON"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"beta", ",", "gamma", ",", "sigmazeta"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"lambdaeta", ",", "taueta", ",", "sigmaepsilon"}], "}"}]}], 
        "}"}]}], "}"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 PageWidth->Infinity,
 CellMargins->{{19.625, 0}, {Inherited, Inherited}},
 InitializationCell->True,
 CellSize->{2319, Inherited},
 CellChangeTimes->{{3.460262921678924*^9, 3.460262922843543*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 CellLabel->"In[288]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"LISRELlik", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"S_", ",", "m_", ",", "n_", ",", "Deterministisch_"}], "}"}], 
    ",", "Theta_", ",", 
    RowBox[{"{", 
     RowBox[{"System_", ",", "ThetaFix_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"Singular_", ",", 
      RowBox[{"const_", ":", 
       RowBox[{"2", " ", "\[Pi]"}]}]}], "}"}]}], "]"}], ":=", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "p", ",", "q", ",", "gamma", ",", "beta", ",", "B1", ",", "sigmazeta", 
      ",", "sigmaepsilon", ",", "lambdaeta", ",", "kp", ",", "kq", ",", 
      "\[IndentingNewLine]", "           ", "B11", ",", "sigmaeta", ",", 
      "sigmay", ",", "M", ",", "My", ",", "Mx", ",", "Myx", ",", "MyxCs", ",",
       "CMxy", ",", "l", ",", "C", ",", "Cs", ",", "eig"}], "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"beta", ",", "gamma", ",", "sigmazeta"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"lambdaeta", ",", "taueta", ",", "sigmaepsilon"}], "}"}]}], 
       "}"}], "=", 
      RowBox[{"System", "[", 
       RowBox[{"Theta", ",", "ThetaFix"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p", ",", "q"}], "}"}], "=", 
      RowBox[{"Dimensions", "[", "gamma", "]"}]}], ";", "  ", 
     "\[IndentingNewLine]", 
     RowBox[{"B1", "=", 
      RowBox[{
       RowBox[{"IdentityMatrix", "[", "p", "]"}], "-", "beta"}]}], ";", "  ", 
     "\[IndentingNewLine]", 
     RowBox[{"kp", "=", 
      RowBox[{"Length", "[", "lambdaeta", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"kq", "=", "q"}], ";", "\[IndentingNewLine]", 
     RowBox[{"B11", "=", 
      RowBox[{"Inverse", "[", "B1", "]"}]}], ";", " ", "\[IndentingNewLine]", 
     
     RowBox[{"sigmaeta", "=", 
      RowBox[{"B11", ".", "sigmazeta", ".", 
       RowBox[{"Transpose", "[", "B11", "]"}]}]}], ";", "    ", 
     "\[IndentingNewLine]", 
     RowBox[{"sigmay", "=", 
      RowBox[{
       RowBox[{"lambdaeta", ".", "sigmaeta", ".", 
        RowBox[{"Transpose", "[", "lambdaeta", "]"}]}], "+", 
       "sigmaepsilon"}]}], ";", " ", "\[IndentingNewLine]", 
     RowBox[{"M", "=", 
      RowBox[{"S", "+", 
       RowBox[{"Outer", "[", 
        RowBox[{"Times", ",", "m", ",", "m"}], "]"}]}]}], ";", "  ", 
     "\[IndentingNewLine]", 
     RowBox[{"My", "=", 
      RowBox[{"M", "\[LeftDoubleBracket]", 
       RowBox[{
        RowBox[{"Range", "[", "kp", "]"}], ",", 
        RowBox[{"Range", "[", "kp", "]"}]}], "\[RightDoubleBracket]"}]}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"Mx", "=", 
      RowBox[{"M", "\[LeftDoubleBracket]", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"kp", "+", "1"}], ",", 
          RowBox[{"kp", "+", "kq"}]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"kp", "+", "1"}], ",", 
          RowBox[{"kp", "+", "kq"}]}], "]"}]}], "\[RightDoubleBracket]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"Myx", "=", 
      RowBox[{"M", "\[LeftDoubleBracket]", 
       RowBox[{
        RowBox[{"Range", "[", "kp", "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"kp", "+", "1"}], ",", 
          RowBox[{"kp", "+", "kq"}]}], "]"}]}], "\[RightDoubleBracket]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"C", "=", 
      RowBox[{
       RowBox[{"lambdaeta", ".", "B11", ".", "gamma"}], "+", "taueta"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"Cs", "=", 
      RowBox[{"Transpose", "[", "C", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"MyxCs", "=", 
      RowBox[{"Myx", ".", "Cs"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"CMxy", "=", 
      RowBox[{"Transpose", "[", "MyxCs", "]"}]}], ";", "  ", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"!", "Singular"}], ",", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"l", "=", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", "n", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"kp", " ", 
            RowBox[{"Log", "[", "const", "]"}]}], "+", 
           RowBox[{"Log", "[", 
            RowBox[{"Det", "[", "sigmay", "]"}], "]"}], "+", 
           RowBox[{"Tr", "[", 
            RowBox[{
             RowBox[{"Inverse", "[", "sigmay", "]"}], ".", 
             RowBox[{"(", 
              RowBox[{"My", "+", 
               RowBox[{"C", ".", "Mx", ".", "Cs"}], "-", "MyxCs", "-", 
               "CMxy"}], ")"}]}], "]"}]}], ")"}]}]}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"eig", "=", 
         RowBox[{"Eigenvalues", "[", "sigmay", "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"eig", "=", 
         RowBox[{"Select", "[", 
          RowBox[{"eig", ",", 
           RowBox[{
            RowBox[{"#1", ">", "0"}], "&"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"l", "=", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", "n", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Plus", "@@", 
             RowBox[{"Log", "[", 
              RowBox[{"const", " ", "eig"}], "]"}]}], "+", 
            RowBox[{"Tr", "[", 
             RowBox[{
              RowBox[{"PseudoInverse", "[", "sigmay", "]"}], ".", 
              RowBox[{"(", 
               RowBox[{"My", "+", 
                RowBox[{"C", ".", "Mx", ".", "Cs"}], "-", "MyxCs", "-", 
                "CMxy"}], ")"}]}], "]"}]}], ")"}]}]}]}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 PageWidth->Infinity,
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 CellLabel->"In[160]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"LISRELDet", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"S_", ",", "m_", ",", "n_", ",", "Deterministisch_"}], "}"}], 
    ",", "Theta_", ",", 
    RowBox[{"{", 
     RowBox[{"System_", ",", "ThetaFix_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"Singular_", ",", 
      RowBox[{"const_", ":", 
       RowBox[{"2", " ", "\[Pi]"}]}]}], "}"}]}], "]"}], ":=", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "p", ",", "q", ",", "gamma", ",", "beta", ",", "B1", ",", "sigmazeta", 
      ",", "sigmaepsilon", ",", "lambdaeta", ",", "kp", ",", "kq", ",", 
      "\[IndentingNewLine]", "           ", "B11", ",", "sigmaeta", ",", 
      "sigmay", ",", "M", ",", "My", ",", "Mx", ",", "Myx", ",", "MyxCs", ",",
       "CMxy", ",", "l", ",", "C", ",", "Cs", ",", "eig"}], "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"beta", ",", "gamma", ",", "sigmazeta"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"lambdaeta", ",", "taueta", ",", "sigmaepsilon"}], "}"}]}], 
       "}"}], "=", 
      RowBox[{"System", "[", 
       RowBox[{"Theta", ",", "ThetaFix"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p", ",", "q"}], "}"}], "=", 
      RowBox[{"Dimensions", "[", "gamma", "]"}]}], ";", "  ", 
     "\[IndentingNewLine]", 
     RowBox[{"B1", "=", 
      RowBox[{
       RowBox[{"IdentityMatrix", "[", "p", "]"}], "-", "beta"}]}], ";", "  ", 
     "\[IndentingNewLine]", 
     RowBox[{"kp", "=", 
      RowBox[{"Length", "[", "lambdaeta", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"kq", "=", "q"}], ";", "\[IndentingNewLine]", 
     RowBox[{"B11", "=", 
      RowBox[{"Inverse", "[", "B1", "]"}]}], ";", " ", "\[IndentingNewLine]", 
     
     RowBox[{"sigmaeta", "=", 
      RowBox[{"B11", ".", "sigmazeta", ".", 
       RowBox[{"Transpose", "[", "B11", "]"}]}]}], ";", "    ", 
     "\[IndentingNewLine]", 
     RowBox[{"sigmay", "=", 
      RowBox[{
       RowBox[{"lambdaeta", ".", "sigmaeta", ".", 
        RowBox[{"Transpose", "[", "lambdaeta", "]"}]}], "+", 
       "sigmaepsilon"}]}], ";", " ", "\[IndentingNewLine]", 
     RowBox[{"M", "=", 
      RowBox[{"S", "+", 
       RowBox[{"Outer", "[", 
        RowBox[{"Times", ",", "m", ",", "m"}], "]"}]}]}], ";", "  ", 
     "\[IndentingNewLine]", 
     RowBox[{"My", "=", 
      RowBox[{"M", "\[LeftDoubleBracket]", 
       RowBox[{
        RowBox[{"Range", "[", "kp", "]"}], ",", 
        RowBox[{"Range", "[", "kp", "]"}]}], "\[RightDoubleBracket]"}]}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"Mx", "=", 
      RowBox[{"M", "\[LeftDoubleBracket]", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"kp", "+", "1"}], ",", 
          RowBox[{"kp", "+", "kq"}]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"kp", "+", "1"}], ",", 
          RowBox[{"kp", "+", "kq"}]}], "]"}]}], "\[RightDoubleBracket]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"Myx", "=", 
      RowBox[{"M", "\[LeftDoubleBracket]", 
       RowBox[{
        RowBox[{"Range", "[", "kp", "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"kp", "+", "1"}], ",", 
          RowBox[{"kp", "+", "kq"}]}], "]"}]}], "\[RightDoubleBracket]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"C", "=", 
      RowBox[{
       RowBox[{"lambdaeta", ".", "B11", ".", "gamma"}], "+", "taueta"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"Cs", "=", 
      RowBox[{"Transpose", "[", "C", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"MyxCs", "=", 
      RowBox[{"Myx", ".", "Cs"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"CMxy", "=", 
      RowBox[{"Transpose", "[", "MyxCs", "]"}]}], ";", "  ", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"l", "=", 
      RowBox[{"Det", "[", "sigmay", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"eig", "=", 
      RowBox[{"Eigenvalues", "[", "sigmay", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"l", ",", "eig"}], "}"}]}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 PageWidth->Infinity,
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 CellLabel->"In[78]:="],

Cell[BoxData[{
 RowBox[{"LISRELLeastSquares", "//", "Clear"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LISRELLeastSquares", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"S_", ",", "m_", ",", "n_", ",", "Deterministisch_"}], "}"}], 
    ",", "Theta_", ",", 
    RowBox[{"{", 
     RowBox[{"System_", ",", "ThetaFix_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"Singular_", ",", 
      RowBox[{"const_", ":", 
       RowBox[{"2", " ", "\[Pi]"}]}]}], "}"}]}], "]"}], ":=", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "p", ",", "q", ",", "gamma", ",", "beta", ",", "B1", ",", "sigmazeta", 
      ",", "sigmaepsilon", ",", "lambdaeta", ",", "kp", ",", "kq", ",", 
      "\[IndentingNewLine]", "           ", "B11", ",", "sigmaeta", ",", 
      "sigmay", ",", "M", ",", "My", ",", "Mx", ",", "Myx", ",", "MyxCs", ",",
       "CMxy", ",", "l", ",", "C", ",", "Cs", ",", "EM", ",", "dM"}], "}"}], 
    ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"beta", ",", "gamma", ",", "sigmazeta"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"lambdaeta", ",", "taueta", ",", "sigmaepsilon"}], "}"}]}], 
       "}"}], "=", 
      RowBox[{"System", "[", 
       RowBox[{"Theta", ",", "ThetaFix"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p", ",", "q"}], "}"}], "=", 
      RowBox[{"Dimensions", "[", "gamma", "]"}]}], ";", "  ", 
     "\[IndentingNewLine]", 
     RowBox[{"B1", "=", 
      RowBox[{
       RowBox[{"IdentityMatrix", "[", "p", "]"}], "-", "beta"}]}], ";", "  ", 
     "\[IndentingNewLine]", 
     RowBox[{"kp", "=", 
      RowBox[{"Length", "[", "lambdaeta", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"kq", "=", "q"}], ";", "\[IndentingNewLine]", 
     RowBox[{"B11", "=", 
      RowBox[{"Inverse", "[", "B1", "]"}]}], ";", " ", "\[IndentingNewLine]", 
     
     RowBox[{"sigmaeta", "=", 
      RowBox[{"B11", ".", "sigmazeta", ".", 
       RowBox[{"Transpose", "[", "B11", "]"}]}]}], ";", "    ", 
     "\[IndentingNewLine]", 
     RowBox[{"sigmay", "=", 
      RowBox[{
       RowBox[{"lambdaeta", ".", "sigmaeta", ".", 
        RowBox[{"Transpose", "[", "lambdaeta", "]"}]}], "+", 
       "sigmaepsilon"}]}], ";", " ", "\[IndentingNewLine]", 
     RowBox[{"M", "=", 
      RowBox[{"S", "+", 
       RowBox[{"Outer", "[", 
        RowBox[{"Times", ",", "m", ",", "m"}], "]"}]}]}], ";", "  ", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"My", "=", 
        RowBox[{"M", "\[LeftDoubleBracket]", 
         RowBox[{
          RowBox[{"Range", "[", "kp", "]"}], ",", 
          RowBox[{"Range", "[", "kp", "]"}]}], "\[RightDoubleBracket]"}]}], 
       ";"}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"Mx", "=", 
      RowBox[{"M", "\[LeftDoubleBracket]", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"kp", "+", "1"}], ",", 
          RowBox[{"kp", "+", "kq"}]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"kp", "+", "1"}], ",", 
          RowBox[{"kp", "+", "kq"}]}], "]"}]}], "\[RightDoubleBracket]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Myx", "=", 
        RowBox[{"M", "\[LeftDoubleBracket]", 
         RowBox[{
          RowBox[{"Range", "[", "kp", "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"kp", "+", "1"}], ",", 
            RowBox[{"kp", "+", "kq"}]}], "]"}]}], "\[RightDoubleBracket]"}]}],
        ";"}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"C", "=", 
      RowBox[{
       RowBox[{"lambdaeta", ".", "B11", ".", "gamma"}], "+", "taueta"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"Cs", "=", 
      RowBox[{"Transpose", "[", "C", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"CMx", "=", 
      RowBox[{"C", ".", "Mx"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"EM", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"sigmay", "+", 
           RowBox[{"CMx", ".", "Cs"}]}], ")"}], "~", "ii", "~", "CMx"}], 
        ")"}], "~", "vv", "~", "\[IndentingNewLine]", "         ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Transpose", "[", "CMx", "]"}], "~", "ii", "~", "Mx"}], 
        ")"}]}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"dM", "=", 
      RowBox[{"(", 
       RowBox[{"M", "-", "EM"}], ")"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"yquer", "=", 
      RowBox[{"m", "[", 
       RowBox[{"[", 
        RowBox[{"Range", "[", "kp", "]"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"xquer", "=", 
      RowBox[{"m", "[", 
       RowBox[{"[", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"kp", "+", "1"}], ",", 
          RowBox[{"kp", "+", "kq"}]}], "]"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"dm", "=", 
      RowBox[{"yquer", "-", 
       RowBox[{"C", ".", "xquer"}]}]}], ";", " ", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"E", "[", "yquer", "]"}], "=", 
       RowBox[{"C", ".", "xquer"}]}], "*)"}], "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"l", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "n"}], "/", "2"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Tr", "[", 
          RowBox[{"dM", ".", 
           RowBox[{"(", 
            RowBox[{"dM", "//", "Transpose"}], ")"}]}], "]"}], "+", 
         RowBox[{"dm", ".", "dm"}]}], ")"}]}]}]}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "]"}]}]}], "Input",
 PageWidth->Infinity,
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 CellLabel->"In[444]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"??", "Tr"}]], "Input",
 CellLabel->"In[579]:="],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\\!\\(\\*RowBox[{\\\"Tr\\\", \\\"[\\\", \
StyleBox[\\\"list\\\", \\\"TI\\\"], \\\"]\\\"}]\\) finds the trace of the \
matrix or tensor \\!\\(\\*StyleBox[\\\"list\\\", \\\"TI\\\"]\\). \
\\n\\!\\(\\*RowBox[{\\\"Tr\\\", \\\"[\\\", RowBox[{StyleBox[\\\"list\\\", \
\\\"TI\\\"], \\\",\\\", StyleBox[\\\"f\\\", \\\"TI\\\"]}], \\\"]\\\"}]\\) \
finds a generalized trace, combining terms with \\!\\(\\*StyleBox[\\\"f\\\", \
\\\"TI\\\"]\\) instead of Plus. \\n\\!\\(\\*RowBox[{\\\"Tr\\\", \\\"[\\\", \
RowBox[{StyleBox[\\\"list\\\", \\\"TI\\\"], \\\",\\\", StyleBox[\\\"f\\\", \\\
\"TI\\\"], \\\",\\\", StyleBox[\\\"n\\\", \\\"TI\\\"]}], \\\"]\\\"}]\\) goes \
down to level \\!\\(\\*StyleBox[\\\"n\\\", \\\"TI\\\"]\\) in \
\\!\\(\\*StyleBox[\\\"list\\\", \\\"TI\\\"]\\). \"\>", "MSG"], " ", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Tr"]}]], "Print", "PrintUsage",
 CellTags->"Info3455273716-9021704"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {
     RowBox[{
      RowBox[{"Attributes", "[", "Tr", "]"}], "=", 
      RowBox[{"{", "Protected", "}"}]}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition["Tr"],
  Editable->False]], "Print",
 CellTags->"Info3455273716-9021704"]
}, Open  ]],

Cell[BoxData[{
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"NotPosition", "[", 
      RowBox[{"List_", ",", "pattern_"}], "]"}], " ", ":=", " ", "\n", "\t", 
     RowBox[{"Delete", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"List", "//", "Length"}], "//", "Range"}], ",", 
       RowBox[{"Position", "[", 
        RowBox[{"List", ",", "pattern"}], "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]"}],
  FontWeight->"Plain"], "\[IndentingNewLine]", 
 RowBox[{"NormalCorrelation", "//", "Clear"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NormalCorrelation", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Y_", ",", "X_", ",", 
      RowBox[{"miss_:", "-", "9"}]}], "}"}], ",", "Theta_", ",", 
    RowBox[{"{", 
     RowBox[{"System_", ",", "ThetaFix_"}], "}"}]}], "]"}], ":=", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "p", ",", "q", ",", "beta", ",", "gamma", ",", "sigmazeta", ",", 
      "lambdaeta", ",", "taueta", ",", "sigmaepsilon", ",", 
      "\[IndentingNewLine]", "           ", "B1", ",", "B11", ",", "mueeta", 
      ",", "sigmaeta", ",", "C", ",", "mueY", ",", "sel", ",", 
      "\[IndentingNewLine]", "           ", "nn", ",", "mueetay", ",", 
      "sigmaetay", ",", "seln", ",", "\[IndentingNewLine]", "            ", 
      "lambdaetan", ",", "inno", ",", "sl", ",", "sigmaYn", ",", "gain", ",", 
      "n"}], "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"beta", ",", "gamma", ",", "sigmazeta"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"lambdaeta", ",", "taueta", ",", "sigmaepsilon"}], "}"}]}], 
       "}"}], "=", 
      RowBox[{"System", "[", 
       RowBox[{"Theta", ",", "ThetaFix"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p", ",", "q"}], "}"}], "=", 
      RowBox[{"Dimensions", "[", "gamma", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"B1", "=", 
      RowBox[{
       RowBox[{"IdentityMatrix", "[", "p", "]"}], "-", "beta"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"B11", "=", 
      RowBox[{"Inverse", "[", "B1", "]"}]}], ";", " ", "\[IndentingNewLine]", 
     
     RowBox[{"sigmazeta", "=", 
      RowBox[{"symmetric", "[", "sigmazeta", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"mueeta", "=", 
      RowBox[{"X", ".", 
       RowBox[{"Transpose", "[", "gamma", "]"}], ".", 
       RowBox[{"Transpose", "[", "B11", "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"sigmaeta", "=", 
      RowBox[{"B11", ".", "sigmazeta", ".", 
       RowBox[{"Transpose", "[", "B11", "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"sigmaepsilon", "=", 
      RowBox[{"symmetric", "[", "sigmaepsilon", "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"C", "=", 
      RowBox[{
       RowBox[{"lambdaeta", ".", "B11", ".", "gamma"}], "+", "taueta"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"mueY", "=", 
      RowBox[{"X", ".", 
       RowBox[{"(", 
        RowBox[{"C", "//", "Transpose"}], ")"}]}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"sel", " ", "=", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"NotPosition", "[", 
          RowBox[{"#", ",", "miss"}], "]"}], "&"}], ",", "Y"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"nn", "=", 
      RowBox[{"Y", "//", "Length"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"mueetay", ",", "sigmaetay"}], "}"}], "=", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Table", "[", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"seln", "=", 
           RowBox[{"sel", "[", 
            RowBox[{"[", "n", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"lambdaetan", "=", 
           RowBox[{"lambdaeta", "[", 
            RowBox[{"[", 
             RowBox[{"seln", ",", "All"}], "]"}], "]"}]}], ";", "\n", 
          "           ", 
          RowBox[{"inno", "=", 
           RowBox[{
            RowBox[{"Y", "[", 
             RowBox[{"[", 
              RowBox[{"n", ",", "seln"}], "]"}], "]"}], "-", 
            RowBox[{"mueY", "[", 
             RowBox[{"[", 
              RowBox[{"n", ",", "seln"}], "]"}], "]"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"sl", "=", " ", 
           RowBox[{"sigmaeta", ".", 
            RowBox[{"(", 
             RowBox[{"lambdaetan", "//", "Transpose"}], ")"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"sigmaYn", "=", 
           RowBox[{
            RowBox[{"lambdaetan", ".", "sl"}], "+", 
            RowBox[{"sigmaepsilon", "[", 
             RowBox[{"[", 
              RowBox[{"seln", ",", "seln"}], "]"}], "]"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"gain", "=", "  ", 
           RowBox[{"sl", ".", 
            RowBox[{"Inverse", "[", "sigmaYn", "]"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"{", " ", 
           RowBox[{
            RowBox[{
             RowBox[{"mueeta", "[", 
              RowBox[{"[", "n", "]"}], "]"}], " ", "+", " ", 
             RowBox[{"gain", ".", "inno"}]}], ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"IdentityMatrix", "[", "p", "]"}], "-", 
               RowBox[{"gain", ".", "lambdaetan"}]}], ")"}], ".", 
             "sigmaeta"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"n", ",", "nn"}], "}"}]}], "]"}], "//", "Transpose"}]}], 
     ";", "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"mueetay", ",", "sigmaetay"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"mueeta", ",", "sigmaeta"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"mueY", ",", "sigmaY"}], "}"}]}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]}], "Input",
 PageWidth->Infinity,
 CellMargins->{{20.375, 0}, {Inherited, Inherited}},
 InitializationCell->True,
 CellSize->{2319, Inherited},
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 CellLabel->"In[480]:="],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Standard", "[", 
    RowBox[{"Dbeta_", ",", "COV_"}], "]"}], ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "X", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"X", "=", 
       RowBox[{"Map", "[", 
        RowBox[{"Flatten", ",", "Dbeta"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Shape", "[", 
       RowBox[{
        RowBox[{"Sqrt", "@", 
         RowBox[{"VecDiag", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"X", "//", "Transpose"}], ")"}], ".", "COV", ".", "X"}], 
          "]"}]}], ",", 
        RowBox[{
         RowBox[{"Dbeta", "//", "Dimensions"}], "//", "Rest"}]}], "]"}]}]}], 
    "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DeltaTheorem", "[", 
   RowBox[{"X_", ",", 
    RowBox[{"{", 
     RowBox[{"Theta_", ",", "COV_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"System_", ",", "ThetaFix_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"labely_:", "None"}], ",", 
      RowBox[{"labeleta_:", "None"}], ",", 
      RowBox[{"labelx_:", "None"}]}], "}"}]}], "]"}], ":=", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "inc", ",", "system", ",", "Dsystem", ",", "beta", ",", "gamma", ",", 
      "sigmazeta", ",", "lambdaeta", ",", "taueta", ",", "sigmaepsilon", ",", 
      "\[IndentingNewLine]", "            ", "B1", ",", "B11", ",", "mueeta", 
      ",", "sigmaeta", ",", "sigma"}], "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"beta", ",", "gamma", ",", "sigmazeta"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"lambdaeta", ",", "taueta", ",", "sigmaepsilon"}], "}"}]}], 
       "}"}], "=", " ", 
      RowBox[{"system", "=", 
       RowBox[{"System", "[", 
        RowBox[{"Theta", ",", "ThetaFix"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", "  ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p", ",", "q"}], "}"}], "=", 
      RowBox[{"Dimensions", "[", "gamma", "]"}]}], ";", "\[IndentingNewLine]",
      "   ", 
     RowBox[{"B1", "=", 
      RowBox[{
       RowBox[{"IdentityMatrix", "[", "p", "]"}], "-", "beta"}]}], ";", 
     "\[IndentingNewLine]", "   ", 
     RowBox[{"B11", "=", 
      RowBox[{"Inverse", "[", "B1", "]"}]}], ";", " ", "\[IndentingNewLine]", 
     "   ", 
     RowBox[{"sigmazeta", "=", 
      RowBox[{"symmetric", "[", "sigmazeta", "]"}]}], ";", 
     "\[IndentingNewLine]", "   ", 
     RowBox[{"mueeta", "=", 
      RowBox[{"X", ".", 
       RowBox[{"Transpose", "[", "gamma", "]"}], ".", 
       RowBox[{"Transpose", "[", "B11", "]"}]}]}], ";", "\[IndentingNewLine]",
      "   ", 
     RowBox[{"sigmaeta", "=", 
      RowBox[{"B11", ".", "sigmazeta", ".", 
       RowBox[{"Transpose", "[", "B11", "]"}]}]}], ";", "\[IndentingNewLine]",
      "   ", 
     RowBox[{"sigmaepsilon", "=", 
      RowBox[{"symmetric", "[", "sigmaepsilon", "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", "  ", 
     RowBox[{
     "Print", "[", "\"\<System Matrices (Maximum Likelihood)\>\"", "]"}], ";",
      "\[IndentingNewLine]", "\[IndentingNewLine]", "  ", 
     RowBox[{
      RowBox[{"beta", "//", 
       RowBox[{
        RowBox[{"MatrixForm", "[", 
         RowBox[{"#", ",", 
          RowBox[{"TableHeadings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"labeleta", ",", "labeleta"}], "}"}]}]}], "]"}], "&"}]}], 
      "                   ", "//", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<beta\\n\>\"", ",", "#"}], "]"}], "&"}]}], ";", 
     "\[IndentingNewLine]", "  ", 
     RowBox[{
      RowBox[{"gamma", "//", 
       RowBox[{
        RowBox[{"MatrixForm", "[", 
         RowBox[{"#", ",", 
          RowBox[{"TableHeadings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"labeleta", ",", "labelx"}], "}"}]}]}], "]"}], "&"}]}], 
      "                     ", "//", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<gamma\\n\>\"", ",", "#"}], "]"}], "&"}]}], ";", 
     "\[IndentingNewLine]", "  ", 
     RowBox[{
      RowBox[{"sigmazeta", "//", 
       RowBox[{
        RowBox[{"MatrixForm", "[", 
         RowBox[{"#", ",", 
          RowBox[{"TableHeadings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"labeleta", ",", "labeleta"}], "}"}]}]}], "]"}], "&"}]}], 
      "       ", "//", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<sigmazeta\\n\>\"", ",", "#"}], "]"}], "&"}]}], ";", 
     "\[IndentingNewLine]", "  ", 
     RowBox[{
      RowBox[{"lambdaeta", "//", 
       RowBox[{
        RowBox[{"MatrixForm", "[", 
         RowBox[{"#", ",", 
          RowBox[{"TableHeadings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"labely", ",", "labeleta"}], "}"}]}]}], "]"}], "&"}]}], 
      "            ", "//", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<lambdaeta\\n\>\"", ",", "#"}], "]"}], "&"}]}], ";", 
     "\[IndentingNewLine]", "  ", 
     RowBox[{
      RowBox[{"taueta", "//", 
       RowBox[{
        RowBox[{"MatrixForm", "[", 
         RowBox[{"#", ",", 
          RowBox[{"TableHeadings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"labely", ",", "labeleta"}], "}"}]}]}], "]"}], "&"}]}], 
      "                  ", "//", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<taueta\\n\>\"", ",", "#"}], "]"}], "&"}]}], ";", 
     "\[IndentingNewLine]", "  ", 
     RowBox[{
      RowBox[{"sigmaepsilon", "//", 
       RowBox[{
        RowBox[{"MatrixForm", "[", 
         RowBox[{"#", ",", 
          RowBox[{"TableHeadings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"labely", ",", "labely"}], "}"}]}]}], "]"}], "&"}]}], 
      "         ", "//", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<sigmaepsilon\\n\>\"", ",", "#"}], "]"}], "&"}]}], ";", 
     "\[IndentingNewLine]", "  ", "\[IndentingNewLine]", " ", 
     "\[IndentingNewLine]", "  ", 
     RowBox[{
     "Print", "[", "\"\<\\nAsymptotic Standard Errors (Delta Theorem)\>\"", 
      "]"}], ";", "\n", "\[IndentingNewLine]", "    ", 
     RowBox[{"inc", "=", 
      RowBox[{
       RowBox[{"$MachineEpsilon", "^", ".5"}], " ", "*", " ", 
       RowBox[{"Abs", "[", "Theta", "]"}]}]}], ";", "\n", "       ", "\n", 
     "         ", 
     RowBox[{"Dsystem", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"System", "[", 
              RowBox[{
               RowBox[{"GRIDI", "[", 
                RowBox[{"Theta", ",", "i", ",", " ", "inc"}], "]"}], ",", 
               RowBox[{"{", "}"}]}], "]"}], "-", "system"}], ",", "1"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "u"}], "}"}]}], "]"}], "/", "inc"}], "//", 
       "Transpose"}]}], ";", "\n", "\[IndentingNewLine]", "   ", 
     RowBox[{"stdbeta", "=", " ", 
      RowBox[{"Standard", "[", 
       RowBox[{
        RowBox[{"Dsystem", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "COV"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "   ", 
     RowBox[{
      RowBox[{"stdbeta", "//", 
       RowBox[{
        RowBox[{"MatrixForm", "[", 
         RowBox[{"#", ",", 
          RowBox[{"TableHeadings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"labeleta", ",", "labeleta"}], "}"}]}]}], "]"}], "&"}]}], 
      "//", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<std(beta)\\n\>\"", ",", "#"}], "]"}], "&"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", "   ", 
     RowBox[{"stdgamma", "=", " ", 
      RowBox[{"Standard", "[", 
       RowBox[{
        RowBox[{"Dsystem", "[", 
         RowBox[{"[", "2", "]"}], "]"}], ",", "COV"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "   ", 
     RowBox[{
      RowBox[{"stdgamma", "//", 
       RowBox[{
        RowBox[{"MatrixForm", "[", 
         RowBox[{"#", ",", 
          RowBox[{"TableHeadings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"labeleta", ",", "labelx"}], "}"}]}]}], "]"}], "&"}]}], "//", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<std(gamma)\\n\>\"", ",", "#"}], "]"}], "&"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", "   ", 
     RowBox[{"stdsigmazeta", "=", " ", 
      RowBox[{"Standard", "[", 
       RowBox[{
        RowBox[{"Dsystem", "[", 
         RowBox[{"[", "3", "]"}], "]"}], ",", "COV"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "   ", 
     RowBox[{
      RowBox[{"stdsigmazeta", "//", 
       RowBox[{
        RowBox[{"MatrixForm", "[", 
         RowBox[{"#", ",", 
          RowBox[{"TableHeadings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"labeleta", ",", "labeleta"}], "}"}]}]}], "]"}], "&"}]}], 
      "//", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<std(sigmazeta)\\n\>\"", ",", "#"}], "]"}], "&"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", "   ", 
     RowBox[{"stdlambdaeta", "=", 
      RowBox[{"Standard", "[", 
       RowBox[{
        RowBox[{"Dsystem", "[", 
         RowBox[{"[", "4", "]"}], "]"}], ",", "COV"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "   ", 
     RowBox[{
      RowBox[{"stdlambdaeta", "//", 
       RowBox[{
        RowBox[{"MatrixForm", "[", 
         RowBox[{"#", ",", 
          RowBox[{"TableHeadings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"labely", ",", "labeleta"}], "}"}]}]}], "]"}], "&"}]}], "//", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<std(lambdaeta)\\n\>\"", ",", "#"}], "]"}], "&"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", "   ", 
     RowBox[{"stdtaueta", "=", 
      RowBox[{"Standard", "[", 
       RowBox[{
        RowBox[{"Dsystem", "[", 
         RowBox[{"[", "5", "]"}], "]"}], ",", "COV"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "   ", 
     RowBox[{
      RowBox[{"stdtaueta", "//", 
       RowBox[{
        RowBox[{"MatrixForm", "[", 
         RowBox[{"#", ",", 
          RowBox[{"TableHeadings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"labely", ",", "labeleta"}], "}"}]}]}], "]"}], "&"}]}], "//", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<std(taueta)\\n\>\"", ",", "#"}], "]"}], "&"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", "   ", 
     RowBox[{"stdsigmaepsilon", "=", 
      RowBox[{"Standard", "[", 
       RowBox[{
        RowBox[{"Dsystem", "[", 
         RowBox[{"[", "6", "]"}], "]"}], ",", "COV"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "   ", 
     RowBox[{
      RowBox[{"stdsigmaepsilon", "//", 
       RowBox[{
        RowBox[{"MatrixForm", "[", 
         RowBox[{"#", ",", 
          RowBox[{"TableHeadings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"labely", ",", "labely"}], "}"}]}]}], "]"}], "&"}]}], "//", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<std(sigmaepsilon)\\n\>\"", ",", "#"}], "]"}], "&"}]}], 
     ";", "\[IndentingNewLine]", "\[IndentingNewLine]", "   ", 
     RowBox[{
     "Print", "[", "\"\<\\nMoments of Endogenous Variables (eta)\>\"", "]"}], 
     ";", "\[IndentingNewLine]", "\[IndentingNewLine]", "  ", 
     RowBox[{
      RowBox[{
       RowBox[{"mueeta", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "//", 
       RowBox[{
        RowBox[{"MatrixForm", "[", 
         RowBox[{"#", ",", 
          RowBox[{"TableHeadings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"labeleta", ",", "None"}], "}"}]}]}], "]"}], "&"}]}], 
      "           ", "//", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<mueeta[[1]]\\n\>\"", ",", "#"}], "]"}], "&"}]}], ";", 
     "\[IndentingNewLine]", "  ", 
     RowBox[{
      RowBox[{"sigmaeta", "//", 
       RowBox[{
        RowBox[{"MatrixForm", "[", 
         RowBox[{"#", ",", 
          RowBox[{"TableHeadings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"labeleta", ",", "labeleta"}], "}"}]}]}], "]"}], "&"}]}], 
      "         ", "//", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<sigmaeta\\n\>\"", ",", "#"}], "]"}], "&"}]}], ";", 
     "\[IndentingNewLine]", "  ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"sigmaeta", "//", "Sigma2Corr"}], "//", "First"}], "//", 
       RowBox[{
        RowBox[{"MatrixForm", "[", 
         RowBox[{"#", ",", 
          RowBox[{"TableHeadings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"labeleta", ",", "labeleta"}], "}"}]}]}], "]"}], "&"}]}], 
      " ", "\[IndentingNewLine]", "\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t   ", "//", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<corr(eta)\\n\>\"", ",", "#"}], "]"}], "&"}]}], ";", 
     "\[IndentingNewLine]", " ", 
     RowBox[{
      RowBox[{"sigmazeta", "//", 
       RowBox[{
        RowBox[{"MatrixForm", "[", 
         RowBox[{"#", ",", 
          RowBox[{"TableHeadings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"labeleta", ",", "labeleta"}], "}"}]}]}], "]"}], "&"}]}], 
      "       ", "//", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<sigmazeta\\n\>\"", ",", "#"}], "]"}], "&"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"sigmazeta", "//", "Eigenvalues"}], "//", "Print"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"sigmaeta", "//", "Eigenvalues"}], "//", "Print"}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"sigmazeta", "//", "Det"}], "//", "Print"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"sigmaeta", "//", "Det"}], "//", "Print"}], ";"}], 
      "\[IndentingNewLine]", "*)"}], "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"B11", "//", 
       RowBox[{
        RowBox[{"MatrixForm", "[", 
         RowBox[{"#", ",", 
          RowBox[{"TableHeadings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"labeleta", ",", "labeleta"}], "}"}]}]}], "]"}], "&"}]}], 
      "       ", "//", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<(I-B)^-1 = B11\\n\>\"", ",", "#"}], "]"}], "&"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"B11", "//", "Det"}], "//", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<|(I-B)^-1| =\>\"", ",", "#"}], "]"}], "&"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", "  ", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", "-", 
         RowBox[{
          RowBox[{"VecDiag", "[", "sigmazeta", "]"}], "/", 
          RowBox[{"VecDiag", "[", "sigmaeta", "]"}]}]}], "}"}], "//", 
       RowBox[{
        RowBox[{"MatrixForm", "[", 
         RowBox[{"#", ",", 
          RowBox[{"TableHeadings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"None", ",", "labeleta"}], "}"}]}]}], "]"}], "&"}]}], " ",
       "\[IndentingNewLine]", "//", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<\\nSquared Multiple Correlations for Structural Equations: \
1-sigmazeta/sigmaeta\\n\>\"", ",", "#"}], "]"}], "&"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", "  ", 
     RowBox[{
      RowBox[{
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"Det", "[", "sigmazeta", "]"}], "/", 
         RowBox[{"Det", "[", "sigmaeta", "]"}]}]}], "//", 
       RowBox[{
        RowBox[{"MatrixForm", "[", 
         RowBox[{"#", ",", 
          RowBox[{"TableHeadings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"labeleta", ",", "None"}], "}"}]}]}], "]"}], "&"}]}], " ",
       "\[IndentingNewLine]", "//", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<Total Coefficient of Determination for Structural Equations: \
1-|sigmazeta|/|sigmaeta| = 1-|I-B|^2 = \>\"", ",", "#"}], "]"}], "&"}]}], ";",
      "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"sigma", "=", " ", 
      RowBox[{
       RowBox[{"lambdaeta", ".", "sigmaeta", ".", 
        RowBox[{"(", 
         RowBox[{"lambdaeta", "//", "Transpose"}], ")"}]}], "+", 
       "sigmaepsilon"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", "-", 
         RowBox[{
          RowBox[{"VecDiag", "[", "sigmaepsilon", "]"}], "/", 
          RowBox[{"VecDiag", "[", "sigma", "]"}]}]}], "}"}], "//", 
       RowBox[{
        RowBox[{"MatrixForm", "[", 
         RowBox[{"#", ",", 
          RowBox[{"TableHeadings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"None", ",", "labely"}], "}"}]}]}], "]"}], "&"}]}], " ", 
      "\[IndentingNewLine]", "//", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<\\nSquared Multiple Correlations for Observed Variables: \
1-sigmaepsilon/sigma=1-MQR/MQT\\n\>\"", ",", "#"}], "]"}], "&"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", "  ", 
     RowBox[{
      RowBox[{
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"Det", "[", "sigmaepsilon", "]"}], "/", 
         RowBox[{"Det", "[", "sigma", "]"}]}]}], "//", 
       RowBox[{
        RowBox[{"MatrixForm", "[", 
         RowBox[{"#", ",", 
          RowBox[{"TableHeadings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"labely", ",", "None"}], "}"}]}]}], "]"}], "&"}]}], " ", 
      "\[IndentingNewLine]", "\t\t\t\t", "//", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<Total Coefficient of Determination for Observed Variables: \
1-|sigmaepsilon|/|sigma| = \>\"", ",", "#"}], "]"}], "&"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"sigma", "//", 
       RowBox[{
        RowBox[{"MatrixForm", "[", 
         RowBox[{"#", ",", 
          RowBox[{"TableHeadings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"labely", ",", "labely"}], "}"}]}]}], "]"}], "&"}]}], " ",
       "//", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Fitted Covariance Matrix sigma\\n\>\"", ",", "#"}], 
        "]"}], "&"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     " ", 
     RowBox[{"{", 
      RowBox[{
      "beta", ",", "gamma", ",", "sigmazeta", ",", "lambdaeta", ",", "taueta",
        ",", "sigmaepsilon", ",", "\[IndentingNewLine]", " ", "stdbeta", ",", 
       "stdgamma", ",", "stdsigmazeta", ",", "stdlambdaeta", ",", "stdtaueta",
        ",", "stdsigmaepsilon", ",", "\[IndentingNewLine]", "mueeta", ",", 
       "sigmaeta", ",", "B11", ",", "sigma"}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]"}], "Input",
 PageWidth->Infinity,
 CellMargins->{{21.5, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 TextAlignment->Left,
 FontWeight->"Plain",
 CellLabel->"In[277]:="],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Symmetrize", "[", "A_", "]"}], ":=", 
    RowBox[{"0.5", 
     RowBox[{"(", 
      RowBox[{"A", "+", 
       RowBox[{"Transpose", "[", "A", "]"}]}], ")"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"IndividualLik", "//", "Clear"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IndividualLik", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Y_", ",", "X_", ",", "miss_"}], "}"}], ",", "Theta_", ",", 
    RowBox[{"{", 
     RowBox[{"System_", ",", "ThetaFix_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Singular_:", "\"\<CholeskyLinearSolve\>\""}], ",", 
      RowBox[{"const_:", 
       RowBox[{"2", " ", "\[Pi]"}]}], " ", ",", 
      RowBox[{"option_:", "0"}]}], "}"}]}], "]"}], ":=", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "P", ",", "Q", ",", "K", ",", "gamma", ",", "beta", ",", "B1", ",", 
      "sigmazeta", ",", "sigmaepsilon", ",", "lambdaeta", ",", 
      "\[IndentingNewLine]", "           ", "B11", ",", "sigmaeta", ",", 
      "sigmay", ",", "lik", ",", "C", ",", "n", ",", "yn", ",", "ymiss", ",", 
      "sel", ",", "muesel", ",", "sigmaysel", ",", "Csel", ",", "nue", ",", 
      "eig", ",", "root", ",", "nue1"}], "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"beta", ",", "gamma", ",", "sigmazeta"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"lambdaeta", ",", "taueta", ",", "sigmaepsilon"}], "}"}]}], 
       "}"}], "=", 
      RowBox[{"System", "[", 
       RowBox[{"Theta", ",", "ThetaFix"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"P", ",", "Q"}], "}"}], "=", 
      RowBox[{"gamma", "//", "Dimensions"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"B1", "=", 
      RowBox[{
       RowBox[{"IdentityMatrix", "[", "P", "]"}], "-", "beta"}]}], ";", "  ", 
     "\[IndentingNewLine]", 
     RowBox[{"B11", "=", 
      RowBox[{"Inverse", "[", "B1", "]"}]}], ";", " ", "\[IndentingNewLine]", 
     
     RowBox[{"sigmaeta", "=", 
      RowBox[{"B11", ".", "sigmazeta", ".", 
       RowBox[{"Transpose", "[", "B11", "]"}]}]}], ";", "    ", 
     "\[IndentingNewLine]", 
     RowBox[{"sigmay", "=", 
      RowBox[{
       RowBox[{"lambdaeta", ".", "sigmaeta", ".", 
        RowBox[{"Transpose", "[", "lambdaeta", "]"}]}], "+", 
       "sigmaepsilon"}]}], ";", " ", "\[IndentingNewLine]", 
     RowBox[{"C", "=", 
      RowBox[{
       RowBox[{"lambdaeta", ".", "B11", ".", "gamma"}], "+", "taueta"}]}], 
     ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"n", "=", 
      RowBox[{"Y", "//", "Length"}]}], ";", " ", "\[IndentingNewLine]", 
     RowBox[{"lik", "=", 
      RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", "   ", 
      RowBox[{
       RowBox[{
        RowBox[{"yn", "=", 
         RowBox[{"Y", "[", 
          RowBox[{"[", "nn", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", "\t", 
        RowBox[{"(*", "\n", "       ", 
         RowBox[{
          RowBox[{"ymiss", "=", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"SameQ", "[", 
               RowBox[{"miss", ",", "#"}], "]"}], "&"}], ",", "yn"}], "]"}]}],
           ";", "\n", "       ", 
          RowBox[{"sel", "=", 
           RowBox[{"Locate", "[", 
            RowBox[{"ymiss", ",", "False"}], "]"}]}], ";"}], 
         "\[IndentingNewLine]", "   ", "*)"}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", "       ", 
        RowBox[{"sel", "=", 
         RowBox[{"NotPosition", "[", 
          RowBox[{"yn", ",", "miss"}], "]"}]}], ";", "\n", 
        "\[IndentingNewLine]", "      ", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"sel", "\[Equal]", 
           RowBox[{"{", "}"}]}], ",", 
          RowBox[{"l", "=", "0"}], ",", 
          RowBox[{"(*", 
           RowBox[{"keine", " ", "Messung"}], "*)"}], "\[IndentingNewLine]", 
          "\[IndentingNewLine]", "   ", 
          RowBox[{"(*", "else", "*)"}], "\[IndentingNewLine]", 
          "\[IndentingNewLine]", "\t ", 
          RowBox[{
           RowBox[{"sigmaysel", "=", 
            RowBox[{"sigmay", "[", 
             RowBox[{"[", 
              RowBox[{"sel", ",", "sel"}], "]"}], "]"}]}], ";", 
           "\[IndentingNewLine]", "\t ", 
           RowBox[{"Csel", "=", 
            RowBox[{"C", "[", 
             RowBox[{"[", "sel", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
           "          ", 
           RowBox[{"muesel", "=", 
            RowBox[{"Csel", ".", 
             RowBox[{"X", "[", 
              RowBox[{"[", "nn", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]",
            "          ", 
           RowBox[{"nue", "=", 
            RowBox[{
             RowBox[{"yn", "[", 
              RowBox[{"[", "sel", "]"}], "]"}], "-", " ", "muesel"}]}], ";", 
           "\[IndentingNewLine]", "\[IndentingNewLine]", "         ", 
           RowBox[{"Which", "[", 
            RowBox[{
             RowBox[{"Singular", "===", "False"}], ",", " ", 
             "\[IndentingNewLine]", "                  ", 
             RowBox[{"l", "=", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["1", "2"]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Log", "[", 
                  RowBox[{"Det", "[", 
                   RowBox[{"const", " ", "sigmaysel"}], "]"}], "]"}], "+", 
                 RowBox[{"nue", ".", 
                  RowBox[{"Inverse", "[", "sigmaysel", "]"}], ".", "nue"}]}], 
                ")"}]}]}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
             "                  ", 
             RowBox[{"Singular", "===", "True"}], ",", "\[IndentingNewLine]", 
             "\[IndentingNewLine]", "                 ", 
             RowBox[{
              RowBox[{"eig", "=", 
               RowBox[{"Eigenvalues", "[", "sigmay", "]"}]}], ";", 
              "\[IndentingNewLine]", "                 ", 
              RowBox[{"eig", "=", 
               RowBox[{"Select", "[", 
                RowBox[{"eig", ",", 
                 RowBox[{
                  RowBox[{"#1", ">", "0"}], "&"}]}], "]"}]}], ";", 
              "\[IndentingNewLine]", "                ", 
              RowBox[{"l", "=", 
               RowBox[{
                RowBox[{"-", 
                 FractionBox["1", "2"]}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Plus", "@@", 
                   RowBox[{"Log", "[", 
                    RowBox[{"const", " ", "eig"}], "]"}]}], "+", 
                  RowBox[{"nue", ".", 
                   RowBox[{"PseudoInverse", "[", "sigmaysel", "]"}], ".", 
                   "nue"}]}], ")"}]}]}]}], ",", "\[IndentingNewLine]", 
             "\[IndentingNewLine]", "                ", 
             RowBox[{"Singular", "===", "\"\<CholeskyLinearSolve\>\""}], ",", 
             "\[IndentingNewLine]", "\[IndentingNewLine]", "                ", 
             RowBox[{
              RowBox[{"root", "=", 
               RowBox[{
                RowBox[{"CholeskyDecomposition", "[", 
                 RowBox[{"sigmaysel", "//", "Symmetrize"}], "]"}], "//", 
                "Transpose"}]}], ";", "\[IndentingNewLine]", 
              "                ", 
              RowBox[{"nue", "=", 
               RowBox[{"LinearSolve", "[", 
                RowBox[{"root", ",", "nue"}], "]"}]}], ";", 
              "\[IndentingNewLine]", "                ", 
              RowBox[{"l", "=", 
               RowBox[{
                RowBox[{"-", 
                 FractionBox["1", "2"]}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Log", "[", 
                   RowBox[{"Det", "[", 
                    RowBox[{"const", " ", "sigmaysel"}], "]"}], "]"}], "+", 
                  RowBox[{"nue", ".", "nue"}]}], ")"}]}]}]}], ",", 
             "\[IndentingNewLine]", "\[IndentingNewLine]", "               ", 
             
             RowBox[{"Singular", "===", "\"\<LinearSolve\>\""}], ",", 
             "\[IndentingNewLine]", "\[IndentingNewLine]", "                ", 
             RowBox[{
              RowBox[{"nue1", "=", 
               RowBox[{"LinearSolve", "[", 
                RowBox[{"sigmaysel", ",", "nue"}], "]"}]}], ";", 
              "\[IndentingNewLine]", "                ", 
              RowBox[{"l", "=", 
               RowBox[{
                RowBox[{"-", 
                 FractionBox["1", "2"]}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Log", "[", 
                   RowBox[{"Det", "[", 
                    RowBox[{"const", " ", "sigmaysel"}], "]"}], "]"}], "+", 
                  RowBox[{"nue", ".", "nue1"}]}], ")"}]}]}]}]}], 
            "\[IndentingNewLine]", "         ", "]"}], ";"}]}], 
         "\[IndentingNewLine]", "      ", "]"}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", "       ", 
        RowBox[{"lik", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"lik", ",", "l"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
       ",", 
       RowBox[{"{", 
        RowBox[{"nn", ",", "n"}], "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"option", "\[Equal]", "5"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Plus", "@@", "lik"}], ",", "lik"}], "}"}], ",", 
       RowBox[{"Plus", "@@", "lik"}]}], "]"}]}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "]"}]}]}], "Input",
 PageWidth->Infinity,
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 CellChangeTimes->{{3.460194284551586*^9, 3.460194430512322*^9}, {
   3.4601944628027267`*^9, 3.460194639371933*^9}, {3.460194707706352*^9, 
   3.4601947269782743`*^9}, {3.460194787282988*^9, 3.4601947879591217`*^9}, {
   3.460195583412208*^9, 3.460195677267837*^9}, {3.460195730531335*^9, 
   3.4601957347363777`*^9}, {3.4601977253341637`*^9, 
   3.4601977303712597`*^9}, {3.460199977089291*^9, 3.460199982306014*^9}, {
   3.4602001100007153`*^9, 3.4602001365337563`*^9}, {3.4602001838757668`*^9, 
   3.46020021505055*^9}, {3.46020039918268*^9, 3.46020043709068*^9}, {
   3.460200544282135*^9, 3.460200546288165*^9}, 3.460200959618925*^9},
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 CellLabel->"In[840]:="],

Cell[BoxData[{
 RowBox[{"LeveragePlot", "//", "Clear"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LeveragePlot", "[", 
   RowBox[{"THETA_", ",", 
    RowBox[{"{", 
     RowBox[{"labeta_", ",", "labx_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i_", ",", "j_"}], "}"}], ",", "X_"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "sel", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"beta", ",", "gamma", ",", "sigmazeta"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"lambdaeta", ",", 
          StyleBox["taueta",
           FontFamily->"Courier"], 
          StyleBox[",",
           FontFamily->"Courier"], "sigmaepsilon"}], "}"}]}], "}"}], "=", 
      RowBox[{"System", "[", 
       RowBox[{"THETA", ",", 
        RowBox[{"{", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"mueetay", ",", "sigmaetay"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"mueeta", ",", "sigmaeta"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"mueY", ",", "sigmaY"}], "}"}]}], "}"}], "=", " ", 
      RowBox[{"NormalCorrelation", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Y", ",", "X"}], "}"}], ",", "THETA", ",", 
        RowBox[{"{", 
         RowBox[{"System", ",", 
          RowBox[{"{", "}"}]}], "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p", ",", "p"}], "}"}], "=", 
      RowBox[{"beta", "//", "Dimensions"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"eta", "//", "Clear"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Eta", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"eta", "[", "ii", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"ii", ",", "p"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"x", "=", 
      RowBox[{"X", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"EY", "=", 
      RowBox[{
       RowBox[{"lambdaeta", ".", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"beta", ".", "Eta"}], "+", 
          RowBox[{"gamma", ".", "x"}]}], ")"}]}], " ", "+", 
       RowBox[{"taueta", ".", "x"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"EEta", "=", 
      RowBox[{
       RowBox[{"beta", ".", "Eta"}], "+", 
       RowBox[{"gamma", ".", "x"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"rule", "=", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Rule", "[", 
          RowBox[{"#", ",", "0"}], "]"}], "&"}], ",", "Eta"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"\"\<beta\>\"", ",", 
       RowBox[{"beta", "//", 
        RowBox[{
         RowBox[{"MatrixForm", "[", 
          RowBox[{"#", ",", 
           RowBox[{"TableHeadings", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"labeta", ",", "labeta"}], "}"}]}]}], "]"}], "&"}]}], 
       ",", "\"\<gamma\>\"", ",", 
       RowBox[{"gamma", "//", 
        RowBox[{
         RowBox[{"MatrixForm", "[", 
          RowBox[{"#", ",", 
           RowBox[{"TableHeadings", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"labeta", ",", "labx"}], "}"}]}]}], "]"}], "&"}]}]}], 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"EEta", "//", 
       RowBox[{
        RowBox[{"MatrixForm", "[", 
         RowBox[{"#", ",", 
          RowBox[{"TableHeadings", "\[Rule]", 
           RowBox[{"{", "labeta", "}"}]}]}], "]"}], "&"}]}], "//", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<eqns\>\"", ",", "#"}], "]"}], "&"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"sel", "=", 
      RowBox[{"Complement", "[", 
       RowBox[{
        RowBox[{"p", "//", "Range"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"EEta", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
        "/.", "\[InvisibleSpace]", 
       RowBox[{
       "rule", "\[LeftDoubleBracket]", "sel", "\[RightDoubleBracket]"}]}], "//",
       "Print"}], ";", "\[IndentingNewLine]", 
     RowBox[{"g1", "=", 
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"EEta", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "/.", 
          RowBox[{"rule", "[", 
           RowBox[{"[", "sel", "]"}], "]"}]}], "//", "Evaluate"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"eta", "[", "j", "]"}], ",", 
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"DisplayFunction", "\[Rule]", "Identity"}], ",", 
        "\[IndentingNewLine]", 
        "                                                                     \
                                                         ", 
        RowBox[{"Axes", "\[Rule]", "True"}], ",", 
        RowBox[{"FrameLabel", "\[Rule]", 
         RowBox[{"labeta", "[", 
          RowBox[{"[", 
           RowBox[{"{", 
            RowBox[{"j", ",", "i"}], "}"}], "]"}], "]"}]}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"g2", "=", 
      RowBox[{"plot1", "[", 
       RowBox[{
        RowBox[{"mueetay", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "i"}], "}"}]}], "]"}], "]"}], ",", 
        RowBox[{"PlotJoined", "\[Rule]", "False"}], ",", 
        RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Show", "[", 
      RowBox[{"g1", ",", "g2", ",", 
       RowBox[{"DisplayFunction", "\[Rule]", "$DisplayFunction"}]}], 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}]}], "Input",
 PageWidth->Infinity,
 CellMargins->{{19.8125, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 FontWeight->"Plain",
 CellLabel->"In[857]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Nonlinear Measurement", "Section",
 CellMargins->{{52, 10}, {10, 30}},
 CellChangeTimes->{{3.4602621632679443`*^9, 3.4602621713132153`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"??", "symmetric"}]], "Input",
 CellMargins->{{52, 10}, {10, 30}},
 CellChangeTimes->{{3.460277913555442*^9, 3.460277914124366*^9}},
 CellLabel->"In[91]:="],

Cell["Global`symmetric", "Print", "PrintUsage",
 CellMargins->{{52, 10}, {10, 30}},
 CellChangeTimes->{3.4602795417243347`*^9},
 CellTags->"Info3460286741-5603323"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {GridBox[{
       {
        RowBox[{
         RowBox[{"symmetric", "[", "A_", "]"}], ":=", 
         RowBox[{"0.5`", " ", 
          RowBox[{"(", 
           RowBox[{"A", "+", 
            RowBox[{"Transpose", "[", "A", "]"}]}], ")"}]}]}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition[$CellContext`symmetric],
  Editable->False]], "Print",
 CellMargins->{{52, 10}, {10, 30}},
 CellChangeTimes->{3.4602795417681*^9},
 CellTags->"Info3460286741-5603323"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"LISRELsimulNonlin", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"n_", ",", "Generator_", ",", "X_"}], "}"}], ",", "Theta_", ",", 
    
    RowBox[{"{", 
     RowBox[{"System_", ",", "ThetaFix_"}], "}"}], ",", 
    RowBox[{"comp_", ":", "True"}]}], "]"}], ":=", "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "P", ",", "Q", ",", "K", ",", "beta", ",", "gamma", ",", "B1", ",", 
      "sigmazeta", ",", "ZETA", ",", "ETA", ",", "sigmaepsilon", ",", "h", 
      ",", "dh", ",", "EPSILON", ",", "Y"}], "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"beta", ",", "gamma", ",", "sigmazeta"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"h", ",", "dh", ",", "sigmaepsilon"}], "}"}]}], "}"}], "=", 
      RowBox[{"System", "[", 
       RowBox[{"Theta", ",", "ThetaFix"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"P", ",", "Q"}], "}"}], "=", 
      RowBox[{"Dimensions", "[", "gamma", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"B1", "=", 
      RowBox[{
       RowBox[{"IdentityMatrix", "[", "P", "]"}], "-", "beta"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{"comp", ",", 
       RowBox[{"RandomGauss", "[", 
        RowBox[{
         RowBox[{"Shape", "[", 
          RowBox[{"0", ",", "Q"}], "]"}], ",", 
         RowBox[{"IdentityMatrix", "[", "Q", "]"}], ",", "n", ",", 
         "Generator"}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"sigmazeta", "=", 
      RowBox[{"symmetric", "[", "sigmazeta", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ZETA", "=", 
      RowBox[{"RandomGauss", "[", 
       RowBox[{
        RowBox[{"Shape", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "P", "}"}]}], "]"}], ",", "sigmazeta", ",", "n", ",", 
        "Generator"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ETA", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"X", ".", 
          RowBox[{"Transpose", "[", "gamma", "]"}]}], "+", "ZETA"}], ")"}], 
       ".", 
       RowBox[{"Transpose", "[", 
        RowBox[{"Inverse", "[", "B1", "]"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"sigmaepsilon", "=", 
      RowBox[{"symmetric", "[", "sigmaepsilon", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"K", "=", 
      RowBox[{"Length", "[", "sigmaepsilon", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"EPSILON", "=", 
      RowBox[{"RandomGauss", "[", 
       RowBox[{
        RowBox[{"Shape", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "K", "}"}]}], "]"}], ",", "sigmaepsilon", ",", "n", 
        ",", "Generator"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{
        RowBox[{"MapThread", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"h", "[", 
            RowBox[{"#1", ",", "#2", ",", "Theta"}], "]"}], "&"}], ",", 
          RowBox[{"{", 
           RowBox[{"ETA", ",", "X"}], "}"}]}], "]"}], "//", "Print"}], ";"}], 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{"Y", "=", 
      RowBox[{
       RowBox[{"MapThread", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"h", "[", 
           RowBox[{"#1", ",", "#2", ",", "Theta"}], "]"}], "&"}], ",", 
         RowBox[{"{", 
          RowBox[{"ETA", ",", "X"}], "}"}]}], "]"}], "+", "EPSILON"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Y", ",", "X", ",", "ETA"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ZETA", ",", "EPSILON"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"beta", ",", "gamma", ",", "sigmazeta"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"h", ",", "dh", ",", "sigmaepsilon"}], "}"}]}], "}"}]}], 
      "}"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 PageWidth->Infinity,
 CellMargins->{{52, 10}, {10, 30}},
 InitializationCell->True,
 CellSize->{2319, Inherited},
 CellChangeTimes->{{3.4602622071626577`*^9, 3.460262398198495*^9}, {
   3.460262437065318*^9, 3.460262472021991*^9}, 3.460262843931487*^9, {
   3.460262950233645*^9, 3.460262986086526*^9}, {3.460263172780684*^9, 
   3.460263176674468*^9}, {3.460277857612403*^9, 3.4602778617889214`*^9}, {
   3.460277939813429*^9, 3.460277941379299*^9}, {3.4602783116100683`*^9, 
   3.4602783180613737`*^9}, 3.460278382288973*^9, {3.4606912264284678`*^9, 
   3.460691233914404*^9}, {3.460691458720351*^9, 3.460691466249228*^9}, {
   3.460691497945997*^9, 3.4606915200974693`*^9}, {3.460691564843457*^9, 
   3.460691575518559*^9}, {3.460691638755324*^9, 3.460691642591969*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 CellLabel->"In[5807]:="],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Symmetrize", "[", "A_", "]"}], " ", ":=", " ", 
    RowBox[{"0.5", "*", 
     RowBox[{"(", 
      RowBox[{"A", " ", "+", " ", 
       RowBox[{"Transpose", "[", "A", "]"}]}], ")"}]}]}], ";"}], " ", 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", "IndividualLikNonlin", "]"}], "\n", 
 RowBox[{
  RowBox[{"IndividualLikNonlin", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Y_", ",", " ", "X_", ",", " ", "miss_"}], "}"}], ",", " ", 
    "Theta_", ",", " ", 
    RowBox[{"{", 
     RowBox[{"System_", ",", " ", "ThetaFix_", ",", " ", 
      RowBox[{"m_:", "3"}], ",", " ", 
      RowBox[{"eps_:", 
       RowBox[{"10.", "^", 
        RowBox[{"(", 
         RowBox[{"-", "16"}], ")"}]}]}], ",", " ", 
      RowBox[{"ksigma_:", "Infinity"}], ",", " ", 
      RowBox[{"text_:", "0"}]}], "}"}], ",", " ", "\n", "   ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Singular_:", "False"}], ",", " ", 
      RowBox[{"const_:", "2", "*", "Pi"}], ",", " ", 
      RowBox[{"option_:", "0"}], ",", " ", 
      RowBox[{"NorKorr_:", "0"}]}], "}"}]}], "]"}], " ", ":=", " ", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "P", ",", " ", "Q", ",", " ", "K", ",", " ", "beta", ",", " ", "gamma", 
      ",", " ", "sigmazeta", ",", " ", "h", ",", " ", "sigmaepsilon", ",", 
      " ", "B1", ",", " ", "B11", ",", " ", "sigmaeta", ",", " ", "n", ",", 
      " ", "lik", ",", " ", "yn", ",", " ", "sel", ",", " ", "\n", 
      "                 ", "xn", ",", " ", "mueeta", ",", " ", "vals", ",", 
      " ", "hl", ",", " ", "hlhl", ",", " ", "Eh", ",", " ", "hh", ",", " ", 
      "sigmaepsilonsel", ",", " ", "yy", ",", " ", "yetasigmaetaI", ",", " ", 
      "ynsel", ",", " ", "nue", ",", " ", "l0", ",", " ", "l1", ",", " ", "l",
       ",", " ", "etay", ",", " ", "H1", ",", " ", "E0etay", ",", " ", 
      "V0etay", ",", "\[IndentingNewLine]", "         ", "sigmaepsilonselI", 
      ",", " ", "zaehler", ",", " ", "nenner", ",", " ", "H", ",", " ", 
      "V0yetaI", ",", " ", "d", ",", " ", "Likratio", ",", " ", "L1"}], "}"}],
     ",", " ", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"beta", ",", " ", "gamma", ",", " ", "sigmazeta"}], "}"}], 
        ",", " ", 
        RowBox[{"{", 
         RowBox[{"h", ",", " ", "sigmaepsilon"}], "}"}]}], "}"}], " ", "=", 
      " ", 
      RowBox[{"System", "[", 
       RowBox[{"Theta", ",", " ", "ThetaFix"}], "]"}]}], ";", " ", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"P", ",", " ", "Q"}], "}"}], " ", "=", " ", 
      RowBox[{"Dimensions", "[", "gamma", "]"}]}], ";", " ", "\n", "     ", 
     RowBox[{"B1", " ", "=", " ", 
      RowBox[{
       RowBox[{"IdentityMatrix", "[", "P", "]"}], " ", "-", " ", "beta"}]}], 
     ";", "\[IndentingNewLine]", " ", 
     RowBox[{"B11", " ", "=", " ", 
      RowBox[{"Inverse", "[", "B1", "]"}]}], ";", " ", "\[IndentingNewLine]", 
     " ", 
     RowBox[{"sigmaeta", " ", "=", " ", 
      RowBox[{"B11", " ", ".", " ", "sigmazeta", " ", ".", " ", 
       RowBox[{"Transpose", "[", "B11", "]"}]}]}], ";", " ", "\n", "     ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"VALS", ",", " ", "WEIGHT"}], "}"}], " ", "=", " ", 
      RowBox[{"GaussHermitePointsMulti2", "[", 
       RowBox[{
       "m", ",", " ", "P", ",", " ", "eps", ",", " ", "ksigma", ",", " ", 
        "text"}], "]"}]}], ";", " ", "\[IndentingNewLine]", " ", 
     RowBox[{"n", " ", "=", " ", 
      RowBox[{"Length", "[", "Y", "]"}]}], ";", " ", "\[IndentingNewLine]", 
     RowBox[{"lik", " ", "=", " ", 
      RowBox[{"{", "}"}]}], ";", " ", "\[IndentingNewLine]", "\n", "    ", 
     RowBox[{"Do", "[", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"yn", " ", "=", " ", 
         RowBox[{"Y", "[", 
          RowBox[{"[", "nn", "]"}], "]"}]}], ";", " ", "\[IndentingNewLine]", 
        
        RowBox[{"sel", " ", "=", " ", 
         RowBox[{"NotPosition", "[", 
          RowBox[{"yn", ",", " ", "miss"}], "]"}]}], ";", " ", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"sel", " ", "==", " ", 
           RowBox[{"{", "}"}]}], ",", " ", 
          RowBox[{"l", " ", "=", " ", "0"}], ",", " ", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{"Which", "[", 
           RowBox[{
            RowBox[{"Singular", " ", "===", " ", "False"}], ",", " ", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", "  ", 
            RowBox[{
             RowBox[{"xn", " ", "=", " ", 
              RowBox[{"X", "[", 
               RowBox[{"[", "nn", "]"}], "]"}]}], ";", " ", 
             "\[IndentingNewLine]", "  ", 
             RowBox[{"mueeta", " ", "=", " ", 
              RowBox[{"B11", " ", ".", " ", "gamma", " ", ".", " ", "xn"}]}], 
             ";", " ", "\n", "              ", 
             RowBox[{"vals", " ", "=", " ", 
              RowBox[{"TrafoMueSigma", "[", 
               RowBox[{"VALS", ",", " ", 
                RowBox[{"{", 
                 RowBox[{"mueeta", ",", " ", "sigmaeta"}], "}"}], ",", " ", 
                "0"}], "]"}]}], ";", "\[IndentingNewLine]", "  ", 
             RowBox[{"hl", " ", "=", " ", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"h", "[", 
                   RowBox[{"#1", ",", " ", "xn", ",", " ", "Theta"}], "]"}], 
                  "[", 
                  RowBox[{"[", "sel", "]"}], "]"}], " ", "&"}], " ", ")"}], 
               " ", "/@", " ", "vals"}]}], ";", " ", 
             RowBox[{"hlhl", " ", "=", " ", 
              RowBox[{"Dyad", " ", "/@", " ", "hl"}]}], ";", " ", 
             "\[IndentingNewLine]", "  ", 
             RowBox[{"Eh", " ", "=", " ", 
              RowBox[{"WEIGHT", " ", ".", " ", "hl"}]}], ";", " ", "\n", 
             "              ", 
             RowBox[{"hh", " ", "=", " ", 
              RowBox[{
               RowBox[{"WEIGHT", " ", ".", " ", "hlhl"}], " ", "-", " ", 
               RowBox[{"Dyad", "[", "Eh", "]"}]}]}], ";", " ", 
             "\[IndentingNewLine]", " ", 
             RowBox[{"sigmaepsilonsel", " ", "=", " ", 
              RowBox[{"sigmaepsilon", "[", 
               RowBox[{"[", 
                RowBox[{"sel", ",", "sel"}], "]"}], "]"}]}], ";", 
             "\[IndentingNewLine]", "  ", 
             RowBox[{"yy", " ", "=", " ", 
              RowBox[{"hh", " ", "+", " ", "sigmaepsilonsel"}]}], ";", 
             "\[IndentingNewLine]", "  ", 
             RowBox[{"yyI", " ", "=", " ", 
              RowBox[{"Inverse", "[", "yy", "]"}]}], ";", " ", 
             RowBox[{"ynsel", " ", "=", " ", 
              RowBox[{"yn", "[", 
               RowBox[{"[", "sel", "]"}], "]"}]}], ";", " ", "\n", 
             "              ", 
             RowBox[{"nue", " ", "=", " ", 
              RowBox[{"ynsel", " ", "-", " ", "Eh"}]}], ";", 
             "\[IndentingNewLine]", " ", 
             RowBox[{"l0", " ", "=", " ", 
              RowBox[{
               RowBox[{"-", "0.5"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Log", "[", 
                  RowBox[{"Det", "[", 
                   RowBox[{"const", "*", "yy"}], "]"}], "]"}], " ", "+", " ", 
                 
                 RowBox[{
                 "nue", " ", ".", " ", "yyI", " ", ".", " ", "nue"}]}], 
                ")"}]}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
             " ", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"NorKorr", " ", "===", " ", "1"}], ",", " ", 
               RowBox[{"l1", " ", "=", " ", "0"}], ",", " ", 
               "\[IndentingNewLine]", "\n", "                 ", 
               RowBox[{
                RowBox[{"yeta", " ", "=", " ", 
                 RowBox[{
                  RowBox[{"WEIGHT", " ", ".", " ", 
                   RowBox[{"MapThread", "[", 
                    RowBox[{"Dyad", ",", " ", 
                    RowBox[{"{", 
                    RowBox[{"hl", ",", " ", "vals"}], "}"}]}], "]"}]}], " ", 
                  "-", " ", 
                  RowBox[{"Dyad", "[", 
                   RowBox[{"Eh", ",", " ", "mueeta"}], "]"}]}]}], ";", " ", 
                "\[IndentingNewLine]", "   ", 
                RowBox[{"etay", " ", "=", " ", 
                 RowBox[{"Transpose", "[", "yeta", "]"}]}], ";", 
                "\[IndentingNewLine]", "   ", 
                RowBox[{"H1", " ", "=", " ", 
                 RowBox[{"etay", " ", ".", " ", "yyI"}]}], ";", 
                "\[IndentingNewLine]", "   ", 
                RowBox[{"E0etay", " ", "=", " ", 
                 RowBox[{"mueeta", " ", "+", " ", 
                  RowBox[{"H1", " ", ".", " ", 
                   RowBox[{"(", 
                    RowBox[{"ynsel", " ", "-", " ", "Eh"}], ")"}]}]}]}], ";", 
                " ", "\n", "                 ", 
                RowBox[{"V0etay", " ", "=", " ", 
                 RowBox[{"sigmaeta", " ", "-", " ", 
                  RowBox[{"H1", " ", ".", " ", "yeta"}]}]}], ";", 
                "\[IndentingNewLine]", "   ", 
                RowBox[{"vals", " ", "=", " ", 
                 RowBox[{"TrafoMueSigma", "[", 
                  RowBox[{"VALS", ",", " ", 
                   RowBox[{"{", 
                    RowBox[{"E0etay", ",", " ", "V0etay"}], "}"}], ",", " ", 
                   "0"}], "]"}]}], ";", "\[IndentingNewLine]", "   ", 
                RowBox[{"hl", " ", "=", " ", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"h", "[", 
                    RowBox[{"#1", ",", " ", "xn", ",", " ", "Theta"}], "]"}], 
                    "[", 
                    RowBox[{"[", "sel", "]"}], "]"}], " ", "&"}], " ", ")"}], 
                  " ", "/@", " ", "vals"}]}], ";", " ", "\n", 
                "                 ", 
                RowBox[{"nue", " ", "=", " ", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"ynsel", " ", "-", " ", "#1"}], " ", "&"}], " ", 
                   ")"}], " ", "/@", " ", "hl"}]}], ";", 
                "\[IndentingNewLine]", "   ", 
                RowBox[{"sigmaepsilonselI", " ", "=", " ", 
                 RowBox[{"Inverse", "[", "sigmaepsilonsel", "]"}]}], ";", " ",
                 "\[IndentingNewLine]", "   ", 
                RowBox[{"zaehler", " ", "=", " ", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    "#1", " ", ".", " ", "sigmaepsilonselI", " ", ".", " ", 
                    "#1"}], " ", "&"}], " ", ")"}], " ", "/@", " ", "nue"}]}],
                 ";", " ", "\[IndentingNewLine]", "\n", "                 ", 
                RowBox[{"H", " ", "=", " ", 
                 RowBox[{"yeta", " ", ".", " ", 
                  RowBox[{"Inverse", "[", "sigmaeta", "]"}]}]}], ";", 
                "\[IndentingNewLine]", "   ", 
                RowBox[{"V0yetaI", " ", "=", " ", 
                 RowBox[{"Inverse", "[", 
                  RowBox[{"yy", " ", "-", " ", 
                   RowBox[{"H", " ", ".", " ", "etay"}]}], "]"}]}], ";", " ", 
                "\[IndentingNewLine]", "  ", 
                RowBox[{"d", " ", "=", " ", 
                 RowBox[{"ynsel", " ", "-", " ", "Eh", " ", "+", " ", 
                  RowBox[{"H", " ", ".", " ", "mueeta"}]}]}], ";", 
                "\[IndentingNewLine]", "  ", 
                RowBox[{"nue", " ", "=", " ", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"d", " ", "-", " ", 
                    RowBox[{"H", " ", ".", " ", "#1"}]}], " ", "&"}], " ", 
                   ")"}], " ", "/@", " ", "vals"}]}], ";", " ", "\n", 
                "                 ", 
                RowBox[{"nenner", " ", "=", " ", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    "#1", " ", ".", " ", "V0yetaI", " ", ".", " ", "#1"}], 
                    " ", "&"}], " ", ")"}], " ", "/@", " ", "nue"}]}], ";", 
                " ", "\[IndentingNewLine]", "\[IndentingNewLine]", "  ", 
                RowBox[{"Jacobi", " ", "=", " ", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Det", "[", "sigmaepsilonselI", "]"}], "/", 
                    RowBox[{"Det", "[", "V0yetaI", "]"}]}], ")"}], "^", 
                  "0.5"}]}], ";", " ", "\[IndentingNewLine]", 
                RowBox[{"Likratio", " ", "=", " ", 
                 RowBox[{"Exp", "[", 
                  RowBox[{
                   RowBox[{"-", "0.5"}], "*", 
                   RowBox[{"(", 
                    RowBox[{"zaehler", " ", "-", " ", "nenner"}], ")"}]}], 
                  "]"}]}], ";", "\[IndentingNewLine]", " ", "\n", 
                "            ", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"pp", " ", ">", " ", "0"}], ",", " ", 
                  "\[IndentingNewLine]", "\[IndentingNewLine]", 
                  RowBox[{"Print", "[", 
                   RowBox[{"plot1", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"vals", "[", 
                    RowBox[{"[", 
                    RowBox[{"All", ",", "pp"}], "]"}], "]"}], ",", " ", 
                    RowBox[{"Jacobi", "*", "Likratio"}], ",", "WEIGHT"}], 
                    "}"}], "//", "Transpose"}], ",", " ", 
                    "\[IndentingNewLine]", "            ", 
                    RowBox[{"PlotJoined", " ", "->", " ", "False"}], ",", " ", 
                    RowBox[{"GridLines", " ", "->", " ", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"E0etay", "[", 
                    RowBox[{"[", "pp", "]"}], "]"}], "}"}], ",", " ", 
                    "None"}], "}"}]}], ",", 
                    RowBox[{"dicke", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{".01", ",", ".02"}], "}"}]}]}], "]"}], "]"}]}], 
                 "]"}], ";", "\[IndentingNewLine]", "              ", "\n", 
                "\[IndentingNewLine]", 
                RowBox[{"L1", " ", "=", " ", 
                 RowBox[{"Jacobi", "*", 
                  RowBox[{"WEIGHT", " ", ".", " ", "Likratio"}]}]}], ";", " ",
                 "\[IndentingNewLine]", 
                RowBox[{"l1", " ", "=", " ", 
                 RowBox[{"Log", "[", "L1", "]"}]}]}]}], "\[IndentingNewLine]",
               "\[IndentingNewLine]", "]"}]}]}], "]"}]}], "]"}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", " ", 
        RowBox[{"l", " ", "=", " ", 
         RowBox[{"l0", " ", "+", " ", "l1"}]}], ";", " ", 
        "\[IndentingNewLine]", 
        RowBox[{"lik", " ", "=", " ", 
         RowBox[{"Append", "[", 
          RowBox[{"lik", ",", " ", "l"}], "]"}]}]}], " ", ",", " ", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"nn", ",", " ", "n"}], "}"}]}], "]"}], ";", " ", 
     "\[IndentingNewLine]", "\n", "    ", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"option", " ", "==", " ", "5"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Plus", " ", "@@", " ", "lik"}], ",", " ", "lik"}], "}"}], 
       ",", " ", 
       RowBox[{"Plus", " ", "@@", " ", "lik"}]}], "]"}]}]}], 
   "]"}]}]}], "Input",
 PageWidth->Infinity,
 CellMargins->{{52, 10}, {10, 30}},
 InitializationCell->True,
 CellChangeTimes->{{3.460194284551586*^9, 3.460194430512322*^9}, {
   3.4601944628027267`*^9, 3.460194639371933*^9}, {3.460194707706352*^9, 
   3.4601947269782743`*^9}, {3.460194787282988*^9, 3.4601947879591217`*^9}, {
   3.460195583412208*^9, 3.460195677267837*^9}, {3.460195730531335*^9, 
   3.4601957347363777`*^9}, {3.4601977253341637`*^9, 
   3.4601977303712597`*^9}, {3.460199977089291*^9, 3.460199982306014*^9}, {
   3.4602001100007153`*^9, 3.4602001365337563`*^9}, {3.4602001838757668`*^9, 
   3.46020021505055*^9}, {3.46020039918268*^9, 3.46020043709068*^9}, {
   3.460200544282135*^9, 3.460200546288165*^9}, 3.460200959618925*^9, {
   3.46026324513008*^9, 3.460263282755694*^9}, {3.4602633380999613`*^9, 
   3.4602633493534527`*^9}, {3.460263400721909*^9, 3.460263415929566*^9}, {
   3.460263454575968*^9, 3.4602634803271923`*^9}, {3.460263596468174*^9, 
   3.460263712913571*^9}, {3.460264149260456*^9, 3.460264306447337*^9}, {
   3.460264339903819*^9, 3.460264344426856*^9}, {3.4602643774296494`*^9, 
   3.460264747632288*^9}, {3.460264778447598*^9, 3.460264783659968*^9}, {
   3.460265503837646*^9, 3.460265516171212*^9}, {3.460265587432678*^9, 
   3.460265590909531*^9}, {3.460265773917304*^9, 3.4602657740295877`*^9}, {
   3.460265809524905*^9, 3.460265937981409*^9}, {3.4602659990577393`*^9, 
   3.460266097141539*^9}, {3.460266166568413*^9, 3.460266209126886*^9}, {
   3.460266250084037*^9, 3.4602662808402967`*^9}, {3.460266339683448*^9, 
   3.460266426663334*^9}, {3.460266497330805*^9, 3.4602665255713882`*^9}, {
   3.4602665962854033`*^9, 3.460266599621019*^9}, {3.4602666981599493`*^9, 
   3.460266745666133*^9}, {3.4602668309241867`*^9, 3.460266885864461*^9}, {
   3.4602669348160353`*^9, 3.460266996301594*^9}, {3.460267038525139*^9, 
   3.4602670405577307`*^9}, {3.460267080242529*^9, 3.4602671269901857`*^9}, {
   3.4602671603427677`*^9, 3.460267254900002*^9}, {3.460267290349532*^9, 
   3.460267311072433*^9}, {3.460267360591495*^9, 3.4602673854606743`*^9}, {
   3.46026741568622*^9, 3.460267493972913*^9}, 3.460267531325343*^9, {
   3.460267657409995*^9, 3.460267687307645*^9}, {3.460267744356736*^9, 
   3.460267792177703*^9}, {3.460267867265236*^9, 3.460267951190172*^9}, {
   3.460268008054109*^9, 3.4602682257600193`*^9}, {3.4602682707145157`*^9, 
   3.460268383589704*^9}, {3.4602684145136213`*^9, 3.4602684234894333`*^9}, {
   3.460268495772295*^9, 3.460268548380769*^9}, {3.460268585324235*^9, 
   3.460268588068144*^9}, {3.460268722529909*^9, 3.4602687808529863`*^9}, {
   3.460268847343011*^9, 3.4602688643424892`*^9}, {3.460268906843392*^9, 
   3.4602690975890217`*^9}, {3.460269137274601*^9, 3.460269351221425*^9}, {
   3.460269595751025*^9, 3.460269628454479*^9}, {3.4602696598838882`*^9, 
   3.460269679514669*^9}, {3.460269723422311*^9, 3.460269755767868*^9}, {
   3.460269879713437*^9, 3.460269923345128*^9}, {3.46027001591717*^9, 
   3.460270024031649*^9}, 3.46027010485046*^9, {3.460270149953143*^9, 
   3.4602702537187767`*^9}, {3.4602702846349297`*^9, 3.46027029514499*^9}, 
   3.460270346891515*^9, 3.460270607274858*^9, {3.4602708505804453`*^9, 
   3.460270862797477*^9}, 3.4602710337362003`*^9, {3.460271102575704*^9, 
   3.460271108328334*^9}, {3.460271156184857*^9, 3.4602711590022993`*^9}, {
   3.46027123095223*^9, 3.460271270598349*^9}, {3.460271302970233*^9, 
   3.4602713202526827`*^9}, 3.460271477470911*^9, {3.460273080051744*^9, 
   3.46027308520679*^9}, {3.4602731161468687`*^9, 3.460273141336913*^9}, {
   3.460273653624395*^9, 3.46027366118076*^9}, 3.4602760224893513`*^9, {
   3.460276063965891*^9, 3.46027607080488*^9}, {3.460276134568684*^9, 
   3.460276135994856*^9}, {3.460277295287301*^9, 3.460277326831636*^9}, {
   3.4602773608967543`*^9, 3.460277367275772*^9}, {3.460279569593549*^9, 
   3.460279618455995*^9}, {3.4602796591590967`*^9, 3.460279676488124*^9}, {
   3.4602797108870907`*^9, 3.460279763057753*^9}, {3.46027987202001*^9, 
   3.460279929326695*^9}, {3.460279967324646*^9, 3.46027997674712*^9}, {
   3.460282349939086*^9, 3.4602823549144163`*^9}, {3.460282784722953*^9, 
   3.460282801190708*^9}, {3.460282835222114*^9, 3.460283098220755*^9}, {
   3.4602831366017437`*^9, 3.46028316523487*^9}, {3.460284499977572*^9, 
   3.4602846111225557`*^9}, {3.460284647887047*^9, 3.460284660037141*^9}, {
   3.460284706170504*^9, 3.460284707028002*^9}, {3.460284826503705*^9, 
   3.460284868358535*^9}, {3.460284916695053*^9, 3.460284961298512*^9}, {
   3.460285127766464*^9, 3.460285132950951*^9}, {3.460285226420979*^9, 
   3.4602852820574627`*^9}, {3.460285317086361*^9, 3.460285318206476*^9}, {
   3.4602854642893744`*^9, 3.460285482471323*^9}, {3.4602855234027843`*^9, 
   3.4602855440981197`*^9}, {3.4602857779503307`*^9, 
   3.4602857819794283`*^9}, {3.460285817792054*^9, 3.4602858207826433`*^9}, {
   3.4602859174667187`*^9, 3.460285930023323*^9}, 3.460342692301155*^9, {
   3.460342777814019*^9, 3.46034278769788*^9}, {3.4603433422695503`*^9, 
   3.460343349850721*^9}, {3.460343396242371*^9, 3.460343484730915*^9}, {
   3.4603436369330587`*^9, 3.4603439074483213`*^9}, {3.460343972471846*^9, 
   3.4603440498963337`*^9}, {3.460344227510378*^9, 3.460344265735627*^9}, {
   3.4603444047070417`*^9, 3.460344534150508*^9}, {3.4603445912321587`*^9, 
   3.460344784896298*^9}, {3.460344921653266*^9, 3.460344974081581*^9}, {
   3.4603451096385717`*^9, 3.46034520251552*^9}, 3.460345246115415*^9, 
   3.4603453567706003`*^9, {3.4603454172412558`*^9, 3.460345447428486*^9}, {
   3.46034549581929*^9, 3.4603455420148697`*^9}, 3.4603455735194817`*^9, {
   3.460364040779513*^9, 3.460364070906877*^9}, {3.460364114400744*^9, 
   3.460364118558858*^9}, {3.460364167066555*^9, 3.460364175124312*^9}, {
   3.460364210010396*^9, 3.460364240151005*^9}, {3.460364322034679*^9, 
   3.4603644028696136`*^9}, {3.460364789547168*^9, 3.460364791139002*^9}, {
   3.460364839217485*^9, 3.460364955498816*^9}, {3.460365024686344*^9, 
   3.4603650444987183`*^9}, {3.460365078184608*^9, 3.460365085863439*^9}, {
   3.460365172070264*^9, 3.460365237129417*^9}, {3.460365305570582*^9, 
   3.4603653112242393`*^9}, {3.460365389295981*^9, 3.460365401230237*^9}, {
   3.460365659465868*^9, 3.460365673436064*^9}, {3.4603657435143757`*^9, 
   3.460365779346396*^9}, {3.460365810556965*^9, 3.460365812812614*^9}, {
   3.4603658931474333`*^9, 3.460365963229039*^9}, {3.460366042607856*^9, 
   3.4603662381997623`*^9}, {3.460366298650962*^9, 3.4603664489586897`*^9}, {
   3.460366479298209*^9, 3.460366481733535*^9}, {3.460366720220016*^9, 
   3.460366755444069*^9}, {3.460366809463408*^9, 3.460366835407606*^9}, {
   3.460366869300931*^9, 3.4603668837833767`*^9}, {3.460366939043384*^9, 
   3.460367079108756*^9}, {3.460368872324092*^9, 3.46036887464939*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 CellLabel->"In[478]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Misc",
 FontWeight->"Bold"]], "Section",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"symmetric", "[", "A_", "]"}], ":=", 
   RowBox[{".5", " ", 
    RowBox[{"(", 
     RowBox[{"A", "+", 
      RowBox[{"Transpose", "[", "A", "]"}]}], ")"}]}]}], ";"}]], "Input",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 CellLabel->"In[161]:="],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{"SymmetricMatrix", "[", 
    RowBox[{"vec_", ",", "p_", ",", 
     RowBox[{"opt_:", "\"\<obere\>\""}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "A"}], "}"}], ",", "\n", "\t", 
     RowBox[{
      RowBox[{"n", "=", "0"}], ";", "\n", "\t", 
      RowBox[{"A", "=", 
       RowBox[{"Shape", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"p", ",", "p"}], "}"}]}], "]"}]}], ";", "\n", "    ", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"opt", "==", "\"\<obere\>\""}], ",", "\n", "        ", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", " ", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"[", 
               RowBox[{"j", ",", "i"}], "]"}], "]"}], "=", 
             RowBox[{"vec", "[", 
              RowBox[{"[", 
               RowBox[{"n", "+=", "1"}], "]"}], "]"}]}]}], ";"}], " ", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "p"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "i", ",", "p"}], "}"}]}], "]"}], ",", "\n", 
        "        ", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"A", "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", " ", 
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"[", 
               RowBox[{"j", ",", "i"}], "]"}], "]"}], "=", 
             RowBox[{"vec", "[", 
              RowBox[{"[", 
               RowBox[{"n", "+=", "1"}], "]"}], "]"}]}]}], ";"}], " ", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "p"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "1", ",", "i"}], "}"}]}], "]"}]}], "\n", 
       "        ", "]"}], ";", "\n", "    ", "A"}]}], "\n", "    ", "]"}]}],
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}]], "Input",
 CellMargins->{{19.8125, Inherited}, {Inherited, Inherited}},
 CellLabel->"In[398]:="],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Unprotect", "[", "RandomGauss", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Clear", "[", "RandomGauss", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"RandomGauss", "[", 
    RowBox[{"X_", ",", "Theta_", ",", 
     RowBox[{"{", 
      RowBox[{"mue_", ",", "sigma_"}], "}"}], ",", 
     RowBox[{"n_", "?", "IntegerQ"}], ",", 
     RowBox[{"Generator_", ":", "Gauss"}]}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m", ",", "s", ",", "s2"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"mue", "[", 
        RowBox[{"X", ",", "Theta"}], "]"}]}], ";", 
      RowBox[{"s", "=", 
       RowBox[{"sigma", "[", 
        RowBox[{"X", ",", "Theta"}], "]"}]}], ";", 
      RowBox[{"s2", "=", 
       RowBox[{"CholeskyDecomposition", "[", "s", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"m", "+", "#1"}], "&"}], ")"}], "/@", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Generator", "//", "ToExpression"}], ",", 
           RowBox[{"{", "n", "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"Length", "[", "m", "]"}], "}"}]}], "]"}], ".", "s2"}], 
        ")"}]}]}]}], "]"}]}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{"RandomGauss", "[", 
   RowBox[{"mue_", ",", "sigma_", ",", 
    RowBox[{"n_", "?", "IntegerQ"}], ",", 
    RowBox[{"Generator_", ":", "Gauss"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "s2", "}"}], ",", 
    RowBox[{
     RowBox[{"s2", "=", 
      RowBox[{"CholeskyDecomposition", "[", "sigma", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"mue", "+", "#1"}], "&"}], ")"}], "/@", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Generator", "//", "ToExpression"}], ",", 
          RowBox[{"{", "n", "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Length", "[", "mue", "]"}], "}"}]}], "]"}], ".", "s2"}], 
       ")"}]}]}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Gauss", "[", "]"}], ":=", 
   RowBox[{
    RowBox[{"Plus", "@@", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Random", "[", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "12"}], "}"}]}], "]"}]}], "-", "6.0"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"symmetric", "[", "A_", "]"}], ":=", 
   RowBox[{".5", " ", 
    RowBox[{"(", 
     RowBox[{"A", "+", 
      RowBox[{"Transpose", "[", "A", "]"}]}], ")"}]}]}], ";"}]}], "Input",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 CellLabel->"In[162]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"max", "[", "x__", "]"}], ":=", 
   RowBox[{"Max", "[", "x", "]"}]}], ";", 
  RowBox[{"SetAttributes", "[", 
   RowBox[{"max", ",", "Listable"}], "]"}], ";"}]], "Input",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 CellLabel->"In[168]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"GRIDIJ", "[", 
   RowBox[{"PSI_", ",", "i_", ",", "J_", ",", "HI_", ",", "HJ_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "OUT", "}"}], ",", 
    RowBox[{
     RowBox[{"OUT", "=", "PSI"}], ";", 
     RowBox[{
      RowBox[{"OUT", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
      "=", 
      RowBox[{
       RowBox[{"OUT", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
       "+", 
       RowBox[{
       "HI", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}]}], ";", 
     
     RowBox[{
      RowBox[{"OUT", "\[LeftDoubleBracket]", "J", "\[RightDoubleBracket]"}], 
      "=", 
      RowBox[{
       RowBox[{"OUT", "\[LeftDoubleBracket]", "J", "\[RightDoubleBracket]"}], 
       "+", 
       RowBox[{
       "HJ", "\[LeftDoubleBracket]", "J", "\[RightDoubleBracket]"}]}]}], ";", 
     "OUT"}]}], "]"}]}]], "Input",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 CellLabelMargins->{{4, Inherited}, {Inherited, Inherited}},
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 CellLabel->"In[169]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"GRIDI", "[", 
   RowBox[{"PSI_", ",", "i_", ",", "HI_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "OUT", "}"}], ",", 
    RowBox[{
     RowBox[{"OUT", "=", "PSI"}], ";", 
     RowBox[{
      RowBox[{"OUT", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
      "=", 
      RowBox[{
       RowBox[{"OUT", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
       "+", 
       RowBox[{
       "HI", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}]}], ";", 
     "OUT"}]}], "]"}]}]], "Input",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 CellLabelMargins->{{4, Inherited}, {Inherited, Inherited}},
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 CellLabel->"In[170]:="],

Cell[BoxData[{
 StyleBox[
  RowBox[{
   RowBox[{"Unprotect", "[", "BlockDiagonalMatrix1", "]"}], ";"}],
  FontWeight->"Plain"], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{"Clear", "[", "BlockDiagonalMatrix1", "]"}],
  FontWeight->"Plain"], "\n", 
 StyleBox[
  RowBox[{
   RowBox[{"BlockDiagonalMatrix1", "[", "astern_", "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"beta", ",", "J"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"J", "=", 
       RowBox[{"astern", "//", "Length"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"beta", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"i", "\[Equal]", "j"}], ",", 
           RowBox[{"astern", "[", 
            RowBox[{"[", "i", "]"}], "]"}], ",", "0"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "J"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "1", ",", "J"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"beta", "=", 
       RowBox[{"ArrayFlatten", "[", "beta", "]"}]}]}]}], 
    "\[IndentingNewLine]", "]"}]}],
  FontWeight->"Plain"]}], "Input",
 CellMargins->{{20, 10}, {0, 10}},
 CellChangeTimes->{{3.460083156012978*^9, 3.460083167130968*^9}},
 CellLabel->"In[238]:="],

Cell[BoxData[{
 RowBox[{"Clear", "[", "SubDiagonalMatrix", "]"}], "\n", 
 RowBox[{
  RowBox[{"SubDiagonalMatrix", "[", 
   RowBox[{"astern_", ",", 
    RowBox[{"{", 
     RowBox[{"T_", ",", "p_"}], "}"}]}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"beta", ",", 
      RowBox[{"null", "=", 
       RowBox[{"Shape", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"p", ",", "p"}], "}"}]}], "]"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"TensorRank", "[", "astern", "]"}], "\[Equal]", "3"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"beta", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"i", "\[Equal]", 
             RowBox[{"j", "+", "1"}]}], ",", 
            RowBox[{"astern", "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", "null"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "T"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "0", ",", "T"}], "}"}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"beta", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"i", "\[Equal]", 
             RowBox[{"j", "+", "1"}]}], ",", "astern", ",", "null"}], "]"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "T"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "0", ",", "T"}], "}"}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"beta", "=", 
      RowBox[{"ArrayFlatten", "[", "beta", "]"}]}]}]}], "\[IndentingNewLine]",
    "]"}]}]}], "Input",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 CellLabel->"In[132]:="],

Cell[BoxData[{
 RowBox[{
  RowBox[{"DoUntil", "[", 
   RowBox[{"range_", ",", "cond_", ",", "body_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{"body", ";", 
       RowBox[{"If", "[", 
        RowBox[{"cond", ",", 
         RowBox[{"Break", "[", "]"}]}], "]"}]}], ",", "range"}], "]"}]}], 
   "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Attributes", "[", "DoUntil", "]"}], "=", "HoldAll"}], 
  ";"}]}], "Input",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 CellLabel->"In[173]:="],

Cell[BoxData[{
 RowBox[{
  RowBox[{"DoWhile", "[", 
   RowBox[{"range_", ",", "cond_", ",", "body_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"!", "cond"}], ",", 
         RowBox[{"Break", "[", "]"}]}], "]"}], ";", "body"}], ",", "range"}], 
     "]"}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Attributes", "[", "DoWhile", "]"}], "=", "HoldAll"}], 
  ";"}]}], "Input",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 CellLabel->"In[175]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"VecPrint", "[", 
   RowBox[{"veclist_", ",", "label_"}], "]"}], ":=", 
  RowBox[{"Print", "[", 
   RowBox[{"TableForm", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", "veclist", "]"}], ",", 
     RowBox[{"TableHeadings", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Automatic", ",", "label"}], "}"}]}], ",", 
     RowBox[{"TableDirections", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Column", ",", "Row"}], "}"}]}], ",", 
     RowBox[{"TableSpacing", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2"}], "}"}]}]}], "]"}], "]"}]}]], "Input",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 CellLabel->"In[33]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VecPrint", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"I2", ",", "I2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\"\<A\>\"", ",", "\"\<B\>\""}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[122]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      StyleBox["\[Null]",
       ShowStringCharacters->False], 
      TagBox["\<\"A\"\>",
       HoldForm], 
      TagBox["\<\"B\"\>",
       HoldForm]},
     {"1", 
      TagBox[GridBox[{
         {"1"},
         {"0"}
        },
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.5599999999999999]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       Column], 
      TagBox[GridBox[{
         {"1"},
         {"0"}
        },
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.5599999999999999]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       Column]},
     {"2", 
      TagBox[GridBox[{
         {"0"},
         {"1"}
        },
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.5599999999999999]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       Column], 
      TagBox[GridBox[{
         {"0"},
         {"1"}
        },
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.5599999999999999]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       Column]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[1.4]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, TableHeadings -> {Automatic, {"A", "B"}}, 
    TableDirections -> {Column, Row}, TableSpacing -> {1, 2}]]]], "Print",
 CellLabel->"During evaluation of In[122]:="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"KroneckerProduct", "[", 
   RowBox[{"a_", ",", "b_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"ab", ",", "i", ",", "j", ",", "k", ",", "l"}], "}"}], ",", 
    RowBox[{
     RowBox[{"ab", "=", 
      RowBox[{"Outer", "[", 
       RowBox[{"Times", ",", "a", ",", "b"}], "]"}]}], ";", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k", ",", "l"}], "}"}], "=", 
      RowBox[{"Dimensions", "[", "ab", "]"}]}], ";", 
     RowBox[{"ab", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Transpose", "[", 
        RowBox[{"ab", ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "3", ",", "2", ",", "4"}], "}"}]}], "]"}], 
       "]"}]}], ";", 
     RowBox[{"Partition", "[", 
      RowBox[{"ab", ",", 
       RowBox[{"j", " ", "l"}]}], "]"}]}]}], "]"}]}]], "Input",
 CellMargins->{{19.625, 29}, {Inherited, Inherited}},
 InitializationCell->True,
 CellLabelMargins->{{73, Inherited}, {Inherited, Inherited}},
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 CellLabel->"In[178]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Shape", "[", 
   RowBox[{"A_", ",", "p_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"pp", ",", "prod", ",", "a"}], "}"}], ",", 
    RowBox[{
     RowBox[{"a", "=", "A"}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "a", "]"}], "==", "0"}], ",", 
       RowBox[{"Return", "[", 
        RowBox[{"Array", "[", 
         RowBox[{
          RowBox[{"a", "&"}], ",", "p"}], "]"}], "]"}]}], "]"}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "p", "]"}], "==", "1"}], ",", 
       RowBox[{"Return", "[", 
        RowBox[{"Flatten", "[", "a", "]"}], "]"}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", "p", "]"}], "==", "2"}], ",", 
         RowBox[{"Return", "[", 
          RowBox[{"Take", "[", 
           RowBox[{
            RowBox[{"Partition", "[", 
             RowBox[{
              RowBox[{"Flatten", "[", "a", "]"}], ",", 
              RowBox[{
              "p", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
             "]"}], ",", 
            RowBox[{
            "p", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
           "]"}], "]"}], ",", 
         RowBox[{
          RowBox[{"pp", "=", 
           RowBox[{"Drop", "[", 
            RowBox[{"p", ",", "1"}], "]"}]}], ";", 
          RowBox[{"prod", "=", 
           RowBox[{"Times", "@@", "pp"}]}], ";", 
          RowBox[{"a", "=", 
           RowBox[{"Partition", "[", 
            RowBox[{
             RowBox[{"Flatten", "[", "a", "]"}], ",", "prod"}], "]"}]}], ";", 
          
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Shape", "[", 
              RowBox[{"#1", ",", "pp"}], "]"}], "&"}], ")"}], "/@", "a"}]}]}],
         "]"}]}], "]"}]}]}], "]"}]}]], "Input",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 CellLabel->"In[179]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Spalte", "[", "x_", "]"}], ":=", 
  RowBox[{"Shape", "[", 
   RowBox[{"x", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Length", "[", "x", "]"}], ",", "1"}], "}"}]}], 
   "]"}]}]], "Input",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 CellLabel->"In[180]:="],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"BlockDiagonalMatrix", "[", 
    RowBox[{"{", 
     RowBox[{"a_List", ",", "b_List"}], "}"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a1", ",", "a2", ",", "null1", ",", "null2"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a1", ",", "a2"}], "}"}], "=", 
       RowBox[{"Dimensions", "[", "a", "]"}]}], ";", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"b1", ",", "b2"}], "}"}], "=", 
       RowBox[{"Dimensions", "[", "b", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"null1", "=", 
       RowBox[{"Shape", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"a1", ",", "b2"}], "}"}]}], "]"}]}], ";", 
      RowBox[{"null2", "=", 
       RowBox[{"Shape", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"b1", ",", "a2"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"ArrayFlatten", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"a", ",", "null1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"null2", ",", "b"}], "}"}]}], "}"}], "]"}]}]}], "]"}]}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BlockDiagonalMatrix", "[", "x_List", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "hilf", "}"}], ",", 
    RowBox[{
     RowBox[{"hilf", "=", 
      RowBox[{"BlockDiagonalMatrix", "[", 
       RowBox[{"Drop", "[", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1"}]}], "]"}], "]"}]}], ";", 
     RowBox[{"BlockDiagonalMatrix", "[", 
      RowBox[{"{", 
       RowBox[{"hilf", ",", 
        RowBox[{"Last", "[", "x", "]"}]}], "}"}], "]"}]}]}], 
   "]"}]}]}], "Input",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 CellLabel->"In[88]:="],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"all", "[", "A_", "]"}], ":=", 
   RowBox[{"And", "@@", 
    RowBox[{"Flatten", "[", "A", "]"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"gr", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{"x", ">", "y"}]}], ";", 
  RowBox[{"SetAttributes", "[", 
   RowBox[{"gr", ",", "Listable"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ii", "=", "AppendRows"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"vv", " ", "=", " ", "AppendColumns"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"VecDiag", "=", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"#1", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}]}], "]"}], "&"}]}], ";"}]}], "Input",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 CellLabel->"In[183]:="],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Varianz", "[", "y_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"yy", ",", "n", ",", "SML", ",", "S", ",", "means"}], "}"}], ",", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"TensorRank", "[", "y", "]"}], "===", "1"}], ",", 
       RowBox[{"yy", "=", 
        RowBox[{"Spalte", "[", "y", "]"}]}], ",", 
       RowBox[{"yy", "=", "y"}]}], "]"}], ";", 
     RowBox[{"n", "=", 
      RowBox[{"First", "[", 
       RowBox[{"Dimensions", "[", "yy", "]"}], "]"}]}], ";", 
     RowBox[{"means", "=", 
      RowBox[{"mean", "[", "yy", "]"}]}], ";", 
     RowBox[{"SML", "=", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"Transpose", "[", "yy", "]"}], ".", "yy"}], "n"], "-", 
       RowBox[{"Outer", "[", 
        RowBox[{"Times", ",", "means", ",", "means"}], "]"}]}]}], ";", 
     RowBox[{"S", "=", 
      FractionBox[
       RowBox[{"n", " ", "SML"}], 
       RowBox[{"n", "-", "1"}]]}], ";", 
     RowBox[{"{", 
      RowBox[{"SML", ",", "S", ",", "means"}], "}"}]}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"mean", "[", "y_", "]"}], ":=", 
   FractionBox[
    RowBox[{"Plus", "@@", "y"}], 
    RowBox[{"First", "[", 
     RowBox[{"Dimensions", "[", "y", "]"}], "]"}]]}], ";"}]}], "Input",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 CellLabel->"In[188]:="],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"AddTimeAxis", "[", 
    RowBox[{"X_", ",", 
     RowBox[{"dt_:", "1.0"}]}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "T", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"T", "=", 
       RowBox[{"Length", "[", "X", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"AppendRows", "[", 
       RowBox[{
        RowBox[{"Shape", "[", 
         RowBox[{
          RowBox[{"dt", " ", 
           RowBox[{"Range", "[", 
            RowBox[{"0", ",", 
             RowBox[{"T", "-", "1"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"T", ",", "1"}], "}"}]}], "]"}], ",", "X"}], "]"}]}]}], 
    "]"}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"AddTimeAxis", "[", 
    RowBox[{"X_", ",", 
     RowBox[{"{", 
      RowBox[{"t0_", ",", "t1_", ",", "dt_"}], "}"}]}], "]"}], ":=", 
   RowBox[{"AppendRows", "[", 
    RowBox[{
     RowBox[{"Spalte", "[", 
      RowBox[{"Range", "[", 
       RowBox[{"t0", ",", "t1", ",", "dt"}], "]"}], "]"}], ",", "X"}], 
    "]"}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input",
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 CellTags->"plot1",
 CellLabel->"In[392]:="],

Cell[TextData[{
 "\nnnn = 1000; \n\nOptions[plot1] = {PlotJoined->True,\n\t\t\t\t  \
PlotRange->All,\n                  Frame->True,\n                  \
Axes->False,\n                  dicke->.003,\n\t                 \
gestrichelt->1,\n\t                 color->Range[nnn],\n\t                 \
DisplayFunction->$DisplayFunction,\n\t                 farbmodell->eigene,\n\t\
                 text->Array[(\" \")&,nnn],\n\t                 \
TEXTSHIFT->Array[{0,0}&,nnn],\n\t                 permute->Range[nnn],\n\t    \
             print->False,\n\t                 Opacity->Array[1&,nnn]};",
 StyleBox["\n   \n\n",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["plot1",
  FontColor->RGBColor[1, 0, 0]],
 "[Data_List,opts___Rule]:= \n\t \n\tModule[{d,d1,dash,Datai,i,ii,gi,g,f,\n\t\
\t\tjoin1,plotrange,dicke1,frame1,axes1,gestrichelt1,color1,epilog1,\
aspectratio1,\n\t\t\t\
optionen,display1,farbe1,text1,textcoords,textshift,print1},\n\t     \n\t     \
\t\t\n\t{join1,     \
plotrange,dicke1,frame1,axes1,gestrichelt1,color1,display1,       farbe1    \
,text1,textshift,permute1,opacity} = \n\t{PlotJoined,PlotRange,dicke, Frame, \
Axes, gestrichelt, color, DisplayFunction,farbmodell,text, \
TEXTSHIFT,permute,Opacity} /. {opts} /. Options[plot1];\n\t\n\tprint1=print/. \
{opts} /. Options[plot1];\n\t\t \n\t\t \n If[TensorRank[      dicke1]==0,     \
 dicke1 = Array[dicke1&,nnn]]; \n If[TensorRank[gestrichelt1]==0,gestrichelt1 \
= Array[gestrichelt1&,nnn]];\n If[TensorRank[      color1]==0,      color1 = \
Array[color1&,nnn]];  \n  \n  \
(*Print[\"Optionen:{dicke,gestrichelt,color,epilog}\"];*)\n (* \
Print[{join1,dicke1,gestrichelt1,color1,epilog1,aspectratio1}];*)\n \n \
(*gestrichelt1//Print;*)\n \n\t     Farben = {RGBColor[.1,.1,.9],\n\t         \
      RGBColor[.1,.9,.8],\n\t               RGBColor[0.875, 0.202, 0.515],\n\t\
               RGBColor[.4,.3,.6],\n\t               RGBColor[.9,.3,.4],\n\t  \
             RGBColor[.9,.0,.2],\n\t               RGBColor[.4,.0,.9],\n\t\t\t\
             RGBColor[.6,.9,.4],\n\t\t\t             RGBColor[.6,.1,.4],\n\t\t\
\t             RGBColor[.0,.0,.0]};\n\t\t\t            \n\t     Farben = \
{Blue,\n\t               SpringGreenMedium,\n\t               Red,            \
\n\t               Yellow,\n\t               (*BlueViolet,*)\n\t              \
 DarkSlateBlue,\n\t               CadmiumOrange,\n\t               Magenta,\n\
\t               TurquoiseDark,\n\t               VioletRedPale,\n\t          \
     Black};\n\t               \n\t\t If[farbe1 === eigene,    Farben,\n\t\t \
If[farbe1 === Hue,       Farben = Map[Hue,Range[.1,1,.1]//Reverse],\n\t\t \
If[farbe1 === GrayLevel, Farben = Map[GrayLevel,Range[0,.9,.1] ],\n\t\t \t\t\t\
\t\t                    Farben = farbe1 ]]];\n\t     f = Length[Farben];\n\t  \
   color1 = Mod[color1-1,f]+1; (* nur zulaessige Farben*) \n\t     \t\t       \
            \t\t          \t\t\t\n\t\t dash = Map[Dashing,\n\t\t      \t.01{{ \
  },\n\t\t \t\t    {1,1},\n\t\t \t\t    {2,4},\n\t                {1,2},\n\t\t\
\t    \t{4,4},\n\t           \t    {4,1},\n\t           \t    {1,4},\n\t\t\t  \
 \t\t{1,3,1},\n\t\t\t   \t\t{.8},\n\t           \t    {5,2}\n\t               \
\t\t}];\n\t     f = Length[dash];\n\t     gestrichelt1 = \
Mod[gestrichelt1-1,f]+1; (* nur zulaessige Muster *) \n\t  \n\t\t \t\t\t\t\t\n\
\t\t d = Dimensions[Data];\n\t\t If[print1,Print[\"Dimension der Daten  \
\",d]];\n\t\t\t\n\t\t\t \n\t\t If[Dimensions[d]=={1}, (* Vektor *)\n\t\t \n\t\
\t \t\t\tg = plot1[Data//Spalte//AddTimeAxis,opts];Return[g], (*rekursiver \
Aufruf*)\n\t\t \t\t\t\n\t\t (* else *)\n\t\t   \n\t\t If[d[[2]]===1, (* \
Spalten-Vektor *)\n\t\t \t  g = plot1[Data//AddTimeAxis,opts];Return[g],      \
   (*rekursiver Aufruf*)\n\t\t \t\n\t\t (* else *)\n\t\t \n\t\t \
d1=d[[1]]//Range;\n\t\t g = {};\n\t\t \n\t\t Do[\n\t\t \n\t\t  ii = \
permute1[[i-1]];\n\t\t \t\n\t\t \tDatai = Data[[d1,{1,ii+1}]];\n\t\t \t\n\t\t \
\t\n\t\t \tlinks  = (Datai//First); \n\t\t \trechts = (Datai//Last);\n\t\t \t\
mitte  =  Datai[[ d[[1]]/2//Floor ]];\n\t\t \t\n\t\t \t\
If[(text1//Last)===\"Links\", textcoords = links,\n\t\t \t\t\t\t\t \n\t\t \t\
If[(text1//Last)===\"Rechts\",textcoords = rechts,\n\t\t \t\t\t\t\t\t\t\t \n\t\
\t \tIf[(text1//Last)===\"Mitte\",\ttextcoords = mitte,\n\t\t \t\n\t\t \t\
If[IntegerQ[(text1//Last)],\ttextcoords = Datai[[text1//Last]],\n\t\t \t\n\t\t\
 \t                            textcoords = rechts\n\t\t \t]]]];\n\t\t \t\t\t\
\t\t\t\t\t \n\t\t \ttextcoords = textcoords + textshift[[ii]];\n\t\t \t\n\t\t \
\tgi = ListPlot[Datai, FilterRules[{opts}, Options[ListPlot]],\n\t\t \t       \
              DisplayFunction->Identity,\n\t\t \t\t\t\t  \t     \
PlotJoined->join1,\n\t\t \t\t\t\t  \t     PlotRange->plotrange,\n\t\t \t\t\t\t\
  \t     Frame->frame1,\n\t\t \t\t\t\t  \t     Axes->axes1,\n\t\t\t           \
          PlotStyle->\n\t\t\t                     {Farben[[color1[[ii]] ]],\n\
\t\t\t                   \t PointSize[ dicke1[[ii]] ],\n\t\t \t\t\t\t\t\t \
Thickness[ dicke1[[ii]] ],\n\t\t \t\t\t\t\t\t dash[[ gestrichelt1[[ii]] ]],\n\
\t\t \t\t\t\t\t\t Text[text1[[ii]],textcoords],\n\t\t \t\t\t\t\t\t \
Opacity[opacity[[ii]]]}];\n\t\t \t\n\t\t   \n\t\t    g = Join[g,{gi}],\n\t\t \
\n\t\t {i, 2, d[[2]]}];\n\t\t \t\t \t\t\t\t\t\n\t\t];\n\t\t\n\t\t\
(*FilterRules[{opts}, Options[ListPlot]]//Print;*)\n\t\t\n\t\tg = \
Show[g,DisplayFunction->display1];\n\t\n  Return[g];\n    \n\t\t];\n\t\t\t\n  \
  \n](*End of plot1*)"
}], "Input",
 CellMargins->{{19, 10}, {0, 10}},
 InitializationCell->True,
 CellChangeTimes->{{3.4604614594324217`*^9, 3.460461501578444*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 CellTags->"plot1",
 CellLabel->"In[3822]:="],

Cell["\<\
connectdatasets//Clear
connectdatasets[X_,opts___]:=
Module[{g1,g2,arrow1},
arrow1=arrow/.{opts};
{t,n,p}=X//Dimensions;
nX=Join[{n//Range},X];
g1=MapThread[plot1[{##2},farbmodell->Hue,dicke->.03,opts,PlotJoined->False,
                   color->#1,DisplayFunction->Identity]&,nX];
g2=MapThread[plot1[{##2},farbmodell->Hue,opts,PlotJoined->True,       
                   color->#1,DisplayFunction->Identity]&,nX];
g3=If[arrow1, \
phaseplotarrowmultiple[X//Transpose,DisplayFunction->Identity],{},{}];

Show[g1,g2,g3,DisplayFunction->$DisplayFunction]

]\
\>", "Input",
 PageWidth->Infinity,
 CellMargins->{{19.875, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 CellLabel->"In[172]:="],

Cell[BoxData[{
 StyleBox[
  RowBox[{
   RowBox[{"missings", "[", 
    RowBox[{"z_", ",", "miss_", ",", "op_"}], "]"}], ":=", 
   RowBox[{"Apply", "[", 
    RowBox[{"op", ",", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"#", "===", "miss"}], ")"}], "&"}], ",", "z"}], "]"}]}], 
    "]"}]}],
  FontWeight->"Plain"], "\n", 
 StyleBox[
  RowBox[{
   RowBox[{"CaseDel", "[", 
    RowBox[{"Z_", ",", "miss_"}], "]"}], ":=", 
   RowBox[{"Select", "[", 
    RowBox[{"Z", ",", 
     RowBox[{
      RowBox[{"Not", "[", 
       RowBox[{"missings", "[", 
        RowBox[{"#", ",", "miss", ",", "Or"}], "]"}], "]"}], "&"}]}], "]"}]}],
  
  FontWeight->"Plain"]}], "Input",
 CellMargins->{{19.8125, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 CellLabel->"In[62]:="],

Cell[CellGroupData[{

Cell["\<\
(*Unprotect[HeadWidth,Arrow];
Clear[HeadWidth,Arrow];
Remove[HeadWidth,Arrow];
<<Graphics`Arrow`
*)\
\>", "Input",
 CellMargins->{{19.8125, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 CellChangeTimes->{{3.460125544016913*^9, 3.460125563553335*^9}, {
   3.460125619932405*^9, 3.460125630260145*^9}, 3.4601257131889477`*^9, 
   3.460125746505066*^9, {3.4601259289814167`*^9, 3.4601259346288967`*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 CellLabel->"In[475]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"obspkg\"\>"}], 
  RowBox[{
  ":", " "}], \
"\<\"\[NoBreak]\\!\\(\\*StyleBox[\\!\\(\\\"Graphics`Arrow`\\\"\\), \
\\\"MT\\\"]\\)\[NoBreak]\\!\\(\\*StyleBox[\\\"\\\\\\\" is now obsolete. The \
legacy version being loaded may conflict with current Mathematica \
functionality. See the Compatibility Guide for updating \
information.\\\\\\\"\\\", \\\"MT\\\"]\\) \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:Compatibility/Tutorials/Graphics/Arrow\\\", ButtonNote \
-> \\\"General::obspkg\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.46012571553447*^9, 3.4601257476834373`*^9, 
  3.460125877229974*^9},
 CellLabel->"During evaluation of In[475]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Arrow"}]], "Input",
 CellChangeTimes->{{3.460125721006076*^9, 3.46012572333494*^9}, 
   3.460125872182432*^9},
 CellLabel->"In[8]:="],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\!\(\*RowBox[{\\\"Arrow\\\", \\\"[\\\", RowBox[{\\\"{\\\", \
RowBox[{SubscriptBox[StyleBox[\\\"pt\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \\\
\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"pt\\\", \\\"TI\\\"], \
StyleBox[\\\"2\\\", \\\"TR\\\"]]}], \\\"}\\\"}], \\\"]\\\"}]\) is a graphics \
primitive which represents an arrow from \!\(\*SubscriptBox[StyleBox[\\\"pt\\\
\", \\\"TI\\\"], StyleBox[\\\"1\\\", \\\"TR\\\"]]\) to \
\!\(\*SubscriptBox[StyleBox[\\\"pt\\\", \\\"TI\\\"], StyleBox[\\\"2\\\", \
\\\"TR\\\"]]\).\\n\!\(\*RowBox[{\\\"Arrow\\\", \\\"[\\\", \
RowBox[{RowBox[{\\\"{\\\", RowBox[{SubscriptBox[StyleBox[\\\"pt\\\", \\\"TI\\\
\"], StyleBox[\\\"1\\\", \\\"TR\\\"]], \\\",\\\", \
SubscriptBox[StyleBox[\\\"pt\\\", \\\"TI\\\"], StyleBox[\\\"2\\\", \
\\\"TR\\\"]]}], \\\"}\\\"}], \\\",\\\", StyleBox[\\\"s\\\", \\\"TI\\\"]}], \\\
\"]\\\"}]\) represents an arrow with its ends set back from \
\!\(\*SubscriptBox[StyleBox[\\\"pt\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \
\\\"TR\\\"]]\) and \!\(\*SubscriptBox[StyleBox[\\\"pt\\\", \\\"TI\\\"], \
StyleBox[\\\"2\\\", \\\"TR\\\"]]\) by a distance \!\(\*StyleBox[\\\"s\\\", \\\
\"TI\\\"]\). \\n\!\(\*RowBox[{\\\"Arrow\\\", \\\"[\\\", RowBox[{RowBox[{\\\"{\
\\\", RowBox[{SubscriptBox[StyleBox[\\\"pt\\\", \\\"TI\\\"], StyleBox[\\\"1\\\
\", \\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"pt\\\", \\\"TI\\\"], \
StyleBox[\\\"2\\\", \\\"TR\\\"]]}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{SubscriptBox[StyleBox[\\\"s\\\", \\\"TI\\\"], \
StyleBox[\\\"1\\\", \\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"s\\\", \
\\\"TI\\\"], StyleBox[\\\"2\\\", \\\"TR\\\"]]}], \\\"}\\\"}]}], \\\"]\\\"}]\) \
sets back by \!\(\*SubscriptBox[StyleBox[\\\"s\\\", \\\"TI\\\"], \
StyleBox[\\\"1\\\", \\\"TR\\\"]]\) from \
\!\(\*SubscriptBox[StyleBox[\\\"pt\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \
\\\"TR\\\"]]\) and \!\(\*SubscriptBox[StyleBox[\\\"s\\\", \\\"TI\\\"], \
StyleBox[\\\"2\\\", \\\"TR\\\"]]\) from \
\!\(\*SubscriptBox[StyleBox[\\\"pt\\\", \\\"TI\\\"], StyleBox[\\\"2\\\", \
\\\"TR\\\"]]\). \"\>", "MSG"], "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Arrow"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.460125923797621*^9},
 CellTags->"Info3460133123-4927937"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Arrow", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}]}], "}"}], "]"}], "//", 
  "Graphics"}]], "Input",
 CellChangeTimes->{{3.460126009809121*^9, 3.460126056769907*^9}, {
  3.4601260921795607`*^9, 3.460126099022417*^9}, {3.460126422248934*^9, 
  3.460126424710491*^9}},
 CellLabel->"In[1066]:="],

Cell[BoxData[
 GraphicsBox[ArrowBox[{{1, 1}, {2, 2}}],
  ImageSize->{137., Automatic}]], "Output",
 CellChangeTimes->{{3.460126028206565*^9, 3.460126058173773*^9}, {
   3.460126096144312*^9, 3.4601260991416807`*^9}, 3.460126425913013*^9, 
   3.460127042267761*^9, 3.4601979244019957`*^9},
 CellLabel->"Out[1066]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"??", "Text"}]], "Input",
 CellChangeTimes->{{3.4601259591052847`*^9, 3.4601259603139877`*^9}},
 CellLabel->"In[9]:="],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\\!\\(\\*RowBox[{\\\"Text\\\", \\\"[\\\", StyleBox[\\\"expr\\\
\", \\\"TI\\\"], \\\"]\\\"}]\\) displays with \\!\\(\\*StyleBox[\\\"expr\\\", \
\\\"TI\\\"]\\) in plain text format. \\n\\!\\(\\*RowBox[{\\\"Text\\\", \
\\\"[\\\", RowBox[{StyleBox[\\\"expr\\\", \\\"TI\\\"], \\\",\\\", StyleBox[\\\
\"coords\\\", \\\"TI\\\"]}], \\\"]\\\"}]\\) is a graphics primitive that \
displays the textual form of \\!\\(\\*StyleBox[\\\"expr\\\", \\\"TI\\\"]\\) \
centered at the point specified by \\!\\(\\*StyleBox[\\\"coords\\\", \\\"TI\\\
\"]\\). \"\>", "MSG"], "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Text"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.460125961647484*^9},
 CellTags->"Info3460133161-7256246"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {
     RowBox[{
      RowBox[{"Attributes", "[", "Text", "]"}], "=", 
      RowBox[{"{", 
       RowBox[{"Protected", ",", "ReadProtected"}], "}"}]}]},
    {" "},
    {GridBox[{
       {
        RowBox[{
         RowBox[{"Options", "[", "Text", "]"}], "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Background", "\[Rule]", "None"}], ",", 
           RowBox[{"ContentSelectable", "\[Rule]", "Automatic"}], ",", 
           RowBox[{"FormatType", "\[RuleDelayed]", "Automatic"}]}], "}"}]}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition[Text],
  Editable->False]], "Print",
 CellChangeTimes->{3.4601259616615677`*^9},
 CellTags->"Info3460133161-7256246"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Compress//Unprotect;\nCompress[a_,b_]:= \
Delete[b,Position[a,False]];\n\nAPLCompress//Unprotect;\nAPLCompress[a_,b_]:= \
Delete[b,Position[a,0]];\n\nSelectIndex[a_,op_]:= \n\tModule[{f,a1},\n\tf = \
If[op[ #2[[1]],#2[[2]] ],#1,{}]&;\n\ta1 = MapIndexed[f, a,{2}];\n\t\
Map[Flatten,a1]\n\t]\n\t\nDelta[x_,lag_:1] := Drop[x,lag] - Drop[x,-lag]\n\
Delta[x_,y_,op_,lag_:1]:= MapThread[op,{Drop[x,lag],Drop[y,-lag]}]\n\n\
pNorm[x_,p_:2]:= Apply[Plus,Abs[x]^p]^(1/p)\n",
  FontWeight->"Plain"],
 "\n\narrowshift=.0;textshift=.1;\n\n",
 StyleBox["BlaBlaDiagramm",
  FontColor->RGBColor[0, 0, 1]],
 "//Clear;\n",
 StyleBox["BlaBlaDiagramm",
  FontColor->RGBColor[0, 0, 1]],
 "[xy_,text_,r_,mask1_:1,mask2_:1,text1_,text2_,fontsize_:18,opts___]:=\n\
Module[{c,c1,t,n,xyij,dxyij,e},\n\nc=Map[Circle[#,r]&,xy];\n\
t=MapThread[Text[#1,#2]&,{text,xy+.02}];\n\nn=xy//Length;\n\
xyij=Table[xy[[{i,j}]],{i,n},{j,i+1,n}]//Flatten[#,1]&;\n\
dxyij=Flatten[Map[Delta,xyij],1];\ne=dxyij/Map[pNorm,dxyij];\nwidth=.3;\n\
anfang=xyij[[All,1]]+r e;\nende  =xyij[[All,2]]-r e;\n\n(*\n\
mask1TF=mask1/.{1->True,0->False};\nmask2TF=mask2/.{1->True,0->False};\n*)\n\n\
a12=MapThread[Arrow[{#1,#2}]&,{anfang,ende}-arrowshift];\n\
a21=MapThread[Arrow[{#1,#2}]&,{anfang,ende}+arrowshift//Reverse];\n\n\
a12=APLCompress[mask1TF,a12];\na21=APLCompress[mask2TF,a21];\n\nc1=.4;\n\
mitte=(c1 anfang+(1-c1)ende); \nt12=MapThread[Text[#1,#2,Background\[Rule] \
LightRed]&,{text1,mitte-textshift}];\n\
t21=MapThread[Text[#1,#2,Background->LightBlue]&,{text2,mitte+textshift}];\n\n\
t12=APLCompress[mask1TF,t12];\nt21=APLCompress[mask2TF,t21];\n \n\nShow[\n\
Graphics[{Thickness[.003],Black,c,\n          Thickness[.003],Black,t,\n      \
    Thickness[.003],Red,a12,\n          Thickness[.003],Blue,a21,\n          \
Thickness[.003],Red,t12,\n          Thickness[.003],Blue,t21},\n          \
AspectRatio->Automatic,Frame->True,FrameTicks->False,\n          \
TextStyle->{FontFamily->\"Helvetica\",FontSize->fontsize}],opts]\n\n]\n\n\n\
BlaBlaDiagrammMatrix//Clear\n\
BlaBlaDiagrammMatrix[text_,r_,beta_,fontsize_:18,opts___]:=\n  Module[{},\n   \
 p=text//Length;\n    \n    \
(*xy=Take[Map[Reverse,Tuples[p/2//Ceiling//Range,2]],p]//Reverse;*)\n    \n   \
 dphi=Pi;\n    {phi0,phi1}={0, 2 Pi(1-1/p)}+dphi;\n    xy = \
Table[{Cos[phi],-Sin[phi]},{phi,phi0,phi1,(2 Pi/p)}];\n    (*xy = \
Table[{phi,-Sin[phi]},{phi,phi0,phi1,(2 Pi/p)}];*) (*linear*)\n    \n    \
beta01=Map[(#=!=0)&,beta//Rationalize,{2}]/.{1->True,0->False}//Rationalize;\n\
    mask2=SelectIndex[beta01,Less]//Flatten;  (*obere H\[ADoubleDot]lfte j\
\[Rule]i*)\n    mask1=SelectIndex[beta01//Transpose,Less]//Flatten;\n    \n   \
 text2=SelectIndex[beta,Less]//Flatten;  (*obere H\[ADoubleDot]lfte \
j\[Rule]i*)\n    text1=SelectIndex[beta//Transpose,Less]//Flatten;\n    \n    \
BlaBlaDiagramm[xy,text,r,mask1,mask2,text1,text2,fontsize,opts]\n    ]\n      \
    \n         "
}], "Input",
 CellMargins->{{19.8125, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 CellLabel->"In[137]:="],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p", "=", "3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"beta", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "b12", ",", "b13"}], "}"}], ",", 
      "\[IndentingNewLine]", "         ", 
      RowBox[{"{", 
       RowBox[{"b21", ",", "0", ",", "0"}], "}"}], ",", "\[IndentingNewLine]",
       "         ", 
      RowBox[{"{", 
       RowBox[{"0.", ",", "b32", ",", "0"}], "}"}]}], "}"}]}], ")"}], "//", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{"BlaBlaDiagrammMatrix", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", ".2", ",", "beta", ",", 
   "10"}], "]"}]}], "Input",
 CellChangeTimes->{
  3.460126584589143*^9, {3.46012680219063*^9, 3.460126835166645*^9}},
 CellLabel->"In[134]:="],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], "1", "2", "3"},
      {"1", "0", "b12", "b13"},
      {"2", "b21", "0", "0"},
      {"3", "0.`", "b32", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.24]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}], 
   "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellLabel->"Out[135]//MatrixForm="],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], Thickness[0.003], CircleBox[{-1, 0}, 0.2], 
    CircleBox[
     NCache[{Rational[1, 2], Rational[1, 2] 3^Rational[1, 2]}, {0.5, 
      0.8660254037844386}], 0.2], 
    CircleBox[
     NCache[{Rational[1, 2], Rational[-1, 2] 3^Rational[1, 2]}, {
      0.5, -0.8660254037844386}], 0.2]}, 
   {GrayLevel[0], Thickness[0.003], InsetBox["1", {-0.98, 0.02}], 
    InsetBox["2", {0.52, 0.8860254037844386}], 
    InsetBox["3", {0.52, -0.8460254037844386}]}, 
   {RGBColor[1, 0, 0], Thickness[0.003], 
    ArrowBox[{{-0.8267949192431123, 0.1}, {0.32679491924311227`, 
     0.7660254037844386}}], 
    ArrowBox[{{-0.8267949192431123, -0.1}, {
     0.32679491924311227`, -0.7660254037844386}}], 
    ArrowBox[{{0.5, 0.6660254037844386}, {0.5, -0.6660254037844386}}]}, 
   {RGBColor[0, 0, 1], Thickness[0.003], 
    ArrowBox[{{0.32679491924311227`, 
     0.7660254037844386}, {-0.8267949192431123, 0.1}}], 
    ArrowBox[{{
     0.32679491924311227`, -0.7660254037844386}, {-0.8267949192431123, \
-0.1}}], ArrowBox[{{0.5, -0.6660254037844386}, {0.5, 0.6660254037844386}}]}, 
   {RGBColor[1, 0, 0], Thickness[0.003], 
    InsetBox["b21", {-0.23464101615137758`, 0.39961524227066314`},
     Background->RGBColor[1, 0.85, 0.85]], 
    InsetBox["0.`", {-0.23464101615137758`, -0.5996152422706631},
     Background->RGBColor[1, 0.85, 0.85]], 
    InsetBox["b32", {0.4, -0.23320508075688776`},
     Background->RGBColor[1, 0.85, 0.85]]}, 
   {RGBColor[0, 0, 1], Thickness[0.003], 
    InsetBox["b12", {-0.034641016151377574`, 0.5996152422706631},
     Background->RGBColor[0.678396, 0.847102, 0.902005]], 
    InsetBox["b13", {-0.034641016151377574`, -0.39961524227066314`},
     Background->RGBColor[0.678396, 0.847102, 0.902005]], 
    InsetBox["0", {0.6, -0.033205080756887745`},
     Background->RGBColor[0.678396, 0.847102, 0.902005]]}},
  AspectRatio->Automatic,
  BaseStyle->{FontFamily -> "Helvetica", FontSize -> 10},
  Frame->True,
  FrameTicks->False,
  ImageSize->{304., Automatic}]], "Output",
 CellLabel->"Out[136]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Maximierung",
 FontWeight->"Bold"]], "Section",
 PageWidth->Infinity,
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"RESAMPLING", "=", "True"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"FDIGITS", "=", 
   RowBox[{"Round", "[", 
    RowBox[{"-", 
     RowBox[{"Log", "[", 
      RowBox[{"10", ",", "$MachineEpsilon"}], "]"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"TYP", "=", "1"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"YMAX", "=", "1000."}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ANALGRAD", "=", "False"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"FACTOR", "=", "1.0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"MAXSTEP", "=", "0.1"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"CSEED", "=", 
   RowBox[{"-", "999"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"SCALING", "=", "1"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"STEPREDUCE", "=", "4"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"FISHER", "=", "False"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"PRINT", "=", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
     "1"}], "}"}]}], ";"}]}], "Input",
 PageWidth->Infinity,
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 CellLabel->"In[5]:="],

Cell[CellGroupData[{

Cell["Lik,Score,BFGS", "Subsection",
 PageWidth->Infinity,
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain"],

Cell["\<\
Unprotect[Lik]; 
Clear[Lik]; 
Lik[data_, Theta_, {system_, LikN_}, misc_] := 
   Plus @@ (LikN[#1, Theta*SCALING, system, misc] & ) /@ data; 
Protect[Lik]; \
\>", "Input",
 PageWidth->Infinity,
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 CellLabel->"In[207]:="],

Cell["\<\
Unprotect[Lik1]; 
Clear[Lik1]; 
Lik1[data_, Theta_, {system_, LikN_}, misc_] := 
   Sum[LikN[data[[i]], Theta*SCALING, system, misc], 
    {i, 1, Length[data]}]; 
Protect[Lik1]; \
\>", "Input",
 PageWidth->Infinity,
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 CellLabel->"In[211]:="],

Cell["\<\
Clear[Score]; 
Score[data_, Theta_, {system_, {Lik_, LikN_}}, misc_] := 
   Module[{INC, i, LIK, LIKI, INC1, SNUM, ETA}, 
    LIK = Lik[data, Theta, {system, LikN}, misc]; 
     ETA = Max[$MachineEpsilon, 10.^(-FDIGITS)]; 
     INC = Sqrt[ETA]*max[Abs[Theta], Abs[TYP]]; INC1 = 1./INC; 
     SNUM = {}; u = Length[Theta]; Do[Thetai = GRIDI[Theta, i, INC]; 
       LIKI = Lik[data, Thetai, {system, LikN}, misc]; 
       SNUM = Append[SNUM, N[(LIKI - LIK)*INC1[[i]]]], {i, u}]; 
     {SNUM, LIK}]; \
\>", "Input",
 PageWidth->Infinity,
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 CellLabel->"In[215]:="],

Cell["\<\
Clear[Score2]; 
Score2[data_, Theta_, {system_, {Lik_, LikN_}}, misc_] := 
   Module[{INC, i, LIK, LIKup, LIKdo, INC1, SNUM, ETA}, 
    LIK = Lik[data, Theta, {system, LikN}, misc]; 
     ETA = Max[$MachineEpsilon, 10.^(-FDIGITS)]; 
     INC = ETA^(1/3)*max[Abs[Theta], Abs[TYP]]; 
     Print[\"Score2: INC: \", INC]; INC1 = 1/(2*INC); SNUM = {}; 
     Do[LIKup = Lik[data, GRIDI[Theta, i, INC], {system, LikN}, 
         misc]; LIKdo = Lik[data, GRIDI[Theta, i, -INC], 
         {system, LikN}, misc]; SNUM = Append[SNUM, 
         (LIKup - LIKdo)*INC1[[i]]], {i, Length[Theta]}]; 
     {SNUM, LIK}]; \
\>", "Input",
 PageWidth->Infinity,
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 CellLabel->"In[217]:="],

Cell["\<\
Hesse2[data_, Theta_, {system_, {Lik_, LikN_, Score_}}, misc_] := 
   Module[{INC, i, LIK, INC1, Sup, Sdo, DS, S, HNUM, SNUM, ETA}, 
    {S, LIK} = Score[data, Theta, {system, {Lik, LikN}}, misc]; 
     ETA = Max[$MachineEpsilon, 10.^(-FDIGITS)]; INC = ETA^(1/3); 
     INC = INC*max[Abs[Theta], Abs[TYP]]; INC1 = 1/(2*INC); 
     HNUM = {}; SNUM = {}; 
     Do[{Sup, likup} = Score[data, GRIDI[Theta, i, INC], 
         {system, {Lik, LikN}}, misc]; {Sdo, likdo} = 
        Score[data, GRIDI[Theta, i, -INC], {system, {Lik, LikN}}, 
         misc]; HNUM = Append[HNUM, (Sup - Sdo)*INC1[[i]]]; 
       SNUM = Append[SNUM, (likup - likdo)*INC1[[i]]], 
      {i, Length[Theta]}]; HNUM = 0.5*(HNUM + Transpose[HNUM]); 
     DS = S - SNUM; Print[
      \"KONTROLLE: NUMERISCHER SCORE - ZENTRALE DIFFERENZEN\"]; 
     Print[MatrixForm[Transpose[{SNUM, S, DS, Theta, INC}], 
       TableHeadings -> {Automatic, {\"SNUM\", \"S\", \"DS\", \"THETA\", 
          \"INC\"}}]]; {HNUM, LIK}]; \
\>", "Input",
 PageWidth->Infinity,
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 CellLabel->"In[219]:="],

Cell["\<\
Hesse[data_, Theta_, {system_, {Lik_, LikN_, Score_}}, misc_] := 
   Module[{LIK, L2, INK, INK2, H4, H, LIJ, LIMJ, LIJM, LIMJM, L2I, 
     LM2I, i, J, ETA}, LIK = Lik[data, Theta, {system, LikN}, misc]; 
     ETA = Max[$MachineEpsilon, 10.^(-FDIGITS)]; INC = ETA^(1/3); 
     INK = INC*max[Abs[Theta], Abs[TYP]]; Print[\"INK: \", INK]; 
     U = Length[Theta]; INK2 = 2*INK; 
     H4 = 0.25/Outer[Times, INK, INK]; L2 = 2*LIK; 
     H = Shape[0, {U, U}]; Do[{LIJ, LIMJ, LIJM, LIMJM} = 
        (Lik[data, #1, {system, LikN}, misc] & ) /@ 
         {GRIDIJ[Theta, i, J, INK, INK], GRIDIJ[Theta, i, J, INK, 
           -INK], GRIDIJ[Theta, i, J, -INK, INK], GRIDIJ[Theta, i, 
           J, -INK, -INK]}; H[[i,J]] = LIJ - LIMJ - LIJM + LIMJM; , 
      {i, 1, U}, {J, i + 1, U}]; H = H + Transpose[H]; 
     Do[{L2I, LM2I} = (Lik[data, #1, {system, LikN}, misc] & ) /@ 
         {GRIDI[Theta, i, INK2], GRIDI[Theta, i, -INK2]}; 
       H[[i,i]] = L2I - L2 + LM2I; , {i, 1, U}]; H = H*H4; 
     {H, LIK}]; \
\>", "Input",
 PageWidth->Infinity,
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 CellLabelMargins->{{4, Inherited}, {Inherited, Inherited}},
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 CellLabel->"In[220]:="],

Cell["\<\
Clear[BFGSUP]; 
BFGSUP[F_, SNEU_, S_, STEP_] := Module[{MACHEPS2, Y, FSTEP, A, B, 
     Fup, ETA}, ETA = Max[$MachineEpsilon, 10.^(-FDIGITS)]; 
     TOL = If[ANALGRAD, ETA, ETA^0.5, ETA^0.5]; 
     NOISE = (Max[Abs[SNEU]] + Max[Abs[S]])*TOL; 
     MACHEPS2 = $MachineEpsilon^0.5; Y = -SNEU + S; 
     FSTEP = F . STEP; A = Y . STEP; 
     If[A < MACHEPS2*Max[Abs[STEP]]*Max[Abs[Y]], Return[F]]; 
     If[Max[Abs[Y - FSTEP]] < NOISE, Return[F]]; A = 1/A; 
     B = 1/STEP . FSTEP; 
     (*Print[\"*BFGSUP \", A, \"  \", B];*)
     Fup = F + Outer[Times, A*Y, Y] - Outer[Times, B*FSTEP, FSTEP]; 
     Fup]; \
\>", "Input",
 PageWidth->Infinity,
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 CellLabelMargins->{{1, Inherited}, {Inherited, Inherited}},
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 CellLabel->"In[61]:="],

Cell["\<\
LikTest[LIKNEU_] := If[ !NumberQ[LIKNEU] || Im[LIKNEU] =!= 0 || 
     LIKNEU > 10.^10, Print[\"LIKNEU = \", LIKNEU, 
      \" reset to -10.^10\"]; -10.^10, LIKNEU]; \
\>", "Input",
 PageWidth->Infinity,
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 CellLabelMargins->{{1, Inherited}, {Inherited, Inherited}},
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 CellLabel->"In[223]:="],

Cell["\<\
Clear[BFGS]; 
BFGS[data_, {THETA0_, F0_}, {system_, {Lik_, LikN_, Score_, Hesse_}}, 
     {misc_, KMAX_, {EPS1_, EPS2_}, OPTION_, PRINT_}] :=
      
   Module[{MINSTEP, BOUND, ALPHA, u, THETA, THETA1, F, S, LIKALT, 
     LIKI, psii, scoreii, STEPL, STEP, LIKNEU, SNEU, likpsi, COV, 
     LIKELI, n, T, T1, Tc, P, Q, k, K, KK, Z, Y, X, ReturnCode}, 
     MINSTEP = 1/10.^10; FMAX = 10^3; BOUND = 1/10.^6; 
     ALPHA = 1/10.^4; 
     
     (*
     T = data[[1,2]]//Length;
     n = data[[1,3]];
     *)
      
     If[PRINT[[1]] == 1, 
       Print[\"***********************LSDE1**********************************\
\"]; 
       Print[\"***********************MODUL:    BFGS (skeleton)**************\
\"]; 
       Print[\"**************************************************************\
\"]; 
       Print[\"Technical Output\"]; Print[LikN]; 
       Print[\"**************************************************************\
\"]; 
       VecPrint[Spalte[{KMAX, EPS1, EPS2, K, Q, n, T, OPTION}], 
                      {\"KMAX\", \"EPS1\", \"EPS2\", \"K\", \"Q\", \"n\", \"T\
\", \"OPTION    \"}]; 
       Print[\"\"];
       VecPrint[Spalte[{MAXSTEP, MINSTEP, BOUND,STEPREDUCE, FMAX}], \
{\"MAXSTEP\", \"MINSTEP\", \"BOUND\", 
         \"STEPREDUCE\", \"FMAX\"}]; Print[\"\"]; 
       VecPrint[Spalte[{RESAMPLING, FDIGITS, TYP, YMAX, ANALGRAD, 
          FACTOR, CSEED}], {\"RESAMPLING\", \"FDIGITS\", \"TYP\", \"YMAX\", 
         \"ANALGRAD\", \"FACTOR\", \"CSEED\"}]; Print[\"\"]; 
       Print[\"    SCALING\"]; Print[MatrixForm[
         Transpose[Spalte[SCALING]], TableHeadings -> 
          {Automatic, {\"SCALING\"}}, TableDepth -> 0]]; Print[\"\"]; 
       Print[\"**************************************************************\
\"]; 
       Print[\"\"]; 
       Print[\"STARTWERT THETA0 = \", THETA0]]; 
     
     u = Length[THETA0]; 
     THETA = THETA0; 
     
     F = F0; 
     If[OPTION == 1, F = SHIFT[F, BOUND]]; 
     {S, LIKALT} = Score[data, THETA0, {system, {Lik, LikN}}, misc]; 
     Print[{S, LIKALT}]; LIKI = {}; psii = {}; scoreii = {}; 
     ReturnCode = 0; k = 0; 
     
     DoUntil[{KK, KMAX}, ReturnCode == 3, 
      If[PRINT[[2]] == 1, 
      Print[\"----------------------------------------------------------------\
-\"]; 
      Print[\"BFGS: Iteration = \", KK]; ]; LIKI = Append[LIKI, LIKALT]; 
       psii = Append[psii, THETA]; scoreii = Append[scoreii, S]; 
       STEP = LinearSolve[F, S]; STEPL = Max[Abs[STEP]]; 
       STEP = STEP*Min[1, MAXSTEP/STEPL]; THETA1 = THETA + STEP; 
       
       LIKNEU = Lik[data, THETA1, {system, LikN}, misc]; 
       LIKNEU = LikTest[LIKNEU]; 
       
       DoWhile[{half, 100}, LIKNEU < LIKALT + ALPHA*S . STEP && \
Max[Abs[STEP]] > MINSTEP, 
       
         STEP = STEP/STEPREDUCE; THETA1 = THETA + STEP; 
         LIKNEU = Lik[data, THETA1, {system, LikN}, misc]; 
         LIKNEU = LikTest[LIKNEU]; If[PRINT[[3]] == 1, 
          Print[\"STEP-REDUCTION:  \", half, \"  LIKNEU  \", 
            PaddedForm[LIKNEU, {20, 15}], \"  LIKALT  \", 
            PaddedForm[LIKALT, {20, 15}]]; ]; ]; 
         If[LIKNEU - LIKALT < 0, Print[\"ReturnCode = 4\"]; 
         ReturnCode = 4; Break[]
         
         ]; 
         
         If[PRINT[[4]] == 1, 
            Print[\"LIKNEU  \", PaddedForm[LIKNEU, {20, 15}]]; 
            Print[\"LIKALT  \", PaddedForm[LIKALT, {20, 15}]]; 
            Print[\"LIKNEU - LIKALT  \", PaddedForm[LIKNEU - LIKALT, {20, \
15}]]; Print[\"\"]; ]; 
           
         If[PRINT[[5]] == 1, 
            Print[PaddedForm[TableForm[(Chop[#1, 1/10^5] & )[
            Transpose[{THETA1, THETA, STEP, S}]], TableHeadings -> 
            {Automatic, {\"THETA1\", \"THETA\", \"STEP\", \"SCORE\"}}, 
            TableDirections -> {Column, Row}, TableSpacing -> 
            {1, 2}], {5, 4}]]]; 
            
         If[PRINT[[6]] == 1, Print[\"F\"]; Print[MatrixForm[F]]; ]; 
        
        {SNEU, LIKALT} = 
        Score[data, THETA1, {system, {Lik, LikN}}, misc]; 
        F = BFGSUP[F, SNEU, S, STEP]; S = SNEU; 
        THETA = THETA1GLOBAL = THETA1; k = KK; 
        relgrad = Max[Abs[S*max[Abs[THETA], TYP]]]/Abs[LIKNEU]; 
        Print[\"relgrad = \", relgrad, \" = Elastizitaet(d l/l)/(d \
theta/theta)\"]; 
        
        If[Max[Abs[S]] < EPS1, Print[\"ReturnCode = 1\"]; ReturnCode = 1]; 
        If[Max[Abs[STEP]] < EPS2, Print[\"ReturnCode = 2\"]; ReturnCode = 2]; \

        
        If[Max[Abs[S]] < EPS1 && Max[Abs[STEP]] < EPS2, Print[\"ReturnCode = \
3\"]; ReturnCode = 3]
        
        ]; 
        
      If[PRINT[[7]] == 1, Print[\"BFGS:  ENDE DER ITERATION  \", k, \"  \", \
KMAX]]; 
       
      If[PRINT[[5]] == 1, 
      Print[TableForm[Transpose[{SNEU}], TableHeadings -> 
         {Automatic, {\"SCORE\"}}, TableDirections -> {Column, Row}, 
         TableSpacing -> {1, 2}]]]; 
        
      If[PRINT[[6]] == 1, 
         Print[\"F\"]; Print[MatrixForm[F]]; ]; 
         LIKI = Append[LIKI, LIKALT]; psii = Append[psii, THETA]; 
         scoreii = Append[scoreii, S]; likpsi = ii[Spalte[LIKI], psii]; 
         
     If[PRINT[[8]] == 1, Print[TableForm[likpsi, 
        TableHeadings -> {Automatic, {\"Likelihood\", \"THETA\"}}, 
        TableDirections -> {Column, Row}, TableSpacing -> {1, 2}]]];
         
     If[FISHER && k < KMAX, 
          {F, LIKELI} = Hesse[data, THETA, {system, {Lik, LikN, Score}}, misc];
          F = -F; 
          COV = OUTPUT[THETA, F, 0.05, S, LIKELI]; 
          LKOMP[LIKELI, u, Indeterminate], 
          (*else*)
          COV = Inverse[F]; 
          ]; 
          
     {THETA, COV, LIKI, psii, scoreii, k, ReturnCode}]; \
\>", "Input",
 PageWidth->Infinity,
 CellMargins->{{20.375, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 TextAlignment->Left,
 TextJustification->0,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 CellTags->"BFGS",
 CellLabel->"In[139]:="],

Cell["\<\
LKOMP//Clear
LKOMP[LIK_, U_, Nue_] := Module[{EPS, LN, KOMP1, KOMP2, KOMP3}, 
     EPS = 1/10^3; LN = Log[N[Nue]]; KOMP1 = U; KOMP2 = 0.5*U*LN; 
     KOMP3 = 0.5*U*(U + 1)*(1 + EPS)*Log[LN]; 
     Print[\"--------------------------------------------------------\"]; 
     Print[\"KOMPENSIERTE LIKELIHOOD\"]; 
     Print[\"--------------------------------------------------------\"]; 
     Print[\"U =  \", U, \"  Nue = \", Nue]; 
     Print[\"AKAIKE (AIC) SCHWARZ/RISSANEN (SIC/RISS) \
AZENCOTT/DACUNHA-CASTELLE (A/D)\"]; 
     ket = {{0, KOMP1, KOMP2, KOMP3}, {LIK, LIK - KOMP1, LIK - KOMP2, LIK - \
KOMP3}}; 
     Print[TableForm[ket, TableHeadings -> {{\"Kompensator\", \"komp. Lik.\"}, 
         {\"LIK\", \"AIC\", \"SIC/RISS\", \"A/D\"}}, TableDirections -> \
{Column, Row}, 
       TableSpacing -> {1, 2}]]; ]; \
\>", "Input",
 PageWidth->Infinity,
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 CellLabel->"In[87]:="],

Cell[CellGroupData[{

Cell["LKOMP[100.99, 5, 10]", "Input",
 PageWidth->Infinity,
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 CellLabel->"In[127]:="],

Cell[BoxData["\<\"--------------------------------------------------------\"\>\
"], "Print",
 CellLabel->"During evaluation of In[127]:="],

Cell[BoxData["\<\"KOMPENSIERTE LIKELIHOOD\"\>"], "Print",
 CellLabel->"During evaluation of In[127]:="],

Cell[BoxData["\<\"--------------------------------------------------------\"\>\
"], "Print",
 CellLabel->"During evaluation of In[127]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"U =  \"\>", "\[InvisibleSpace]", "5", 
   "\[InvisibleSpace]", "\<\"  Nue = \"\>", "\[InvisibleSpace]", "10"}],
  SequenceForm["U =  ", 5, "  Nue = ", 10],
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[127]:="],

Cell[BoxData["\<\"AKAIKE (AIC) SCHWARZ/RISSANEN (SIC/RISS) \
AZENCOTT/DACUNHA-CASTELLE (A/D)\"\>"], "Print",
 CellLabel->"During evaluation of In[127]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      StyleBox["\[Null]",
       ShowStringCharacters->False], 
      TagBox["\<\"LIK\"\>",
       HoldForm], 
      TagBox["\<\"AIC\"\>",
       HoldForm], 
      TagBox["\<\"SIC/RISS\"\>",
       HoldForm], 
      TagBox["\<\"A/D\"\>",
       HoldForm]},
     {
      TagBox["\<\"Kompensator\"\>",
       HoldForm], "0", "5", "5.756462732485115`", "12.522997165398056`"},
     {
      TagBox["\<\"komp. Lik.\"\>",
       HoldForm], "100.99`", "95.99`", "95.23353726751488`", 
      "88.46700283460194`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[1.4]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {{"Kompensator", "komp. Lik."}, {
      "LIK", "AIC", "SIC/RISS", "A/D"}}, TableDirections -> {Column, Row}, 
    TableSpacing -> {1, 2}]]]], "Print",
 CellLabel->"During evaluation of In[127]:="]
}, Open  ]],

Cell["\<\
OUTPUT[THETA_, F_, ALPHA_, SCORE_, LIKELI_] := 
   Module[{COV, EIGF, EIGCOV}, 
    Print[
      \"--------------------------------------------------------\"]; 
     Print[\"ML-Sch\[ADoubleDot]tzer, SCORE UND LIKELIHOOD\"]; 
     Print[\"--------------------------------------------------------\\
\"]; Print[(MatrixForm[#1, TableHeadings -> {Automatic, 
           {\"THETA\", \"SCORE\"}}] & )[Transpose[{THETA, SCORE}]], 
      \"   Likelihood = \", N[LIKELI, 25]]; 
     COV = SIGNI[THETA, F, ALPHA]; EIGF = Eigenvalues[F]; 
     EIGCOV = 1/EIGF; 
     Print[\"--------------------------------------------------------\\
\"]; Print[\"GESCH\[CapitalADoubleDot]TZTE KOVARIANZMATRIX UND EIGENWERTE\"]; \

     Print[\"--------------------------------------------------------\\
\"]; Print[MatrixForm[Chop[N[COV, 5]]]]; Print[\"\"]; 
     Print[N[EIGCOV, 5]]; 
     Print[\"--------------------------------------------------------\\
\"]; Print[\"GESCH\[CapitalADoubleDot]TZTE FISHER-INFORMATIONS-MATRIX UND \
EIGENWERTE\"]; 
     Print[
      \"--------------------------------------------------------\"]; 
     Print[MatrixForm[Chop[N[F, 5]]]]; Print[\"\"]; Print[N[EIGF, 5]]; 
     COV]; \
\>", "Input",
 PageWidth->Infinity,
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 CellLabel->"In[228]:="],

Cell["\<\
SIGNI[THETA_, F_, ALPHA_] := Module[{U, CHI, PROB, Z, COV, AU2, DCOV, STD, \
STD1, 
     CORR, GRENZE}, U = Length[THETA]; CHI = N[THETA . F . THETA]; 
     If[CHI >= 0, PROB = 1 - CDF[ChiSquareDistribution[U], CHI]; 
       Print[\"------------------------------------------------------\"]; 
       Print[\"WALD-TEST:\"]; 
       Print[\"------------------------------------------------------\"]; 
       VecPrint[Spalte[{CHI, U, Chop[PROB], ALPHA}], {\"CHI \", \"U \", \
\"PROB \", 
         \"ALPHA \"}]; If[PROB < ALPHA, 
        Print[\"NULLHYPOTHESE THETA = 0 ABLEHNEN\"]]; , 
      Print[\"F NICHT POSITIV DEFINIT\"]; ]; COV = PseudoInverse[F]; 
     AU2 = ALPHA/(2*U); Z = Quantile[NormalDistribution[0, 1], 1 - AU2]; 
     DCOV = Transpose[COV, {1, 1}]; If[all[gr[DCOV, 0]], 
      STD = Sqrt[DCOV]; STD1 = 1/STD; CORR = DiagonalMatrix[STD1] . COV . 
         DiagonalMatrix[STD1]; GRENZE = Z*STD; 
       Print[\"------------------------------------------------------\"]; 
       Print[\"BONFERRONI-KONFIDENZINTERVALLE:\"]; 
       Print[\"------------------------------------------------------\"]; 
       Print[\"P{THETA AUS [THDACH-GRENZE,THDACH+GRENZE] } >= 1-ALPHA\"]; 
       Print[\"QUANTIL Z(1-ALPHA/2U) = \", N[Z]]; 
       VecPrint[N[{THETA, GRENZE, STD}], {\"THETA\", \"GRENZE\", \"STD\"}]; 
       Print[\"-------------------------------------------------------\"]; 
       Print[\"Korrelation der ML-Sch\[ADoubleDot]tzer\"]; 
       Print[\"-------------------------------------------------------\"]; 
       Print[MatrixForm[Chop[N[CORR, 2]]]]; , 
      Print[\"Warnung: Negative Diagonalelemente der Kovarianzmatrix\"]; ]; 
     Return[COV]; ]; \
\>", "Input",
 PageWidth->WindowWidth,
 CellMargins->{{19.625, Inherited}, {Inherited, Inherited}},
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Plain",
 CellLabel->"In[92]:="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Applications", "Section",
 CellChangeTimes->{{3.46008408020374*^9, 3.4600840838788967`*^9}}],

Cell[CellGroupData[{

Cell["Matrizen /SDE/Coupled Oscillators", "Subsection",
 PageWidth->Infinity,
 CellMargins->{{34, 50}, {10, 26}},
 CellChangeTimes->{{3.4600842566241693`*^9, 3.4600842570250177`*^9}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
SDE:
dy  = A y dt + B x dt + G dw
z_t = H y_t + D x_t + eps_t\
\>", "Text",
 CellMargins->{{34, 50}, {10, 26}},
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]],

Cell["\<\
EDM:
y_{t+1} = astern y_t + bstern x_t + u_t
z_t = H y_t + D x_t +  eps_t
E[y_0] = mue; Var[y_0] = Sigma; \
\>", "Text",
 PageWidth->Infinity,
 CellMargins->{{34, 50}, {10, 26}},
 ImageRegion->{{0, 1}, {0, 1}},
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 0]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Unprotect", "[", "A", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", "A", "]"}], "\n", 
 RowBox[{
  RowBox[{"A", "[", 
   RowBox[{"t_", ",", 
    RowBox[{"{", 
     RowBox[{
     "\[Omega]10_", ",", "\[Omega]11_", ",", "gamma10_", ",", "gamma11_", ",",
       "b10_", ",", "b11_", ",", "eps10_", ",", "eps11_", ",", "g10_", ",", 
      "g11_", ",", "mu11_", ",", "mu12_", ",", "Sigma111_", ",", "Sigma112_", 
      ",", "Sigma122_", ",", "\[IndentingNewLine]", "\[Omega]20_", ",", 
      "\[Omega]21_", ",", "gamma20_", ",", "gamma21_", ",", "b20_", ",", 
      "b21_", ",", "eps20_", ",", "eps21_", ",", "g20_", ",", "g21_", ",", 
      "mu21_", ",", "mu22_", ",", "Sigma211_", ",", "Sigma212_", ",", 
      "Sigma222_"}], "}"}]}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"\[Omega]10", "+", 
           RowBox[{"\[Omega]11", " ", "*", "t"}]}], ")"}]}], "+", 
        RowBox[{"(", 
         RowBox[{"eps10", "+", 
          RowBox[{"eps11", " ", "t"}]}], ")"}]}], ")"}], ",", 
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"gamma10", "+", 
         RowBox[{"gamma11", " ", "*", "t"}]}], ")"}]}], ",", 
      RowBox[{"(", 
       RowBox[{"eps20", "+", 
        RowBox[{"eps21", " ", "t"}]}], ")"}], ",", "0"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"eps10", "+", 
         RowBox[{"eps11", " ", "t"}]}], ")"}]}], ",", "0", ",", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"\[Omega]20", "+", 
           RowBox[{"\[Omega]21", " ", "*", "t"}]}], ")"}]}], "-", 
        RowBox[{"(", 
         RowBox[{"eps20", "+", 
          RowBox[{"eps21", " ", "t"}]}], ")"}]}], ")"}], ",", 
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"gamma20", "+", 
         RowBox[{"gamma21", " ", "*", "t"}]}], ")"}]}]}], "}"}]}], 
   "}"}]}]}], "Input",
 PageWidth->Infinity,
 CellMargins->{{34, 50}, {10, 26}},
 CellChangeTimes->{{3.45984459725543*^9, 3.4598446021322613`*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[252]:="],

Cell[BoxData[
 RowBox[{"{", "\<\"A\"\>", "}"}]], "Output",
 CellMargins->{{34, 50}, {10, 26}},
 CellChangeTimes->{3.45984461644902*^9},
 CellLabel->"Out[252]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", 
   RowBox[{"t_", ",", 
    RowBox[{"{", 
     RowBox[{
     "\[Omega]10_", ",", "\[Omega]11_", ",", "gamma10_", ",", "gamma11_", ",",
       "b10_", ",", "b11_", ",", "eps10_", ",", "eps11_", ",", "g10_", ",", 
      "g11_", ",", "mu11_", ",", "mu12_", ",", "Sigma111_", ",", "Sigma112_", 
      ",", "Sigma122_", ",", "\[IndentingNewLine]", "\[Omega]20_", ",", 
      "\[Omega]21_", ",", "gamma20_", ",", "gamma21_", ",", "b20_", ",", 
      "b21_", ",", "eps20_", ",", "eps21_", ",", "g20_", ",", "g21_", ",", 
      "mu21_", ",", "mu22_", ",", "Sigma211_", ",", "Sigma212_", ",", 
      "Sigma222_"}], "}"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 PageWidth->Infinity,
 CellMargins->{{34, 50}, {10, 26}},
 CellChangeTimes->{{3.459844619008317*^9, 3.459844624321163*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[255]:="],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], "1", "2", "3", "4"},
      {"1", "0", "1", "0", "0"},
      {"2", 
       RowBox[{"eps10_", "+", 
        RowBox[{"eps11_", " ", "t_"}], "-", "\[Omega]10_", "-", 
        RowBox[{"t_", " ", "\[Omega]11_"}]}], 
       RowBox[{
        RowBox[{"-", "gamma10_"}], "-", 
        RowBox[{"gamma11_", " ", "t_"}]}], 
       RowBox[{"eps20_", "+", 
        RowBox[{"eps21_", " ", "t_"}]}], "0"},
      {"3", "0", "0", "0", "1"},
      {"4", 
       RowBox[{
        RowBox[{"-", "eps10_"}], "-", 
        RowBox[{"eps11_", " ", "t_"}]}], "0", 
       RowBox[{
        RowBox[{"-", "eps20_"}], "-", 
        RowBox[{"eps21_", " ", "t_"}], "-", "\[Omega]20_", "-", 
        RowBox[{"t_", " ", "\[Omega]21_"}]}], 
       RowBox[{
        RowBox[{"-", "gamma20_"}], "-", 
        RowBox[{"gamma21_", " ", "t_"}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.24]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}], 
   "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellMargins->{{34, 50}, {10, 26}},
 CellChangeTimes->{3.459844625115395*^9},
 CellLabel->"Out[255]//MatrixForm="]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"Clear", "[", "B", "]"}], "\n", 
 RowBox[{
  RowBox[{"B", "[", 
   RowBox[{"t_", ",", 
    RowBox[{"{", 
     RowBox[{
     "\[Omega]10_", ",", "\[Omega]11_", ",", "gamma10_", ",", "gamma11_", ",",
       "b10_", ",", "b11_", ",", "eps10_", ",", "eps11_", ",", "g10_", ",", 
      "g11_", ",", "mu11_", ",", "mu12_", ",", "Sigma111_", ",", "Sigma112_", 
      ",", "Sigma122_", ",", "\[IndentingNewLine]", "\[Omega]20_", ",", 
      "\[Omega]21_", ",", "gamma20_", ",", "gamma21_", ",", "b20_", ",", 
      "b21_", ",", "eps20_", ",", "eps21_", ",", "g20_", ",", "g21_", ",", 
      "mu21_", ",", "mu22_", ",", "Sigma211_", ",", "Sigma212_", ",", 
      "Sigma222_"}], "}"}]}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", "0", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"b10", "+", 
      RowBox[{"b11", " ", "t"}]}], "}"}], ",", 
    RowBox[{"{", "0", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"b20", "+", 
      RowBox[{"b21", " ", "t"}]}], "}"}]}], "}"}]}]}], "Input",
 PageWidth->Infinity,
 CellMargins->{{34, 50}, {10, 26}},
 CellChangeTimes->{{3.4598446298267603`*^9, 3.4598446347366447`*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[257]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"B", "[", 
   RowBox[{"t_", ",", 
    RowBox[{"{", 
     RowBox[{
     "\[Omega]10_", ",", "\[Omega]11_", ",", "gamma10_", ",", "gamma11_", ",",
       "b10_", ",", "b11_", ",", "eps10_", ",", "eps11_", ",", "g10_", ",", 
      "g11_", ",", "mu11_", ",", "mu12_", ",", "Sigma111_", ",", "Sigma112_", 
      ",", "Sigma122_", ",", "\[IndentingNewLine]", "\[Omega]20_", ",", 
      "\[Omega]21_", ",", "gamma20_", ",", "gamma21_", ",", "b20_", ",", 
      "b21_", ",", "eps20_", ",", "eps21_", ",", "g20_", ",", "g21_", ",", 
      "mu21_", ",", "mu22_", ",", "Sigma211_", ",", "Sigma212_", ",", 
      "Sigma222_"}], "}"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 PageWidth->Infinity,
 CellMargins->{{34, 50}, {10, 26}},
 CellChangeTimes->{{3.459844636406591*^9, 3.459844639903082*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[259]:="],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], "1"},
      {"1", "0"},
      {"2", 
       RowBox[{"b10_", "+", 
        RowBox[{"b11_", " ", "t_"}]}]},
      {"3", "0"},
      {"4", 
       RowBox[{"b20_", "+", 
        RowBox[{"b21_", " ", "t_"}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.24]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}], 
   "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellMargins->{{34, 50}, {10, 26}},
 CellChangeTimes->{{3.459844641098481*^9, 3.459844644351522*^9}},
 CellLabel->"Out[259]//MatrixForm="]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"Clear", "[", "Omega", "]"}], "\n", 
 RowBox[{
  RowBox[{"Omega", "[", 
   RowBox[{"t_", ",", 
    RowBox[{"{", 
     RowBox[{
     "\[Omega]10_", ",", "\[Omega]11_", ",", "gamma10_", ",", "gamma11_", ",",
       "b10_", ",", "b11_", ",", "eps10_", ",", "eps11_", ",", "g10_", ",", 
      "g11_", ",", "mu11_", ",", "mu12_", ",", "Sigma111_", ",", "Sigma112_", 
      ",", "Sigma122_", ",", "\[IndentingNewLine]", "\[Omega]20_", ",", 
      "\[Omega]21_", ",", "gamma20_", ",", "gamma21_", ",", "b20_", ",", 
      "b21_", ",", "eps20_", ",", "eps21_", ",", "g20_", ",", "g21_", ",", 
      "mu21_", ",", "mu22_", ",", "Sigma211_", ",", "Sigma212_", ",", 
      "Sigma222_"}], "}"}]}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"10", "^", 
       RowBox[{"-", "4"}]}], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"g10", "+", 
         RowBox[{"g11", " ", "t"}]}], ")"}], "^", "2"}], ",", "0", ",", "0"}],
      "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", 
      RowBox[{"10", "^", 
       RowBox[{"-", "4"}]}], ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"g20", "+", 
         RowBox[{"g21", " ", "t"}]}], ")"}], "^", "2"}]}], "}"}]}], 
   "}"}]}]}], "Input",
 PageWidth->Infinity,
 CellMargins->{{34, 50}, {10, 26}},
 CellChangeTimes->{{3.4598446490522118`*^9, 3.459844653001995*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[260]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Omega", "[", 
   RowBox[{"tau", ",", 
    RowBox[{"{", 
     RowBox[{
     "\[Omega]10_", ",", "\[Omega]11_", ",", "gamma10_", ",", "gamma11_", ",",
       "b10_", ",", "b11_", ",", "eps10_", ",", "eps11_", ",", "g10_", ",", 
      "g11_", ",", "mu11_", ",", "mu12_", ",", "Sigma111_", ",", "Sigma112_", 
      ",", "Sigma122_", ",", "\[IndentingNewLine]", "         ", 
      "\[Omega]20_", ",", "\[Omega]21_", ",", "gamma20_", ",", "gamma21_", 
      ",", "b20_", ",", "b21_", ",", "eps20_", ",", "eps21_", ",", "g20_", 
      ",", "g21_", ",", "mu21_", ",", "mu22_", ",", "Sigma211_", ",", 
      "Sigma212_", ",", "Sigma222_"}], "}"}]}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 PageWidth->Infinity,
 CellMargins->{{34, 50}, {10, 26}},
 CellChangeTimes->{{3.4598446568809843`*^9, 3.459844667278812*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[263]:="],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], "1", "2", "3", "4"},
      {"1", 
       FractionBox["1", "10000"], "0", "0", "0"},
      {"2", "0", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"g10_", "+", 
          RowBox[{"tau", " ", "g11_"}]}], ")"}], "2"], "0", "0"},
      {"3", "0", "0", 
       FractionBox["1", "10000"], "0"},
      {"4", "0", "0", "0", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"g20_", "+", 
          RowBox[{"tau", " ", "g21_"}]}], ")"}], "2"]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.24]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}], 
   "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellMargins->{{34, 50}, {10, 26}},
 CellChangeTimes->{{3.459844662795705*^9, 3.4598446685172043`*^9}},
 CellLabel->"Out[263]//MatrixForm="]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"Clear", "[", "Mue", "]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Mue", "[", 
    RowBox[{"t_", ",", 
     RowBox[{"{", 
      RowBox[{
      "\[Omega]10_", ",", "\[Omega]11_", ",", "gamma10_", ",", "gamma11_", 
       ",", "b10_", ",", "b11_", ",", "eps10_", ",", "eps11_", ",", "g10_", 
       ",", "g11_", ",", "mu11_", ",", "mu12_", ",", "Sigma111_", ",", 
       "Sigma112_", ",", "Sigma122_", ",", "\[IndentingNewLine]", "   ", 
       "\[Omega]20_", ",", "\[Omega]21_", ",", "gamma20_", ",", "gamma21_", 
       ",", "b20_", ",", "b21_", ",", "eps20_", ",", "eps21_", ",", "g20_", 
       ",", "g21_", ",", "mu21_", ",", "mu22_", ",", "Sigma211_", ",", 
       "Sigma212_", ",", "Sigma222_"}], "}"}]}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"mu11", ",", "mu12", ",", "mu21", ",", "mu22"}], "}"}]}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{"Clear", "[", "Sigma", "]"}], "\n", 
 RowBox[{
  RowBox[{"Sigma", "[", 
   RowBox[{"t_", ",", 
    RowBox[{"{", 
     RowBox[{
     "\[Omega]10_", ",", "\[Omega]11_", ",", "gamma10_", ",", "gamma11_", ",",
       "b10_", ",", "b11_", ",", "eps10_", ",", "eps11_", ",", "g10_", ",", 
      "g11_", ",", "mu11_", ",", "mu12_", ",", "Sigma111_", ",", "Sigma112_", 
      ",", "Sigma122_", ",", "\[IndentingNewLine]", "        ", "\[Omega]20_",
       ",", "\[Omega]21_", ",", "gamma20_", ",", "gamma21_", ",", "b20_", ",",
       "b21_", ",", "eps20_", ",", "eps21_", ",", "g20_", ",", "g21_", ",", 
      "mu21_", ",", "mu22_", ",", "Sigma211_", ",", "Sigma212_", ",", 
      "Sigma222_"}], "}"}]}], "]"}], ":=", "\[IndentingNewLine]", "  ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "root", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"root", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Sigma111", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
        "\[IndentingNewLine]", "           ", 
        RowBox[{"{", 
         RowBox[{"Sigma112", ",", "Sigma122", ",", "0", ",", "0"}], "}"}], 
        ",", "\[IndentingNewLine]", "           ", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "Sigma211", ",", "0"}], "}"}], ",", 
        "\[IndentingNewLine]", "           ", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "Sigma212", ",", "Sigma222"}], "}"}]}], 
       "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"root", ".", 
      RowBox[{"Transpose", "[", "root", "]"}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}]}], "Input",
 PageWidth->Infinity,
 CellMargins->{{34, 50}, {10, 26}},
 CellChangeTimes->{{3.459844675074719*^9, 3.459844687849305*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[284]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Mue", "[", 
  RowBox[{"t_", ",", 
   RowBox[{"{", 
    RowBox[{
    "\[Omega]10_", ",", "\[Omega]11_", ",", "gamma10_", ",", "gamma11_", ",", 
     "b10_", ",", "b11_", ",", "eps10_", ",", "eps11_", ",", "g10_", ",", 
     "g11_", ",", "mu11_", ",", "mu12_", ",", "Sigma111_", ",", "Sigma112_", 
     ",", "Sigma122_", ",", "\[IndentingNewLine]", "      ", "\[Omega]20_", 
     ",", "\[Omega]21_", ",", "gamma20_", ",", "gamma21_", ",", "b20_", ",", 
     "b21_", ",", "eps20_", ",", "eps21_", ",", "g20_", ",", "g21_", ",", 
     "mu21_", ",", "mu22_", ",", "Sigma211_", ",", "Sigma212_", ",", 
     "Sigma222_"}], "}"}]}], "]"}]], "Input",
 PageWidth->Infinity,
 CellMargins->{{34, 50}, {10, 26}},
 CellChangeTimes->{{3.4598446926020412`*^9, 3.459844697759499*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[292]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"mu11_", ",", "mu12_", ",", "mu21_", ",", "mu22_"}], 
  "}"}]], "Output",
 CellMargins->{{34, 50}, {10, 26}},
 CellChangeTimes->{{3.459844698687099*^9, 3.4598447197299128`*^9}, 
   3.459844786397634*^9},
 CellLabel->"Out[292]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Sigma", "[", 
   RowBox[{"t", ",", 
    RowBox[{"{", 
     RowBox[{
     "\[Omega]10_", ",", "\[Omega]11_", ",", "gamma10_", ",", "gamma11_", ",",
       "b10_", ",", "b11_", ",", "eps10_", ",", "eps11_", ",", "g10_", ",", 
      "g11_", ",", "mu11_", ",", "mu12_", ",", "Sigma111_", ",", "Sigma112_", 
      ",", "Sigma122_", ",", "\[IndentingNewLine]", "      ", "\[Omega]20_", 
      ",", "\[Omega]21_", ",", "gamma20_", ",", "gamma21_", ",", "b20_", ",", 
      "b21_", ",", "eps20_", ",", "eps21_", ",", "g20_", ",", "g21_", ",", 
      "mu21_", ",", "mu22_", ",", "Sigma211_", ",", "Sigma212_", ",", 
      "Sigma222_"}], "}"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 PageWidth->Infinity,
 CellMargins->{{34, 50}, {10, 26}},
 CellChangeTimes->{{3.4598447978633633`*^9, 3.459844850970435*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[294]:="],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], "1", "2", "3", "4"},
      {"1", 
       SuperscriptBox["Sigma111_", "2"], 
       RowBox[{"Sigma111_", " ", "Sigma112_"}], "0", "0"},
      {"2", 
       RowBox[{"Sigma111_", " ", "Sigma112_"}], 
       RowBox[{
        SuperscriptBox["Sigma112_", "2"], "+", 
        SuperscriptBox["Sigma122_", "2"]}], "0", "0"},
      {"3", "0", "0", 
       SuperscriptBox["Sigma211_", "2"], 
       RowBox[{"Sigma211_", " ", "Sigma212_"}]},
      {"4", "0", "0", 
       RowBox[{"Sigma211_", " ", "Sigma212_"}], 
       RowBox[{
        SuperscriptBox["Sigma212_", "2"], "+", 
        SuperscriptBox["Sigma222_", "2"]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.24]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}], 
   "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellMargins->{{34, 50}, {10, 26}},
 CellChangeTimes->{3.4598448026749573`*^9, 3.4598448519630136`*^9},
 CellLabel->"Out[294]//MatrixForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", "H", "]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"H", "[", 
    RowBox[{"t_", ",", 
     RowBox[{"{", 
      RowBox[{
      "\[Omega]10_", ",", "\[Omega]11_", ",", "gamma10_", ",", "gamma11_", 
       ",", "b10_", ",", "b11_", ",", "eps10_", ",", "eps11_", ",", "g10_", 
       ",", "g11_", ",", "mu11_", ",", "mu12_", ",", "Sigma111_", ",", 
       "Sigma112_", ",", "Sigma122_", ",", "\[IndentingNewLine]", 
       "\[Omega]20_", ",", "\[Omega]21_", ",", "gamma20_", ",", "gamma21_", 
       ",", "b20_", ",", "b21_", ",", "eps20_", ",", "eps21_", ",", "g20_", 
       ",", "g21_", ",", "mu21_", ",", "mu22_", ",", "Sigma211_", ",", 
       "Sigma212_", ",", "Sigma222_"}], "}"}]}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}]}], "}"}]}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{"H", "[", 
  RowBox[{"t_", ",", 
   RowBox[{"{", 
    RowBox[{
    "\[Omega]10_", ",", "\[Omega]11_", ",", "gamma10_", ",", "gamma11_", ",", 
     "b10_", ",", "b11_", ",", "eps10_", ",", "eps11_", ",", "g10_", ",", 
     "g11_", ",", "mu11_", ",", "mu12_", ",", "Sigma111_", ",", "Sigma112_", 
     ",", "Sigma122_", ",", "\[IndentingNewLine]", "\[Omega]20_", ",", 
     "\[Omega]21_", ",", "gamma20_", ",", "gamma21_", ",", "b20_", ",", 
     "b21_", ",", "eps20_", ",", "eps21_", ",", "g20_", ",", "g21_", ",", 
     "mu21_", ",", "mu22_", ",", "Sigma211_", ",", "Sigma212_", ",", 
     "Sigma222_"}], "}"}]}], "]"}]}], "Input",
 PageWidth->Infinity,
 CellMargins->{{34, 50}, {10, 26}},
 CellChangeTimes->{{3.459844862839942*^9, 3.4598448913287983`*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[301]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellMargins->{{34, 50}, {10, 26}},
 CellChangeTimes->{{3.459844868487949*^9, 3.4598448920452843`*^9}},
 CellLabel->"Out[303]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"DD", "[", 
   RowBox[{"t_", ",", 
    RowBox[{"{", 
     RowBox[{
     "\[Omega]10_", ",", "\[Omega]11_", ",", "gamma10_", ",", "gamma11_", ",",
       "b10_", ",", "b11_", ",", "eps10_", ",", "eps11_", ",", "g10_", ",", 
      "g11_", ",", "mu11_", ",", "mu12_", ",", "Sigma111_", ",", "Sigma112_", 
      ",", "Sigma122_", ",", "\[IndentingNewLine]", "  ", "\[Omega]20_", ",", 
      "\[Omega]21_", ",", "gamma20_", ",", "gamma21_", ",", "b20_", ",", 
      "b21_", ",", "eps20_", ",", "eps21_", ",", "g20_", ",", "g21_", ",", 
      "mu21_", ",", "mu22_", ",", "Sigma211_", ",", "Sigma212_", ",", 
      "Sigma222_"}], "}"}]}], "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", "0", "}"}], ",", 
    RowBox[{"{", "0", "}"}]}], "}"}]}]], "Input",
 CellMargins->{{34, 50}, {10, 26}},
 CellChangeTimes->{{3.4598449054190197`*^9, 3.459844909561409*^9}},
 CellLabel->"In[304]:="],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", "R", "]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"R", "[", 
    RowBox[{"t_", ",", 
     RowBox[{"{", 
      RowBox[{
      "\[Omega]10_", ",", "\[Omega]11_", ",", "gamma10_", ",", "gamma11_", 
       ",", "b10_", ",", "b11_", ",", "eps10_", ",", "eps11_", ",", "g10_", 
       ",", "g11_", ",", "mu11_", ",", "mu12_", ",", "Sigma111_", ",", 
       "Sigma112_", ",", "Sigma122_", ",", "\[IndentingNewLine]", 
       "\[Omega]20_", ",", "\[Omega]21_", ",", "gamma20_", ",", "gamma21_", 
       ",", "b20_", ",", "b21_", ",", "eps20_", ",", "eps21_", ",", "g20_", 
       ",", "g21_", ",", "mu21_", ",", "mu22_", ",", "Sigma211_", ",", 
       "Sigma212_", ",", "Sigma222_"}], "}"}]}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"10", "^", 
        RowBox[{"-", "2"}]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"10", "^", 
        RowBox[{"-", "2"}]}]}], "}"}]}], "}"}]}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{"R", "[", 
  RowBox[{"t_", ",", 
   RowBox[{"{", 
    RowBox[{
    "\[Omega]10_", ",", "\[Omega]11_", ",", "gamma10_", ",", "gamma11_", ",", 
     "b10_", ",", "b11_", ",", "eps10_", ",", "eps11_", ",", "g10_", ",", 
     "g11_", ",", "mu11_", ",", "mu12_", ",", "Sigma111_", ",", "Sigma112_", 
     ",", "Sigma122_", ",", "\[IndentingNewLine]", "\[Omega]20_", ",", 
     "\[Omega]21_", ",", "gamma20_", ",", "gamma21_", ",", "b20_", ",", 
     "b21_", ",", "eps20_", ",", "eps21_", ",", "g20_", ",", "g21_", ",", 
     "mu21_", ",", "mu22_", ",", "Sigma211_", ",", "Sigma212_", ",", 
     "Sigma222_"}], "}"}]}], "]"}]}], "Input",
 PageWidth->Infinity,
 CellMargins->{{34, 50}, {10, 26}},
 CellChangeTimes->{{3.459844914567726*^9, 3.4598449302159433`*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[308]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "100"], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox["1", "100"]}], "}"}]}], "}"}]], "Output",
 CellMargins->{{34, 50}, {10, 26}},
 CellChangeTimes->{{3.459844922365293*^9, 3.459844931949176*^9}},
 CellLabel->"Out[310]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["EDM", "Subsection",
 CellMargins->{{35, 50}, {10, 26}},
 CellChangeTimes->{{3.4600842743954268`*^9, 3.4600842753059483`*^9}}],

Cell[BoxData[{
 RowBox[{"Clear", "[", "STERN", "]"}], "\n", 
 RowBox[{
  RowBox[{"STERN", "[", 
   RowBox[{"Theta_", ",", "Deltat_", ",", "t_", ",", 
    RowBox[{"Nonlin_:", "1"}]}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "L", ",", "p", ",", "a", ",", "b", ",", "omega", ",", "Ip", ",", "Ip2", 
      ",", "astern", ",", "bstern", ",", "ostern"}], "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"a", "=", 
      RowBox[{"A", "[", 
       RowBox[{"t", ",", "Theta"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"b", "=", 
      RowBox[{"B", "[", 
       RowBox[{"t", ",", "Theta"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"omega", "=", 
      RowBox[{"Omega", "[", 
       RowBox[{"t", ",", "Theta"}], "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"p", "=", 
      RowBox[{"Length", "[", "a", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Ip", "=", 
      RowBox[{"IdentityMatrix", "[", "p", "]"}]}], ";", "\[IndentingNewLine]",
      "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"Nonlin", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Ip2", "=", 
         RowBox[{"IdentityMatrix", "[", 
          SuperscriptBox["p", "2"], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"astern", "=", 
         RowBox[{"MatrixExp", "[", 
          RowBox[{"a", " ", "Deltat"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"bstern", "=", 
         RowBox[{
          RowBox[{"Inverse", "[", "a", "]"}], ".", 
          RowBox[{"(", 
           RowBox[{"astern", "-", "Ip"}], ")"}], ".", "b"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"L", "=", 
         RowBox[{
          RowBox[{"KroneckerProduct", "[", 
           RowBox[{"a", ",", "Ip"}], "]"}], "+", 
          RowBox[{"KroneckerProduct", "[", 
           RowBox[{"Ip", ",", "a"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"ostern", "=", 
         RowBox[{
          RowBox[{"Inverse", "[", "L", "]"}], ".", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"KroneckerProduct", "[", 
             RowBox[{"astern", ",", "astern"}], "]"}], "-", "Ip2"}], ")"}], 
          ".", 
          RowBox[{"Flatten", "[", "omega", "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"ostern", "=", 
         RowBox[{"Shape", "[", 
          RowBox[{"ostern", ",", 
           RowBox[{"{", 
            RowBox[{"p", ",", "p"}], "}"}]}], "]"}]}]}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", "else", "*)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"astern", "=", 
         RowBox[{"Ip", " ", "+", " ", 
          RowBox[{"a", " ", "Deltat"}]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"bstern", " ", "=", " ", 
         RowBox[{"b", " ", "Deltat"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"ostern", " ", "=", " ", 
         RowBox[{"omega", " ", "Deltat"}]}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"astern", ",", "bstern", ",", "ostern"}], "}"}]}]}], 
   "]"}]}]}], "Input",
 PageWidth->Infinity,
 CellMargins->{{35, 50}, {10, 26}},
 CellChangeTimes->{{3.459844947011632*^9, 3.4598449826932487`*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[311]:="],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "SystemEDMdetOver", "]"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{"SystemEDMdetOver", "[", 
   RowBox[{"Theta_", ",", 
    RowBox[{"{", 
     RowBox[{"dt_", ",", "t_", ",", 
      RowBox[{"Nonlin_:", "1"}], ",", 
      RowBox[{"missings_:", "0"}]}], "}"}]}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "T1", ",", "t0", ",", "t1", ",", "j1", ",", "J1", ",", "time", ",", 
      "astern", ",", "bstern", ",", "ostern", ",", "p", ",", "q", ",", "beta",
       ",", "gamma", ",", "mu", ",", "sigma", ",", "\[IndentingNewLine]", 
      "             ", "sigmazeta", ",", "lambdaeta", ",", "taueta", ",", 
      "sigmaepsilon", ",", "rep", ",", "K", ",", "P", ",", "Q", ",", "h", ",",
       "d", ",", "r"}], "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"T1", "=", 
      RowBox[{"t", "//", "Length"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"t0", "=", 
      RowBox[{"t", "//", "First"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"t1", "=", 
      RowBox[{"t", "//", "Last"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"j1", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"t", "-", "t0"}], ")"}], "/", "dt"}]}], ")"}], "//", 
       "Rationalize"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"J1", "=", 
      RowBox[{"Last", "[", "j1", "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"time", "=", 
      RowBox[{"Range", "[", 
       RowBox[{"t0", ",", "t1", ",", "dt"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"astern", ",", "bstern", ",", "ostern"}], "}"}], "=", 
      RowBox[{
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"STERN", "[", 
           RowBox[{"Theta", ",", "dt", ",", "#", ",", "Nonlin"}], "]"}], 
          "&"}], ",", 
         RowBox[{"Drop", "[", 
          RowBox[{"time", ",", 
           RowBox[{"-", "1"}]}], "]"}]}], "]"}], "//", "Transpose"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p", ",", "q"}], "}"}], "=", 
      RowBox[{"Dimensions", "[", 
       RowBox[{"bstern", "//", "First"}], "]"}]}], ";", "\[IndentingNewLine]",
      "\[IndentingNewLine]", 
     RowBox[{"beta", "=", 
      RowBox[{"SubDiagonalMatrix", "[", 
       RowBox[{"astern", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"J1", "-", "1"}], ",", "p"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"mu", "=", 
      RowBox[{
       RowBox[{"Mue", "[", 
        RowBox[{"time", ",", "Theta"}], "]"}], "//", "Spalte"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"gamma", "=", 
      RowBox[{"BlockDiagonalMatrix", "[", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "mu", "}"}], ",", "bstern"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"gamma", "=", 
      RowBox[{"gamma", "~", "ii", "~", 
       RowBox[{"Shape", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"J1", "  ", "p"}], ",", "q"}], "}"}]}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"sigma", "=", 
      RowBox[{"Sigma", "[", 
       RowBox[{"time", ",", "Theta"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"sigmazeta", "=", 
      RowBox[{"BlockDiagonalMatrix", "[", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "sigma", "}"}], ",", "ostern"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"h", "=", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"H", "[", 
          RowBox[{"#", ",", "Theta"}], "]"}], "&"}], ",", "time"}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"lambdaeta", "=", 
      RowBox[{"Shape", "[", 
       RowBox[{"rep", ",", 
        RowBox[{"{", 
         RowBox[{"T1", ",", "J1"}], " ", "}"}]}], "]"}]}], ";", "\n", "     ", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"lambdaeta", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", 
           RowBox[{"j1", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], " ", "]"}], "]"}], "=", 
        RowBox[{"h", "[", 
         RowBox[{"[", 
          RowBox[{"j1", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "T1"}], "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     " ", 
     RowBox[{"lambdaeta", "=", 
      RowBox[{
       RowBox[{"lambdaeta", "/.", 
        RowBox[{"rep", "\[Rule]", 
         RowBox[{"(", 
          RowBox[{"0", " ", 
           RowBox[{"h", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}]}], "//", 
       "ArrayFlatten"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     
     RowBox[{
      RowBox[{"{", 
       RowBox[{"K", ",", "Q"}], "}"}], "=", 
      RowBox[{"Dimensions", "[", "lambdaeta", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"P", ",", "Q"}], "}"}], "=", 
      RowBox[{"Dimensions", "[", "gamma", "]"}]}], ";", "\[IndentingNewLine]",
      "\[IndentingNewLine]", 
     RowBox[{"d", "=", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"DD", "[", 
          RowBox[{"#", ",", "Theta"}], "]"}], "&"}], ",", "time"}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"taueta", "=", 
      RowBox[{"Shape", "[", 
       RowBox[{"rep", ",", 
        RowBox[{"{", 
         RowBox[{"T1", ",", "J1"}], "}"}]}], "]"}]}], ";", "\n", "     ", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"taueta", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", 
           RowBox[{"j1", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], " ", "]"}], "]"}], "=", 
        RowBox[{"d", "[", 
         RowBox[{"[", 
          RowBox[{"j1", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "T1"}], "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"taueta", "=", 
      RowBox[{
       RowBox[{"taueta", "/.", 
        RowBox[{"rep", "\[Rule]", 
         RowBox[{"(", 
          RowBox[{"0", " ", 
           RowBox[{"d", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}]}], "//", 
       "ArrayFlatten"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"taueta", "=", 
      RowBox[{
       RowBox[{"Shape", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"K", ",", "1"}], "}"}]}], "]"}], "~", "ii", "~", 
       "taueta"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"r", "=", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"R", "[", 
          RowBox[{"#", ",", "Theta"}], "]"}], "&"}], ",", 
        RowBox[{"time", "[", 
         RowBox[{"[", "j1", "]"}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"sigmaepsilon", "=", 
      RowBox[{"BlockDiagonalMatrix", "[", "r", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"sigmaepsilon", "=", 
      RowBox[{"sigmaepsilon", "//", "ArrayFlatten"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"missings", "===", "0"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"beta", ",", "gamma", ",", "sigmazeta"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"lambdaeta", ",", "taueta", ",", "sigmaepsilon"}], "}"}]}], 
        "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"nonmiss", "=", 
         RowBox[{"Complement", "[", 
          RowBox[{
           RowBox[{"K", "//", "Range"}], ",", "missings"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"beta", ",", "gamma", ",", "sigmazeta"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"lambdaeta", "[", 
             RowBox[{"[", "nonmiss", "]"}], "]"}], ",", 
            RowBox[{"taueta", "[", 
             RowBox[{"[", "nonmiss", "]"}], "]"}], ",", 
            RowBox[{"sigmaepsilon", "[", 
             RowBox[{"[", 
              RowBox[{"nonmiss", ",", "nonmiss"}], "]"}], "]"}]}], "}"}]}], 
         "}"}]}]}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}]}], "Input",
 PageWidth->Infinity,
 CellMargins->{{35, 50}, {10, 26}},
 CellChangeTimes->{{3.459845387122418*^9, 3.459845438734496*^9}, {
  3.459845504120901*^9, 3.459845554480986*^9}, {3.459845634220306*^9, 
  3.459845761855526*^9}, {3.4598458403832006`*^9, 3.459845844643331*^9}},
 TextJustification->1.,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[408]:="]
}, Closed]]
}, Closed]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowToolbars->"RulerBar",
WindowSize->{1201, 940},
WindowMargins->{{-158, Automatic}, {989, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowSelection->True,
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1,
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"ArticleModern.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3455273716-9021704"->{
  Cell[42014, 1157, 1009, 18, 69, "Print",
   CellTags->"Info3455273716-9021704"],
  Cell[43026, 1177, 416, 13, 35, "Print",
   CellTags->"Info3455273716-9021704"]},
 "Info3460286741-5603323"->{
  Cell[86341, 2303, 164, 3, 71, "Print",
   CellTags->"Info3460286741-5603323"],
  Cell[86508, 2308, 971, 27, 68, "Print",
   CellTags->"Info3460286741-5603323"]},
 "plot1"->{
  Cell[140769, 3695, 1390, 41, 172, "Input",
   InitializationCell->True,
   CellTags->"plot1"],
  Cell[142162, 3738, 5711, 85, 2118, "Input",
   InitializationCell->True,
   CellTags->"plot1"]},
 "Info3460133123-4927937"->{
  Cell[151034, 3925, 2364, 38, 78, "Print",
   CellTags->"Info3460133123-4927937"]},
 "Info3460133161-7256246"->{
  Cell[154372, 3999, 844, 16, 54, "Print",
   CellTags->"Info3460133161-7256246"],
  Cell[155219, 4017, 1190, 33, 68, "Print",
   CellTags->"Info3460133161-7256246"]},
 "BFGS"->{
  Cell[171282, 4431, 5874, 147, 1637, "Input",
   InitializationCell->True,
   CellTags->"BFGS"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3455273716-9021704", 222923, 5806},
 {"Info3460286741-5603323", 223118, 5811},
 {"plot1", 223294, 5816},
 {"Info3460133123-4927937", 223519, 5823},
 {"Info3460133161-7256246", 223633, 5826},
 {"BFGS", 223812, 5831}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 171, 4, 69, "Title",
 InitializationCell->True],
Cell[741, 28, 473, 13, 202, "Subtitle",
 InitializationCell->True],
Cell[1217, 43, 366, 9, 111, "Subsubtitle",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1608, 56, 145, 2, 58, "Section"],
Cell[1756, 60, 508, 12, 156, "Input",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[2301, 77, 148, 2, 58, "Section"],
Cell[2452, 81, 471, 12, 143, "Input",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[2960, 98, 129, 5, 77, "Section"],
Cell[3092, 105, 1966, 55, 380, "Input",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[5095, 165, 188, 4, 58, "Section",
 InitializationCell->True],
Cell[5286, 171, 674, 18, 97, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[5997, 194, 163, 3, 58, "Section",
 InitializationCell->True],
Cell[6163, 199, 394, 11, 67, "Input",
 InitializationCell->True],
Cell[6560, 212, 380, 10, 67, "Input",
 InitializationCell->True],
Cell[6943, 224, 388, 10, 67, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[7368, 239, 182, 3, 58, "Section",
 InitializationCell->True],
Cell[7553, 244, 4866, 128, 412, "Input",
 InitializationCell->True],
Cell[12422, 374, 6552, 163, 607, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[19011, 542, 250, 5, 32, "Section",
 InitializationCell->True],
Cell[19264, 549, 5989, 159, 472, "Input",
 InitializationCell->True],
Cell[25256, 710, 6051, 158, 548, "Input",
 InitializationCell->True],
Cell[31310, 870, 4571, 117, 442, "Input",
 InitializationCell->True],
Cell[35884, 989, 6031, 160, 532, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[41940, 1153, 71, 2, 39, "Input"],
Cell[42014, 1157, 1009, 18, 69, "Print",
 CellTags->"Info3455273716-9021704"],
Cell[43026, 1177, 416, 13, 35, "Print",
 CellTags->"Info3455273716-9021704"]
}, Open  ]],
Cell[43457, 1193, 6514, 165, 697, "Input",
 InitializationCell->True],
Cell[49974, 1360, 19233, 509, 1492, "Input",
 InitializationCell->True],
Cell[69210, 1871, 10700, 248, 1188, "Input",
 InitializationCell->True],
Cell[79913, 2121, 6038, 165, 352, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[85988, 2291, 146, 2, 58, "Section"],
Cell[CellGroupData[{
Cell[86159, 2297, 179, 4, 69, "Input"],
Cell[86341, 2303, 164, 3, 71, "Print",
 CellTags->"Info3460286741-5603323"],
Cell[86508, 2308, 971, 27, 68, "Print",
 CellTags->"Info3460286741-5603323"]
}, Open  ]],
Cell[87494, 2338, 5026, 129, 340, "Input",
 InitializationCell->True],
Cell[92523, 2469, 22826, 439, 1240, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[115386, 2913, 206, 5, 58, "Section",
 InitializationCell->True],
Cell[115595, 2920, 389, 12, 51, "Input",
 InitializationCell->True],
Cell[115987, 2934, 2211, 61, 172, "Input"],
Cell[118201, 2997, 2892, 88, 202, "Input",
 InitializationCell->True],
Cell[121096, 3087, 382, 11, 51, "Input",
 InitializationCell->True],
Cell[121481, 3100, 1139, 32, 51, "Input",
 InitializationCell->True],
Cell[122623, 3134, 803, 23, 51, "Input",
 InitializationCell->True],
Cell[123429, 3159, 1366, 38, 157, "Input"],
Cell[124798, 3199, 2061, 58, 187, "Input",
 InitializationCell->True],
Cell[126862, 3259, 676, 22, 67, "Input",
 InitializationCell->True],
Cell[127541, 3283, 703, 23, 67, "Input",
 InitializationCell->True],
Cell[128247, 3308, 763, 21, 51, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[129035, 3333, 225, 7, 39, "Input"],
Cell[129263, 3342, 3257, 95, 103, "Print"]
}, Open  ]],
Cell[132535, 3440, 1136, 32, 67, "Input",
 InitializationCell->True],
Cell[133674, 3474, 2143, 62, 82, "Input",
 InitializationCell->True],
Cell[135820, 3538, 442, 14, 51, "Input",
 InitializationCell->True],
Cell[136265, 3554, 2006, 60, 127, "Input",
 InitializationCell->True],
Cell[138274, 3616, 941, 30, 112, "Input",
 InitializationCell->True],
Cell[139218, 3648, 1548, 45, 136, "Input",
 InitializationCell->True],
Cell[140769, 3695, 1390, 41, 172, "Input",
 InitializationCell->True,
 CellTags->"plot1"],
Cell[142162, 3738, 5711, 85, 2118, "Input",
 InitializationCell->True,
 CellTags->"plot1"],
Cell[147876, 3825, 811, 24, 233, "Input",
 InitializationCell->True],
Cell[148690, 3851, 825, 28, 67, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[149540, 3883, 508, 14, 103, "Input",
 InitializationCell->True],
Cell[150051, 3899, 781, 15, 15, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[150869, 3919, 162, 4, 39, "Input"],
Cell[151034, 3925, 2364, 38, 78, "Print",
 CellTags->"Info3460133123-4927937"]
}, Open  ]],
Cell[CellGroupData[{
Cell[153435, 3968, 439, 13, 39, "Input"],
Cell[153877, 3983, 314, 6, 164, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[154228, 3994, 141, 3, 39, "Input"],
Cell[154372, 3999, 844, 16, 54, "Print",
 CellTags->"Info3460133161-7256246"],
Cell[155219, 4017, 1190, 33, 68, "Print",
 CellTags->"Info3460133161-7256246"]
}, Open  ]],
Cell[156424, 4053, 3113, 53, 1234, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[159562, 4110, 833, 24, 100, "Input"],
Cell[160398, 4136, 1033, 28, 95, "Output"],
Cell[161434, 4166, 2060, 43, 366, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[163543, 4215, 235, 6, 58, "Section",
 InitializationCell->True],
Cell[163781, 4223, 1171, 39, 217, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[164977, 4266, 200, 5, 50, "Subsection",
 InitializationCell->True],
Cell[165180, 4273, 370, 12, 103, "Input",
 InitializationCell->True],
Cell[165553, 4287, 392, 13, 116, "Input",
 InitializationCell->True],
Cell[165948, 4302, 711, 17, 168, "Input",
 InitializationCell->True],
Cell[166662, 4321, 816, 19, 194, "Input",
 InitializationCell->True],
Cell[167481, 4342, 1194, 24, 259, "Input",
 InitializationCell->True],
Cell[168678, 4368, 1276, 25, 259, "Input",
 InitializationCell->True],
Cell[169957, 4395, 879, 21, 207, "Input",
 InitializationCell->True],
Cell[170839, 4418, 440, 11, 77, "Input",
 InitializationCell->True],
Cell[171282, 4431, 5874, 147, 1637, "Input",
 InitializationCell->True,
 CellTags->"BFGS"],
Cell[177159, 4580, 1030, 23, 207, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[178214, 4607, 199, 5, 51, "Input"],
Cell[178416, 4614, 138, 2, 35, "Print"],
Cell[178557, 4618, 103, 1, 35, "Print"],
Cell[178663, 4621, 138, 2, 35, "Print"],
Cell[178804, 4625, 280, 6, 35, "Print"],
Cell[179087, 4633, 154, 2, 35, "Print"],
Cell[179244, 4637, 1461, 42, 71, "Print"]
}, Open  ]],
Cell[180720, 4682, 1400, 31, 325, "Input",
 InitializationCell->True],
Cell[182123, 4715, 1886, 35, 376, "Input",
 InitializationCell->True]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[184058, 4756, 98, 1, 32, "Section"],
Cell[CellGroupData[{
Cell[184181, 4761, 215, 4, 50, "Subsection"],
Cell[184399, 4767, 173, 7, 50, "Text"],
Cell[184575, 4776, 272, 10, 65, "Text"],
Cell[CellGroupData[{
Cell[184872, 4790, 2486, 67, 145, "Input"],
Cell[187361, 4859, 160, 4, 39, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[187558, 4868, 878, 18, 55, "Input"],
Cell[188439, 4888, 1806, 49, 109, "Output"]
}, Open  ]],
Cell[190260, 4940, 1221, 29, 85, "Input"],
Cell[CellGroupData[{
Cell[191506, 4973, 878, 18, 55, "Input"],
Cell[192387, 4993, 1231, 35, 109, "Output"]
}, Open  ]],
Cell[193633, 5031, 1645, 43, 85, "Input"],
Cell[CellGroupData[{
Cell[195303, 5078, 901, 19, 55, "Input"],
Cell[196207, 5099, 1494, 41, 135, "Output"]
}, Open  ]],
Cell[197716, 5143, 2712, 60, 250, "Input"],
Cell[CellGroupData[{
Cell[200453, 5207, 848, 17, 55, "Input"],
Cell[201304, 5226, 267, 7, 39, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[201608, 5238, 893, 18, 55, "Input"],
Cell[202504, 5258, 1638, 43, 121, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[204179, 5306, 1825, 40, 130, "Input"],
Cell[206007, 5348, 340, 9, 39, "Output"]
}, Open  ]],
Cell[206362, 5360, 921, 20, 55, "Input"],
Cell[CellGroupData[{
Cell[207308, 5384, 1864, 43, 115, "Input"],
Cell[209175, 5429, 350, 11, 59, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[209574, 5446, 131, 2, 28, "Subsection"],
Cell[209708, 5450, 3500, 86, 493, "Input"],
Cell[213211, 5538, 9033, 242, 828, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
